from dataclasses import dataclass
from enum import Enum
from typing import Optional

@dataclass(frozen=True)
class ThirtyTwoBits:
    """
    Class representing 32 bits that can be interpreted either as a signed or unsigned 32-bit integer.
    ThirtyTwoBits values can be equality-compared to integers; the comparision will return True for both the signed and unsigned interpretation of the underlying 32 bits.
    """

    underlying_unsigned_value: int

    def __init__(self, value: int) -> None:
        """
        Constructor a ThirtyTwoBits object. Argument can be any (signed or unsigned) value that can be represented in 32 bits, i.e. any value in the range [-2147483648, 4294967295].
        Passing a value not representable in 32 bits raises a ValueError, while passing any other type of value raises a TypeError.
        """

        if not isinstance(value, int):
            raise TypeError(f'Not a valid int value: {repr(value)}')

        min_signed = -2**31
        max_unsigned = 2**32-1
        if value < min_signed or value > max_unsigned:
            raise ValueError(f'Value must be in [{min_signed}, {max_unsigned}] to be representable in 32 bits: {value}')

        if value < 0:
            value = value + 2**32

        # Get around frozen=True's limitation
        # See details here: https://stackoverflow.com/a/58336722
        object.__setattr__(self, 'underlying_unsigned_value', value)

    @property
    def unsigned_value(self) -> int:
        """
        The numeric value of the ThirtyTwoBits object, interpreted as a 32-bit unsigned integer.
        Always will be in range [0, 4294967295].
        x == x.usigned_value returns True for all ThirtyTwoBits values.
        """

        return self.underlying_unsigned_value

    @property
    def signed_value(self) -> int:
        """
        The numeric value of the ThirtyTwoBits object, interpreted as a 32-bit signed integer.
        Always will be in range [-2147483648, 2147483647].
        x == x.signed_value returns True for all ThirtyTwoBits values.
        """

        return (self.underlying_unsigned_value ^ 0x80000000) - 0x80000000

    def __eq__(self, other: object) -> bool:
        """
        Equality check for NtStatus. It supports checking ThirtyTwoBits instances against other ThirtyTwoBits instances and ints.
        In the latter case, returns True for both the signed and unsigned interpretation of the underlying 32 bits.
        """

        if isinstance(other, ThirtyTwoBits):
            return self.underlying_unsigned_value == other.underlying_unsigned_value

        if isinstance(other, int):
            try:
                return self == ThirtyTwoBits(other)
            except ValueError:
                return False

        return NotImplemented

class NtStatusSeverity(Enum):
    """
    Enumeration representing WinAPI NTSTATUS severity values. Values can be obtained using the 'severity' property of NtStatus values.

    See explanation of severity values here: https://learn.microsoft.com/en-us/windows-hardware/drivers/kernel/using-ntstatus-values
    See how to calculate the severity from a numeric NTSTATUS value here: https://learn.microsoft.com/en-us/openspecs/windows_protocols/ms-erref/87fba13e-bf06-450e-83b1-9241dc81e781
    """

    STATUS_SEVERITY_SUCCESS = 0x0
    STATUS_SEVERITY_INFORMATIONAL = 0x1
    STATUS_SEVERITY_WARNING = 0x2
    STATUS_SEVERITY_ERROR = 0x3

class NtStatus(Enum):
    """
    Enumeration representing WinAPI NTSTATUS values.
    See definition and meaning of values here: https://learn.microsoft.com/en-us/openspecs/windows_protocols/ms-erref/596a1078-e883-4972-9bbc-49e60bebca55

    NtStatus values can be equality-compared to integers; the comparision will return True for both the signed and unsigned interpretation of the underlying 32 bits.

    Properties:
    - signed_value: The numeric value of the NtStatus, interpreted as a 32-bit signed integer.
    - unsigned_value: The numeric value of the NtStatus, interpreted as a 32-bit unsigned integer.
    - exit_code: The numeric value of the NtStatus, interpreted in a way that it can be passed to sys.exit() without information loss. (Alias to signed_value.)

    Static methods:
    - make(code): Factory method for creating an NtStatus from an integer. Raises ValueError if argument is not a known NtStatus value.
    - decode(code): Factory method for creating an NtStatus from an integer. Returns None if argument is not a known NtStatus value.
    - decode_name(code, default=''): Returns the name of the NtStatus value associated with the first argument if there is such a value. Otherwise, returns the second argument.
    """

    @property
    def signed_value(self) -> int:
        """
        The numeric value of the NtStatus, interpreted as a 32-bit signed integer.
        Always will be in range [-2147483648, 2147483647].
        status == status.signed_value returns True for all NtStatus values.
        """

        return self.value.signed_value

    @property
    def unsigned_value(self) -> int:
        """
        The numeric value of the NtStatus, interpreted as a 32-bit unsigned integer.
        Always will be in range [0, 4294967295].
        status == status.usigned_value returns True for all NtStatus values.
        """

        return self.value.unsigned_value

    @property
    def exit_code(self) -> int:
        """
        The numeric value of the NtStatus, interpreted in a way that it can be passed to sys.exit() without information loss.
        Implemented as an alias to signed_value.
        """

        return self.signed_value

    @property
    def severity(self) -> NtStatusSeverity:
        """
        Severity of the NtStatus. Returns one of the 4 NtStatusSeverity values.
        """

        return NtStatusSeverity((self.unsigned_value & 0xC0000000) >> 30)

    def __eq__(self, other: object) -> bool:
        """
        Equality check for NtStatus. It supports checking NtStatus against other NtStatus instances, ThirtyTwoBits instances and ints.
        In the latter case, returns True for both the signed and unsigned interpretation of the underlying 32 bits.
        """

        if isinstance(other, NtStatus):
            return self.value == other.value

        if isinstance(other, ThirtyTwoBits):
            return self.value == other

        if isinstance(other, int):
            try:
                return self == ThirtyTwoBits(other)
            except ValueError:
                return False

        return NotImplemented

    def __repr__(self) -> str:
        return f'<NtStatus.{self.name}: 0x{self.unsigned_value:08X}>'

    @staticmethod
    def make(code: int) -> 'NtStatus':
        """
        Factory method for creating an NtStatus from an integer. Raises ValueError if argument is not a known NtStatus value.
        """

        if not isinstance(code, int):
            raise TypeError(f'Not a valid int value: {repr(code)}')

        return NtStatus(ThirtyTwoBits(code))

    @staticmethod
    def decode(code: int) -> Optional['NtStatus']:
        """
        Factory method for creating an NtStatus from an integer. Returns None if argument is not a known NtStatus value.
        """

        try:
            return NtStatus.make(code)
        except ValueError:
            return None

    @staticmethod
    def decode_name(code: int, default: str = '') -> str:
        """
        Returns the name of the NtStatus value associated with the first argument if there is such a value.
        Returns the second argument otherwise, or an empty string if there is no second argument.
        """

        try:
            return NtStatus.make(code).name
        except ValueError:
            return default

    # AUTOGENERATED FROM HERE, DO NOT TOUCH

    STATUS_SUCCESS = ThirtyTwoBits(0x00000000)
    STATUS_ABANDONED = ThirtyTwoBits(0x00000080)
    STATUS_USER_APC = ThirtyTwoBits(0x000000C0)
    STATUS_ALREADY_COMPLETE = ThirtyTwoBits(0x000000FF)
    STATUS_KERNEL_APC = ThirtyTwoBits(0x00000100)
    STATUS_ALERTED = ThirtyTwoBits(0x00000101)
    STATUS_TIMEOUT = ThirtyTwoBits(0x00000102)
    STATUS_PENDING = ThirtyTwoBits(0x00000103)
    STATUS_REPARSE = ThirtyTwoBits(0x00000104)
    STATUS_MORE_ENTRIES = ThirtyTwoBits(0x00000105)
    STATUS_NOT_ALL_ASSIGNED = ThirtyTwoBits(0x00000106)
    STATUS_SOME_NOT_MAPPED = ThirtyTwoBits(0x00000107)
    STATUS_OPLOCK_BREAK_IN_PROGRESS = ThirtyTwoBits(0x00000108)
    STATUS_VOLUME_MOUNTED = ThirtyTwoBits(0x00000109)
    STATUS_RXACT_COMMITTED = ThirtyTwoBits(0x0000010A)
    STATUS_NOTIFY_CLEANUP = ThirtyTwoBits(0x0000010B)
    STATUS_NOTIFY_ENUM_DIR = ThirtyTwoBits(0x0000010C)
    STATUS_NO_QUOTAS_FOR_ACCOUNT = ThirtyTwoBits(0x0000010D)
    STATUS_PRIMARY_TRANSPORT_CONNECT_FAILED = ThirtyTwoBits(0x0000010E)
    STATUS_PAGE_FAULT_TRANSITION = ThirtyTwoBits(0x00000110)
    STATUS_PAGE_FAULT_DEMAND_ZERO = ThirtyTwoBits(0x00000111)
    STATUS_PAGE_FAULT_COPY_ON_WRITE = ThirtyTwoBits(0x00000112)
    STATUS_PAGE_FAULT_GUARD_PAGE = ThirtyTwoBits(0x00000113)
    STATUS_PAGE_FAULT_PAGING_FILE = ThirtyTwoBits(0x00000114)
    STATUS_CACHE_PAGE_LOCKED = ThirtyTwoBits(0x00000115)
    STATUS_CRASH_DUMP = ThirtyTwoBits(0x00000116)
    STATUS_BUFFER_ALL_ZEROS = ThirtyTwoBits(0x00000117)
    STATUS_REPARSE_OBJECT = ThirtyTwoBits(0x00000118)
    STATUS_RESOURCE_REQUIREMENTS_CHANGED = ThirtyTwoBits(0x00000119)
    STATUS_TRANSLATION_COMPLETE = ThirtyTwoBits(0x00000120)
    STATUS_DS_MEMBERSHIP_EVALUATED_LOCALLY = ThirtyTwoBits(0x00000121)
    STATUS_NOTHING_TO_TERMINATE = ThirtyTwoBits(0x00000122)
    STATUS_PROCESS_NOT_IN_JOB = ThirtyTwoBits(0x00000123)
    STATUS_PROCESS_IN_JOB = ThirtyTwoBits(0x00000124)
    STATUS_VOLSNAP_HIBERNATE_READY = ThirtyTwoBits(0x00000125)
    STATUS_FSFILTER_OP_COMPLETED_SUCCESSFULLY = ThirtyTwoBits(0x00000126)
    STATUS_INTERRUPT_VECTOR_ALREADY_CONNECTED = ThirtyTwoBits(0x00000127)
    STATUS_INTERRUPT_STILL_CONNECTED = ThirtyTwoBits(0x00000128)
    STATUS_PROCESS_CLONED = ThirtyTwoBits(0x00000129)
    STATUS_FILE_LOCKED_WITH_ONLY_READERS = ThirtyTwoBits(0x0000012A)
    STATUS_FILE_LOCKED_WITH_WRITERS = ThirtyTwoBits(0x0000012B)
    STATUS_VALID_IMAGE_HASH = ThirtyTwoBits(0x0000012C)
    STATUS_VALID_CATALOG_HASH = ThirtyTwoBits(0x0000012D)
    STATUS_VALID_STRONG_CODE_HASH = ThirtyTwoBits(0x0000012E)
    STATUS_GHOSTED = ThirtyTwoBits(0x0000012F)
    STATUS_DATA_OVERWRITTEN = ThirtyTwoBits(0x00000130)
    STATUS_RESOURCEMANAGER_READ_ONLY = ThirtyTwoBits(0x00000202)
    STATUS_RING_PREVIOUSLY_EMPTY = ThirtyTwoBits(0x00000210)
    STATUS_RING_PREVIOUSLY_FULL = ThirtyTwoBits(0x00000211)
    STATUS_RING_PREVIOUSLY_ABOVE_QUOTA = ThirtyTwoBits(0x00000212)
    STATUS_RING_NEWLY_EMPTY = ThirtyTwoBits(0x00000213)
    STATUS_RING_SIGNAL_OPPOSITE_ENDPOINT = ThirtyTwoBits(0x00000214)
    STATUS_OPLOCK_SWITCHED_TO_NEW_HANDLE = ThirtyTwoBits(0x00000215)
    STATUS_OPLOCK_HANDLE_CLOSED = ThirtyTwoBits(0x00000216)
    STATUS_WAIT_FOR_OPLOCK = ThirtyTwoBits(0x00000367)
    STATUS_REPARSE_GLOBAL = ThirtyTwoBits(0x00000368)
    STATUS_PAGE_FAULT_RETRY = ThirtyTwoBits(0x00000369)
    STATUS_FLT_IO_COMPLETE = ThirtyTwoBits(0x001C0001)
    STATUS_RTPM_CONTEXT_CONTINUE = ThirtyTwoBits(0x00293000)
    STATUS_RTPM_CONTEXT_COMPLETE = ThirtyTwoBits(0x00293001)
    STATUS_HV_PENDING_PAGE_REQUESTS = ThirtyTwoBits(0x00350059)
    STATUS_SPACES_REPAIRED = ThirtyTwoBits(0x00E70000)
    STATUS_SPACES_PAUSE = ThirtyTwoBits(0x00E70001)
    STATUS_SPACES_COMPLETE = ThirtyTwoBits(0x00E70002)
    STATUS_SPACES_REDIRECT = ThirtyTwoBits(0x00E70003)
    STATUS_OBJECT_NAME_EXISTS = ThirtyTwoBits(0x40000000)
    STATUS_THREAD_WAS_SUSPENDED = ThirtyTwoBits(0x40000001)
    STATUS_WORKING_SET_LIMIT_RANGE = ThirtyTwoBits(0x40000002)
    STATUS_IMAGE_NOT_AT_BASE = ThirtyTwoBits(0x40000003)
    STATUS_RXACT_STATE_CREATED = ThirtyTwoBits(0x40000004)
    STATUS_SEGMENT_NOTIFICATION = ThirtyTwoBits(0x40000005)
    STATUS_LOCAL_USER_SESSION_KEY = ThirtyTwoBits(0x40000006)
    STATUS_BAD_CURRENT_DIRECTORY = ThirtyTwoBits(0x40000007)
    STATUS_SERIAL_MORE_WRITES = ThirtyTwoBits(0x40000008)
    STATUS_REGISTRY_RECOVERED = ThirtyTwoBits(0x40000009)
    STATUS_FT_READ_RECOVERY_FROM_BACKUP = ThirtyTwoBits(0x4000000A)
    STATUS_FT_WRITE_RECOVERY = ThirtyTwoBits(0x4000000B)
    STATUS_SERIAL_COUNTER_TIMEOUT = ThirtyTwoBits(0x4000000C)
    STATUS_NULL_LM_PASSWORD = ThirtyTwoBits(0x4000000D)
    STATUS_IMAGE_MACHINE_TYPE_MISMATCH = ThirtyTwoBits(0x4000000E)
    STATUS_RECEIVE_PARTIAL = ThirtyTwoBits(0x4000000F)
    STATUS_RECEIVE_EXPEDITED = ThirtyTwoBits(0x40000010)
    STATUS_RECEIVE_PARTIAL_EXPEDITED = ThirtyTwoBits(0x40000011)
    STATUS_EVENT_DONE = ThirtyTwoBits(0x40000012)
    STATUS_EVENT_PENDING = ThirtyTwoBits(0x40000013)
    STATUS_CHECKING_FILE_SYSTEM = ThirtyTwoBits(0x40000014)
    STATUS_FATAL_APP_EXIT = ThirtyTwoBits(0x40000015)
    STATUS_PREDEFINED_HANDLE = ThirtyTwoBits(0x40000016)
    STATUS_WAS_UNLOCKED = ThirtyTwoBits(0x40000017)
    STATUS_SERVICE_NOTIFICATION = ThirtyTwoBits(0x40000018)
    STATUS_WAS_LOCKED = ThirtyTwoBits(0x40000019)
    STATUS_LOG_HARD_ERROR = ThirtyTwoBits(0x4000001A)
    STATUS_ALREADY_WIN32 = ThirtyTwoBits(0x4000001B)
    STATUS_WX86_UNSIMULATE = ThirtyTwoBits(0x4000001C)
    STATUS_WX86_CONTINUE = ThirtyTwoBits(0x4000001D)
    STATUS_WX86_SINGLE_STEP = ThirtyTwoBits(0x4000001E)
    STATUS_WX86_BREAKPOINT = ThirtyTwoBits(0x4000001F)
    STATUS_WX86_EXCEPTION_CONTINUE = ThirtyTwoBits(0x40000020)
    STATUS_WX86_EXCEPTION_LASTCHANCE = ThirtyTwoBits(0x40000021)
    STATUS_WX86_EXCEPTION_CHAIN = ThirtyTwoBits(0x40000022)
    STATUS_IMAGE_MACHINE_TYPE_MISMATCH_EXE = ThirtyTwoBits(0x40000023)
    STATUS_NO_YIELD_PERFORMED = ThirtyTwoBits(0x40000024)
    STATUS_TIMER_RESUME_IGNORED = ThirtyTwoBits(0x40000025)
    STATUS_ARBITRATION_UNHANDLED = ThirtyTwoBits(0x40000026)
    STATUS_CARDBUS_NOT_SUPPORTED = ThirtyTwoBits(0x40000027)
    STATUS_WX86_CREATEWX86TIB = ThirtyTwoBits(0x40000028)
    STATUS_MP_PROCESSOR_MISMATCH = ThirtyTwoBits(0x40000029)
    STATUS_HIBERNATED = ThirtyTwoBits(0x4000002A)
    STATUS_RESUME_HIBERNATION = ThirtyTwoBits(0x4000002B)
    STATUS_FIRMWARE_UPDATED = ThirtyTwoBits(0x4000002C)
    STATUS_DRIVERS_LEAKING_LOCKED_PAGES = ThirtyTwoBits(0x4000002D)
    STATUS_MESSAGE_RETRIEVED = ThirtyTwoBits(0x4000002E)
    STATUS_SYSTEM_POWERSTATE_TRANSITION = ThirtyTwoBits(0x4000002F)
    STATUS_ALPC_CHECK_COMPLETION_LIST = ThirtyTwoBits(0x40000030)
    STATUS_SYSTEM_POWERSTATE_COMPLEX_TRANSITION = ThirtyTwoBits(0x40000031)
    STATUS_ACCESS_AUDIT_BY_POLICY = ThirtyTwoBits(0x40000032)
    STATUS_ABANDON_HIBERFILE = ThirtyTwoBits(0x40000033)
    STATUS_BIZRULES_NOT_ENABLED = ThirtyTwoBits(0x40000034)
    STATUS_FT_READ_FROM_COPY = ThirtyTwoBits(0x40000035)
    STATUS_IMAGE_AT_DIFFERENT_BASE = ThirtyTwoBits(0x40000036)
    STATUS_PATCH_DEFERRED = ThirtyTwoBits(0x40000037)
    STATUS_EMULATION_BREAKPOINT = ThirtyTwoBits(0x40000038)
    STATUS_EMULATION_SYSCALL = ThirtyTwoBits(0x40000039)
    STATUS_WAKE_SYSTEM = ThirtyTwoBits(0x40000294)
    STATUS_DS_SHUTTING_DOWN = ThirtyTwoBits(0x40000370)
    STATUS_DISK_REPAIR_REDIRECTED = ThirtyTwoBits(0x40000807)
    STATUS_SERVICES_FAILED_AUTOSTART = ThirtyTwoBits(0x4000A144)
    STATUS_CTX_CDM_CONNECT = ThirtyTwoBits(0x400A0004)
    STATUS_CTX_CDM_DISCONNECT = ThirtyTwoBits(0x400A0005)
    STATUS_SXS_RELEASE_ACTIVATION_CONTEXT = ThirtyTwoBits(0x4015000D)
    STATUS_HEURISTIC_DAMAGE_POSSIBLE = ThirtyTwoBits(0x40190001)
    STATUS_RECOVERY_NOT_NEEDED = ThirtyTwoBits(0x40190034)
    STATUS_RM_ALREADY_STARTED = ThirtyTwoBits(0x40190035)
    STATUS_LOG_NO_RESTART = ThirtyTwoBits(0x401A000C)
    STATUS_VIDEO_DRIVER_DEBUG_REPORT_REQUEST = ThirtyTwoBits(0x401B00EC)
    STATUS_GRAPHICS_PARTIAL_DATA_POPULATED = ThirtyTwoBits(0x401E000A)
    STATUS_GRAPHICS_SKIP_ALLOCATION_PREPARATION = ThirtyTwoBits(0x401E0201)
    STATUS_GRAPHICS_MODE_NOT_PINNED = ThirtyTwoBits(0x401E0307)
    STATUS_GRAPHICS_NO_PREFERRED_MODE = ThirtyTwoBits(0x401E031E)
    STATUS_GRAPHICS_DATASET_IS_EMPTY = ThirtyTwoBits(0x401E034B)
    STATUS_GRAPHICS_NO_MORE_ELEMENTS_IN_DATASET = ThirtyTwoBits(0x401E034C)
    STATUS_GRAPHICS_PATH_CONTENT_GEOMETRY_TRANSFORMATION_NOT_PINNED = ThirtyTwoBits(0x401E0351)
    STATUS_GRAPHICS_UNKNOWN_CHILD_STATUS = ThirtyTwoBits(0x401E042F)
    STATUS_GRAPHICS_LEADLINK_START_DEFERRED = ThirtyTwoBits(0x401E0437)
    STATUS_GRAPHICS_POLLING_TOO_FREQUENTLY = ThirtyTwoBits(0x401E0439)
    STATUS_GRAPHICS_START_DEFERRED = ThirtyTwoBits(0x401E043A)
    STATUS_GRAPHICS_DEPENDABLE_CHILD_STATUS = ThirtyTwoBits(0x401E043C)
    STATUS_NDIS_INDICATION_REQUIRED = ThirtyTwoBits(0x40230001)
    STATUS_PCP_UNSUPPORTED_PSS_SALT = ThirtyTwoBits(0x40292023)
    STATUS_GUARD_PAGE_VIOLATION = ThirtyTwoBits(0x80000001)
    STATUS_DATATYPE_MISALIGNMENT = ThirtyTwoBits(0x80000002)
    STATUS_BREAKPOINT = ThirtyTwoBits(0x80000003)
    STATUS_SINGLE_STEP = ThirtyTwoBits(0x80000004)
    STATUS_BUFFER_OVERFLOW = ThirtyTwoBits(0x80000005)
    STATUS_NO_MORE_FILES = ThirtyTwoBits(0x80000006)
    STATUS_WAKE_SYSTEM_DEBUGGER = ThirtyTwoBits(0x80000007)
    STATUS_HANDLES_CLOSED = ThirtyTwoBits(0x8000000A)
    STATUS_NO_INHERITANCE = ThirtyTwoBits(0x8000000B)
    STATUS_GUID_SUBSTITUTION_MADE = ThirtyTwoBits(0x8000000C)
    STATUS_PARTIAL_COPY = ThirtyTwoBits(0x8000000D)
    STATUS_DEVICE_PAPER_EMPTY = ThirtyTwoBits(0x8000000E)
    STATUS_DEVICE_POWERED_OFF = ThirtyTwoBits(0x8000000F)
    STATUS_DEVICE_OFF_LINE = ThirtyTwoBits(0x80000010)
    STATUS_DEVICE_BUSY = ThirtyTwoBits(0x80000011)
    STATUS_NO_MORE_EAS = ThirtyTwoBits(0x80000012)
    STATUS_INVALID_EA_NAME = ThirtyTwoBits(0x80000013)
    STATUS_EA_LIST_INCONSISTENT = ThirtyTwoBits(0x80000014)
    STATUS_INVALID_EA_FLAG = ThirtyTwoBits(0x80000015)
    STATUS_VERIFY_REQUIRED = ThirtyTwoBits(0x80000016)
    STATUS_EXTRANEOUS_INFORMATION = ThirtyTwoBits(0x80000017)
    STATUS_RXACT_COMMIT_NECESSARY = ThirtyTwoBits(0x80000018)
    STATUS_NO_MORE_ENTRIES = ThirtyTwoBits(0x8000001A)
    STATUS_FILEMARK_DETECTED = ThirtyTwoBits(0x8000001B)
    STATUS_MEDIA_CHANGED = ThirtyTwoBits(0x8000001C)
    STATUS_BUS_RESET = ThirtyTwoBits(0x8000001D)
    STATUS_END_OF_MEDIA = ThirtyTwoBits(0x8000001E)
    STATUS_BEGINNING_OF_MEDIA = ThirtyTwoBits(0x8000001F)
    STATUS_MEDIA_CHECK = ThirtyTwoBits(0x80000020)
    STATUS_SETMARK_DETECTED = ThirtyTwoBits(0x80000021)
    STATUS_NO_DATA_DETECTED = ThirtyTwoBits(0x80000022)
    STATUS_REDIRECTOR_HAS_OPEN_HANDLES = ThirtyTwoBits(0x80000023)
    STATUS_SERVER_HAS_OPEN_HANDLES = ThirtyTwoBits(0x80000024)
    STATUS_ALREADY_DISCONNECTED = ThirtyTwoBits(0x80000025)
    STATUS_LONGJUMP = ThirtyTwoBits(0x80000026)
    STATUS_CLEANER_CARTRIDGE_INSTALLED = ThirtyTwoBits(0x80000027)
    STATUS_PLUGPLAY_QUERY_VETOED = ThirtyTwoBits(0x80000028)
    STATUS_UNWIND_CONSOLIDATE = ThirtyTwoBits(0x80000029)
    STATUS_REGISTRY_HIVE_RECOVERED = ThirtyTwoBits(0x8000002A)
    STATUS_DLL_MIGHT_BE_INSECURE = ThirtyTwoBits(0x8000002B)
    STATUS_DLL_MIGHT_BE_INCOMPATIBLE = ThirtyTwoBits(0x8000002C)
    STATUS_STOPPED_ON_SYMLINK = ThirtyTwoBits(0x8000002D)
    STATUS_CANNOT_GRANT_REQUESTED_OPLOCK = ThirtyTwoBits(0x8000002E)
    STATUS_NO_ACE_CONDITION = ThirtyTwoBits(0x8000002F)
    STATUS_DEVICE_SUPPORT_IN_PROGRESS = ThirtyTwoBits(0x80000030)
    STATUS_DEVICE_POWER_CYCLE_REQUIRED = ThirtyTwoBits(0x80000031)
    STATUS_NO_WORK_DONE = ThirtyTwoBits(0x80000032)
    STATUS_RETURN_ADDRESS_HIJACK_ATTEMPT = ThirtyTwoBits(0x80000033)
    STATUS_RECOVERABLE_BUGCHECK = ThirtyTwoBits(0x80000034)
    STATUS_DEVICE_RESET_REQUIRED = ThirtyTwoBits(0x800001B6)
    STATUS_DEVICE_REQUIRES_CLEANING = ThirtyTwoBits(0x80000288)
    STATUS_DEVICE_DOOR_OPEN = ThirtyTwoBits(0x80000289)
    STATUS_DATA_LOST_REPAIR = ThirtyTwoBits(0x80000803)
    STATUS_GPIO_INTERRUPT_ALREADY_UNMASKED = ThirtyTwoBits(0x8000A127)
    STATUS_CLOUD_FILE_PROPERTY_BLOB_CHECKSUM_MISMATCH = ThirtyTwoBits(0x8000CF00)
    STATUS_CLOUD_FILE_PROPERTY_BLOB_TOO_LARGE = ThirtyTwoBits(0x8000CF04)
    STATUS_CLOUD_FILE_TOO_MANY_PROPERTY_BLOBS = ThirtyTwoBits(0x8000CF05)
    STATUS_CLUSTER_NODE_ALREADY_UP = ThirtyTwoBits(0x80130001)
    STATUS_CLUSTER_NODE_ALREADY_DOWN = ThirtyTwoBits(0x80130002)
    STATUS_CLUSTER_NETWORK_ALREADY_ONLINE = ThirtyTwoBits(0x80130003)
    STATUS_CLUSTER_NETWORK_ALREADY_OFFLINE = ThirtyTwoBits(0x80130004)
    STATUS_CLUSTER_NODE_ALREADY_MEMBER = ThirtyTwoBits(0x80130005)
    STATUS_COULD_NOT_RESIZE_LOG = ThirtyTwoBits(0x80190009)
    STATUS_NO_TXF_METADATA = ThirtyTwoBits(0x80190029)
    STATUS_CANT_RECOVER_WITH_HANDLE_OPEN = ThirtyTwoBits(0x80190031)
    STATUS_TXF_METADATA_ALREADY_PRESENT = ThirtyTwoBits(0x80190041)
    STATUS_TRANSACTION_SCOPE_CALLBACKS_NOT_SET = ThirtyTwoBits(0x80190042)
    STATUS_VIDEO_HUNG_DISPLAY_DRIVER_THREAD_RECOVERED = ThirtyTwoBits(0x801B00EB)
    STATUS_FLT_BUFFER_TOO_SMALL = ThirtyTwoBits(0x801C0001)
    STATUS_GRAPHICS_LINK_CONFIGURATION_IN_PROGRESS = ThirtyTwoBits(0x801E0000)
    STATUS_FVE_PARTIAL_METADATA = ThirtyTwoBits(0x80210001)
    STATUS_FVE_TRANSIENT_STATE = ThirtyTwoBits(0x80210002)
    STATUS_VID_REMOTE_NODE_PARENT_GPA_PAGES_USED = ThirtyTwoBits(0x80370001)
    STATUS_VOLMGR_INCOMPLETE_REGENERATION = ThirtyTwoBits(0x80380001)
    STATUS_VOLMGR_INCOMPLETE_DISK_MIGRATION = ThirtyTwoBits(0x80380002)
    STATUS_BCD_NOT_ALL_ENTRIES_IMPORTED = ThirtyTwoBits(0x80390001)
    STATUS_BCD_NOT_ALL_ENTRIES_SYNCHRONIZED = ThirtyTwoBits(0x80390003)
    STATUS_QUERY_STORAGE_ERROR = ThirtyTwoBits(0x803A0001)
    STATUS_GDI_HANDLE_LEAK = ThirtyTwoBits(0x803F0001)
    STATUS_SECUREBOOT_NOT_ENABLED = ThirtyTwoBits(0x80430006)
    STATUS_UNSUCCESSFUL = ThirtyTwoBits(0xC0000001)
    STATUS_NOT_IMPLEMENTED = ThirtyTwoBits(0xC0000002)
    STATUS_INVALID_INFO_CLASS = ThirtyTwoBits(0xC0000003)
    STATUS_INFO_LENGTH_MISMATCH = ThirtyTwoBits(0xC0000004)
    STATUS_ACCESS_VIOLATION = ThirtyTwoBits(0xC0000005)
    STATUS_IN_PAGE_ERROR = ThirtyTwoBits(0xC0000006)
    STATUS_PAGEFILE_QUOTA = ThirtyTwoBits(0xC0000007)
    STATUS_INVALID_HANDLE = ThirtyTwoBits(0xC0000008)
    STATUS_BAD_INITIAL_STACK = ThirtyTwoBits(0xC0000009)
    STATUS_BAD_INITIAL_PC = ThirtyTwoBits(0xC000000A)
    STATUS_INVALID_CID = ThirtyTwoBits(0xC000000B)
    STATUS_TIMER_NOT_CANCELED = ThirtyTwoBits(0xC000000C)
    STATUS_INVALID_PARAMETER = ThirtyTwoBits(0xC000000D)
    STATUS_NO_SUCH_DEVICE = ThirtyTwoBits(0xC000000E)
    STATUS_NO_SUCH_FILE = ThirtyTwoBits(0xC000000F)
    STATUS_INVALID_DEVICE_REQUEST = ThirtyTwoBits(0xC0000010)
    STATUS_END_OF_FILE = ThirtyTwoBits(0xC0000011)
    STATUS_WRONG_VOLUME = ThirtyTwoBits(0xC0000012)
    STATUS_NO_MEDIA_IN_DEVICE = ThirtyTwoBits(0xC0000013)
    STATUS_UNRECOGNIZED_MEDIA = ThirtyTwoBits(0xC0000014)
    STATUS_NONEXISTENT_SECTOR = ThirtyTwoBits(0xC0000015)
    STATUS_MORE_PROCESSING_REQUIRED = ThirtyTwoBits(0xC0000016)
    STATUS_NO_MEMORY = ThirtyTwoBits(0xC0000017)
    STATUS_CONFLICTING_ADDRESSES = ThirtyTwoBits(0xC0000018)
    STATUS_NOT_MAPPED_VIEW = ThirtyTwoBits(0xC0000019)
    STATUS_UNABLE_TO_FREE_VM = ThirtyTwoBits(0xC000001A)
    STATUS_UNABLE_TO_DELETE_SECTION = ThirtyTwoBits(0xC000001B)
    STATUS_INVALID_SYSTEM_SERVICE = ThirtyTwoBits(0xC000001C)
    STATUS_ILLEGAL_INSTRUCTION = ThirtyTwoBits(0xC000001D)
    STATUS_INVALID_LOCK_SEQUENCE = ThirtyTwoBits(0xC000001E)
    STATUS_INVALID_VIEW_SIZE = ThirtyTwoBits(0xC000001F)
    STATUS_INVALID_FILE_FOR_SECTION = ThirtyTwoBits(0xC0000020)
    STATUS_ALREADY_COMMITTED = ThirtyTwoBits(0xC0000021)
    STATUS_ACCESS_DENIED = ThirtyTwoBits(0xC0000022)
    STATUS_BUFFER_TOO_SMALL = ThirtyTwoBits(0xC0000023)
    STATUS_OBJECT_TYPE_MISMATCH = ThirtyTwoBits(0xC0000024)
    STATUS_NONCONTINUABLE_EXCEPTION = ThirtyTwoBits(0xC0000025)
    STATUS_INVALID_DISPOSITION = ThirtyTwoBits(0xC0000026)
    STATUS_UNWIND = ThirtyTwoBits(0xC0000027)
    STATUS_BAD_STACK = ThirtyTwoBits(0xC0000028)
    STATUS_INVALID_UNWIND_TARGET = ThirtyTwoBits(0xC0000029)
    STATUS_NOT_LOCKED = ThirtyTwoBits(0xC000002A)
    STATUS_PARITY_ERROR = ThirtyTwoBits(0xC000002B)
    STATUS_UNABLE_TO_DECOMMIT_VM = ThirtyTwoBits(0xC000002C)
    STATUS_NOT_COMMITTED = ThirtyTwoBits(0xC000002D)
    STATUS_INVALID_PORT_ATTRIBUTES = ThirtyTwoBits(0xC000002E)
    STATUS_PORT_MESSAGE_TOO_LONG = ThirtyTwoBits(0xC000002F)
    STATUS_INVALID_PARAMETER_MIX = ThirtyTwoBits(0xC0000030)
    STATUS_INVALID_QUOTA_LOWER = ThirtyTwoBits(0xC0000031)
    STATUS_DISK_CORRUPT_ERROR = ThirtyTwoBits(0xC0000032)
    STATUS_OBJECT_NAME_INVALID = ThirtyTwoBits(0xC0000033)
    STATUS_OBJECT_NAME_NOT_FOUND = ThirtyTwoBits(0xC0000034)
    STATUS_OBJECT_NAME_COLLISION = ThirtyTwoBits(0xC0000035)
    STATUS_PORT_DO_NOT_DISTURB = ThirtyTwoBits(0xC0000036)
    STATUS_PORT_DISCONNECTED = ThirtyTwoBits(0xC0000037)
    STATUS_DEVICE_ALREADY_ATTACHED = ThirtyTwoBits(0xC0000038)
    STATUS_OBJECT_PATH_INVALID = ThirtyTwoBits(0xC0000039)
    STATUS_OBJECT_PATH_NOT_FOUND = ThirtyTwoBits(0xC000003A)
    STATUS_OBJECT_PATH_SYNTAX_BAD = ThirtyTwoBits(0xC000003B)
    STATUS_DATA_OVERRUN = ThirtyTwoBits(0xC000003C)
    STATUS_DATA_LATE_ERROR = ThirtyTwoBits(0xC000003D)
    STATUS_DATA_ERROR = ThirtyTwoBits(0xC000003E)
    STATUS_CRC_ERROR = ThirtyTwoBits(0xC000003F)
    STATUS_SECTION_TOO_BIG = ThirtyTwoBits(0xC0000040)
    STATUS_PORT_CONNECTION_REFUSED = ThirtyTwoBits(0xC0000041)
    STATUS_INVALID_PORT_HANDLE = ThirtyTwoBits(0xC0000042)
    STATUS_SHARING_VIOLATION = ThirtyTwoBits(0xC0000043)
    STATUS_QUOTA_EXCEEDED = ThirtyTwoBits(0xC0000044)
    STATUS_INVALID_PAGE_PROTECTION = ThirtyTwoBits(0xC0000045)
    STATUS_MUTANT_NOT_OWNED = ThirtyTwoBits(0xC0000046)
    STATUS_SEMAPHORE_LIMIT_EXCEEDED = ThirtyTwoBits(0xC0000047)
    STATUS_PORT_ALREADY_SET = ThirtyTwoBits(0xC0000048)
    STATUS_SECTION_NOT_IMAGE = ThirtyTwoBits(0xC0000049)
    STATUS_SUSPEND_COUNT_EXCEEDED = ThirtyTwoBits(0xC000004A)
    STATUS_THREAD_IS_TERMINATING = ThirtyTwoBits(0xC000004B)
    STATUS_BAD_WORKING_SET_LIMIT = ThirtyTwoBits(0xC000004C)
    STATUS_INCOMPATIBLE_FILE_MAP = ThirtyTwoBits(0xC000004D)
    STATUS_SECTION_PROTECTION = ThirtyTwoBits(0xC000004E)
    STATUS_EAS_NOT_SUPPORTED = ThirtyTwoBits(0xC000004F)
    STATUS_EA_TOO_LARGE = ThirtyTwoBits(0xC0000050)
    STATUS_NONEXISTENT_EA_ENTRY = ThirtyTwoBits(0xC0000051)
    STATUS_NO_EAS_ON_FILE = ThirtyTwoBits(0xC0000052)
    STATUS_EA_CORRUPT_ERROR = ThirtyTwoBits(0xC0000053)
    STATUS_FILE_LOCK_CONFLICT = ThirtyTwoBits(0xC0000054)
    STATUS_LOCK_NOT_GRANTED = ThirtyTwoBits(0xC0000055)
    STATUS_DELETE_PENDING = ThirtyTwoBits(0xC0000056)
    STATUS_CTL_FILE_NOT_SUPPORTED = ThirtyTwoBits(0xC0000057)
    STATUS_UNKNOWN_REVISION = ThirtyTwoBits(0xC0000058)
    STATUS_REVISION_MISMATCH = ThirtyTwoBits(0xC0000059)
    STATUS_INVALID_OWNER = ThirtyTwoBits(0xC000005A)
    STATUS_INVALID_PRIMARY_GROUP = ThirtyTwoBits(0xC000005B)
    STATUS_NO_IMPERSONATION_TOKEN = ThirtyTwoBits(0xC000005C)
    STATUS_CANT_DISABLE_MANDATORY = ThirtyTwoBits(0xC000005D)
    STATUS_NO_LOGON_SERVERS = ThirtyTwoBits(0xC000005E)
    STATUS_NO_SUCH_LOGON_SESSION = ThirtyTwoBits(0xC000005F)
    STATUS_NO_SUCH_PRIVILEGE = ThirtyTwoBits(0xC0000060)
    STATUS_PRIVILEGE_NOT_HELD = ThirtyTwoBits(0xC0000061)
    STATUS_INVALID_ACCOUNT_NAME = ThirtyTwoBits(0xC0000062)
    STATUS_USER_EXISTS = ThirtyTwoBits(0xC0000063)
    STATUS_NO_SUCH_USER = ThirtyTwoBits(0xC0000064)
    STATUS_GROUP_EXISTS = ThirtyTwoBits(0xC0000065)
    STATUS_NO_SUCH_GROUP = ThirtyTwoBits(0xC0000066)
    STATUS_MEMBER_IN_GROUP = ThirtyTwoBits(0xC0000067)
    STATUS_MEMBER_NOT_IN_GROUP = ThirtyTwoBits(0xC0000068)
    STATUS_LAST_ADMIN = ThirtyTwoBits(0xC0000069)
    STATUS_WRONG_PASSWORD = ThirtyTwoBits(0xC000006A)
    STATUS_ILL_FORMED_PASSWORD = ThirtyTwoBits(0xC000006B)
    STATUS_PASSWORD_RESTRICTION = ThirtyTwoBits(0xC000006C)
    STATUS_LOGON_FAILURE = ThirtyTwoBits(0xC000006D)
    STATUS_ACCOUNT_RESTRICTION = ThirtyTwoBits(0xC000006E)
    STATUS_INVALID_LOGON_HOURS = ThirtyTwoBits(0xC000006F)
    STATUS_INVALID_WORKSTATION = ThirtyTwoBits(0xC0000070)
    STATUS_PASSWORD_EXPIRED = ThirtyTwoBits(0xC0000071)
    STATUS_ACCOUNT_DISABLED = ThirtyTwoBits(0xC0000072)
    STATUS_NONE_MAPPED = ThirtyTwoBits(0xC0000073)
    STATUS_TOO_MANY_LUIDS_REQUESTED = ThirtyTwoBits(0xC0000074)
    STATUS_LUIDS_EXHAUSTED = ThirtyTwoBits(0xC0000075)
    STATUS_INVALID_SUB_AUTHORITY = ThirtyTwoBits(0xC0000076)
    STATUS_INVALID_ACL = ThirtyTwoBits(0xC0000077)
    STATUS_INVALID_SID = ThirtyTwoBits(0xC0000078)
    STATUS_INVALID_SECURITY_DESCR = ThirtyTwoBits(0xC0000079)
    STATUS_PROCEDURE_NOT_FOUND = ThirtyTwoBits(0xC000007A)
    STATUS_INVALID_IMAGE_FORMAT = ThirtyTwoBits(0xC000007B)
    STATUS_NO_TOKEN = ThirtyTwoBits(0xC000007C)
    STATUS_BAD_INHERITANCE_ACL = ThirtyTwoBits(0xC000007D)
    STATUS_RANGE_NOT_LOCKED = ThirtyTwoBits(0xC000007E)
    STATUS_DISK_FULL = ThirtyTwoBits(0xC000007F)
    STATUS_SERVER_DISABLED = ThirtyTwoBits(0xC0000080)
    STATUS_SERVER_NOT_DISABLED = ThirtyTwoBits(0xC0000081)
    STATUS_TOO_MANY_GUIDS_REQUESTED = ThirtyTwoBits(0xC0000082)
    STATUS_GUIDS_EXHAUSTED = ThirtyTwoBits(0xC0000083)
    STATUS_INVALID_ID_AUTHORITY = ThirtyTwoBits(0xC0000084)
    STATUS_AGENTS_EXHAUSTED = ThirtyTwoBits(0xC0000085)
    STATUS_INVALID_VOLUME_LABEL = ThirtyTwoBits(0xC0000086)
    STATUS_SECTION_NOT_EXTENDED = ThirtyTwoBits(0xC0000087)
    STATUS_NOT_MAPPED_DATA = ThirtyTwoBits(0xC0000088)
    STATUS_RESOURCE_DATA_NOT_FOUND = ThirtyTwoBits(0xC0000089)
    STATUS_RESOURCE_TYPE_NOT_FOUND = ThirtyTwoBits(0xC000008A)
    STATUS_RESOURCE_NAME_NOT_FOUND = ThirtyTwoBits(0xC000008B)
    STATUS_ARRAY_BOUNDS_EXCEEDED = ThirtyTwoBits(0xC000008C)
    STATUS_FLOAT_DENORMAL_OPERAND = ThirtyTwoBits(0xC000008D)
    STATUS_FLOAT_DIVIDE_BY_ZERO = ThirtyTwoBits(0xC000008E)
    STATUS_FLOAT_INEXACT_RESULT = ThirtyTwoBits(0xC000008F)
    STATUS_FLOAT_INVALID_OPERATION = ThirtyTwoBits(0xC0000090)
    STATUS_FLOAT_OVERFLOW = ThirtyTwoBits(0xC0000091)
    STATUS_FLOAT_STACK_CHECK = ThirtyTwoBits(0xC0000092)
    STATUS_FLOAT_UNDERFLOW = ThirtyTwoBits(0xC0000093)
    STATUS_INTEGER_DIVIDE_BY_ZERO = ThirtyTwoBits(0xC0000094)
    STATUS_INTEGER_OVERFLOW = ThirtyTwoBits(0xC0000095)
    STATUS_PRIVILEGED_INSTRUCTION = ThirtyTwoBits(0xC0000096)
    STATUS_TOO_MANY_PAGING_FILES = ThirtyTwoBits(0xC0000097)
    STATUS_FILE_INVALID = ThirtyTwoBits(0xC0000098)
    STATUS_ALLOTTED_SPACE_EXCEEDED = ThirtyTwoBits(0xC0000099)
    STATUS_INSUFFICIENT_RESOURCES = ThirtyTwoBits(0xC000009A)
    STATUS_DFS_EXIT_PATH_FOUND = ThirtyTwoBits(0xC000009B)
    STATUS_DEVICE_DATA_ERROR = ThirtyTwoBits(0xC000009C)
    STATUS_DEVICE_NOT_CONNECTED = ThirtyTwoBits(0xC000009D)
    STATUS_DEVICE_POWER_FAILURE = ThirtyTwoBits(0xC000009E)
    STATUS_FREE_VM_NOT_AT_BASE = ThirtyTwoBits(0xC000009F)
    STATUS_MEMORY_NOT_ALLOCATED = ThirtyTwoBits(0xC00000A0)
    STATUS_WORKING_SET_QUOTA = ThirtyTwoBits(0xC00000A1)
    STATUS_MEDIA_WRITE_PROTECTED = ThirtyTwoBits(0xC00000A2)
    STATUS_DEVICE_NOT_READY = ThirtyTwoBits(0xC00000A3)
    STATUS_INVALID_GROUP_ATTRIBUTES = ThirtyTwoBits(0xC00000A4)
    STATUS_BAD_IMPERSONATION_LEVEL = ThirtyTwoBits(0xC00000A5)
    STATUS_CANT_OPEN_ANONYMOUS = ThirtyTwoBits(0xC00000A6)
    STATUS_BAD_VALIDATION_CLASS = ThirtyTwoBits(0xC00000A7)
    STATUS_BAD_TOKEN_TYPE = ThirtyTwoBits(0xC00000A8)
    STATUS_BAD_MASTER_BOOT_RECORD = ThirtyTwoBits(0xC00000A9)
    STATUS_INSTRUCTION_MISALIGNMENT = ThirtyTwoBits(0xC00000AA)
    STATUS_INSTANCE_NOT_AVAILABLE = ThirtyTwoBits(0xC00000AB)
    STATUS_PIPE_NOT_AVAILABLE = ThirtyTwoBits(0xC00000AC)
    STATUS_INVALID_PIPE_STATE = ThirtyTwoBits(0xC00000AD)
    STATUS_PIPE_BUSY = ThirtyTwoBits(0xC00000AE)
    STATUS_ILLEGAL_FUNCTION = ThirtyTwoBits(0xC00000AF)
    STATUS_PIPE_DISCONNECTED = ThirtyTwoBits(0xC00000B0)
    STATUS_PIPE_CLOSING = ThirtyTwoBits(0xC00000B1)
    STATUS_PIPE_CONNECTED = ThirtyTwoBits(0xC00000B2)
    STATUS_PIPE_LISTENING = ThirtyTwoBits(0xC00000B3)
    STATUS_INVALID_READ_MODE = ThirtyTwoBits(0xC00000B4)
    STATUS_IO_TIMEOUT = ThirtyTwoBits(0xC00000B5)
    STATUS_FILE_FORCED_CLOSED = ThirtyTwoBits(0xC00000B6)
    STATUS_PROFILING_NOT_STARTED = ThirtyTwoBits(0xC00000B7)
    STATUS_PROFILING_NOT_STOPPED = ThirtyTwoBits(0xC00000B8)
    STATUS_COULD_NOT_INTERPRET = ThirtyTwoBits(0xC00000B9)
    STATUS_FILE_IS_A_DIRECTORY = ThirtyTwoBits(0xC00000BA)
    STATUS_NOT_SUPPORTED = ThirtyTwoBits(0xC00000BB)
    STATUS_REMOTE_NOT_LISTENING = ThirtyTwoBits(0xC00000BC)
    STATUS_DUPLICATE_NAME = ThirtyTwoBits(0xC00000BD)
    STATUS_BAD_NETWORK_PATH = ThirtyTwoBits(0xC00000BE)
    STATUS_NETWORK_BUSY = ThirtyTwoBits(0xC00000BF)
    STATUS_DEVICE_DOES_NOT_EXIST = ThirtyTwoBits(0xC00000C0)
    STATUS_TOO_MANY_COMMANDS = ThirtyTwoBits(0xC00000C1)
    STATUS_ADAPTER_HARDWARE_ERROR = ThirtyTwoBits(0xC00000C2)
    STATUS_INVALID_NETWORK_RESPONSE = ThirtyTwoBits(0xC00000C3)
    STATUS_UNEXPECTED_NETWORK_ERROR = ThirtyTwoBits(0xC00000C4)
    STATUS_BAD_REMOTE_ADAPTER = ThirtyTwoBits(0xC00000C5)
    STATUS_PRINT_QUEUE_FULL = ThirtyTwoBits(0xC00000C6)
    STATUS_NO_SPOOL_SPACE = ThirtyTwoBits(0xC00000C7)
    STATUS_PRINT_CANCELLED = ThirtyTwoBits(0xC00000C8)
    STATUS_NETWORK_NAME_DELETED = ThirtyTwoBits(0xC00000C9)
    STATUS_NETWORK_ACCESS_DENIED = ThirtyTwoBits(0xC00000CA)
    STATUS_BAD_DEVICE_TYPE = ThirtyTwoBits(0xC00000CB)
    STATUS_BAD_NETWORK_NAME = ThirtyTwoBits(0xC00000CC)
    STATUS_TOO_MANY_NAMES = ThirtyTwoBits(0xC00000CD)
    STATUS_TOO_MANY_SESSIONS = ThirtyTwoBits(0xC00000CE)
    STATUS_SHARING_PAUSED = ThirtyTwoBits(0xC00000CF)
    STATUS_REQUEST_NOT_ACCEPTED = ThirtyTwoBits(0xC00000D0)
    STATUS_REDIRECTOR_PAUSED = ThirtyTwoBits(0xC00000D1)
    STATUS_NET_WRITE_FAULT = ThirtyTwoBits(0xC00000D2)
    STATUS_PROFILING_AT_LIMIT = ThirtyTwoBits(0xC00000D3)
    STATUS_NOT_SAME_DEVICE = ThirtyTwoBits(0xC00000D4)
    STATUS_FILE_RENAMED = ThirtyTwoBits(0xC00000D5)
    STATUS_VIRTUAL_CIRCUIT_CLOSED = ThirtyTwoBits(0xC00000D6)
    STATUS_NO_SECURITY_ON_OBJECT = ThirtyTwoBits(0xC00000D7)
    STATUS_CANT_WAIT = ThirtyTwoBits(0xC00000D8)
    STATUS_PIPE_EMPTY = ThirtyTwoBits(0xC00000D9)
    STATUS_CANT_ACCESS_DOMAIN_INFO = ThirtyTwoBits(0xC00000DA)
    STATUS_CANT_TERMINATE_SELF = ThirtyTwoBits(0xC00000DB)
    STATUS_INVALID_SERVER_STATE = ThirtyTwoBits(0xC00000DC)
    STATUS_INVALID_DOMAIN_STATE = ThirtyTwoBits(0xC00000DD)
    STATUS_INVALID_DOMAIN_ROLE = ThirtyTwoBits(0xC00000DE)
    STATUS_NO_SUCH_DOMAIN = ThirtyTwoBits(0xC00000DF)
    STATUS_DOMAIN_EXISTS = ThirtyTwoBits(0xC00000E0)
    STATUS_DOMAIN_LIMIT_EXCEEDED = ThirtyTwoBits(0xC00000E1)
    STATUS_OPLOCK_NOT_GRANTED = ThirtyTwoBits(0xC00000E2)
    STATUS_INVALID_OPLOCK_PROTOCOL = ThirtyTwoBits(0xC00000E3)
    STATUS_INTERNAL_DB_CORRUPTION = ThirtyTwoBits(0xC00000E4)
    STATUS_INTERNAL_ERROR = ThirtyTwoBits(0xC00000E5)
    STATUS_GENERIC_NOT_MAPPED = ThirtyTwoBits(0xC00000E6)
    STATUS_BAD_DESCRIPTOR_FORMAT = ThirtyTwoBits(0xC00000E7)
    STATUS_INVALID_USER_BUFFER = ThirtyTwoBits(0xC00000E8)
    STATUS_UNEXPECTED_IO_ERROR = ThirtyTwoBits(0xC00000E9)
    STATUS_UNEXPECTED_MM_CREATE_ERR = ThirtyTwoBits(0xC00000EA)
    STATUS_UNEXPECTED_MM_MAP_ERROR = ThirtyTwoBits(0xC00000EB)
    STATUS_UNEXPECTED_MM_EXTEND_ERR = ThirtyTwoBits(0xC00000EC)
    STATUS_NOT_LOGON_PROCESS = ThirtyTwoBits(0xC00000ED)
    STATUS_LOGON_SESSION_EXISTS = ThirtyTwoBits(0xC00000EE)
    STATUS_INVALID_PARAMETER_1 = ThirtyTwoBits(0xC00000EF)
    STATUS_INVALID_PARAMETER_2 = ThirtyTwoBits(0xC00000F0)
    STATUS_INVALID_PARAMETER_3 = ThirtyTwoBits(0xC00000F1)
    STATUS_INVALID_PARAMETER_4 = ThirtyTwoBits(0xC00000F2)
    STATUS_INVALID_PARAMETER_5 = ThirtyTwoBits(0xC00000F3)
    STATUS_INVALID_PARAMETER_6 = ThirtyTwoBits(0xC00000F4)
    STATUS_INVALID_PARAMETER_7 = ThirtyTwoBits(0xC00000F5)
    STATUS_INVALID_PARAMETER_8 = ThirtyTwoBits(0xC00000F6)
    STATUS_INVALID_PARAMETER_9 = ThirtyTwoBits(0xC00000F7)
    STATUS_INVALID_PARAMETER_10 = ThirtyTwoBits(0xC00000F8)
    STATUS_INVALID_PARAMETER_11 = ThirtyTwoBits(0xC00000F9)
    STATUS_INVALID_PARAMETER_12 = ThirtyTwoBits(0xC00000FA)
    STATUS_REDIRECTOR_NOT_STARTED = ThirtyTwoBits(0xC00000FB)
    STATUS_REDIRECTOR_STARTED = ThirtyTwoBits(0xC00000FC)
    STATUS_STACK_OVERFLOW = ThirtyTwoBits(0xC00000FD)
    STATUS_NO_SUCH_PACKAGE = ThirtyTwoBits(0xC00000FE)
    STATUS_BAD_FUNCTION_TABLE = ThirtyTwoBits(0xC00000FF)
    STATUS_VARIABLE_NOT_FOUND = ThirtyTwoBits(0xC0000100)
    STATUS_DIRECTORY_NOT_EMPTY = ThirtyTwoBits(0xC0000101)
    STATUS_FILE_CORRUPT_ERROR = ThirtyTwoBits(0xC0000102)
    STATUS_NOT_A_DIRECTORY = ThirtyTwoBits(0xC0000103)
    STATUS_BAD_LOGON_SESSION_STATE = ThirtyTwoBits(0xC0000104)
    STATUS_LOGON_SESSION_COLLISION = ThirtyTwoBits(0xC0000105)
    STATUS_NAME_TOO_LONG = ThirtyTwoBits(0xC0000106)
    STATUS_FILES_OPEN = ThirtyTwoBits(0xC0000107)
    STATUS_CONNECTION_IN_USE = ThirtyTwoBits(0xC0000108)
    STATUS_MESSAGE_NOT_FOUND = ThirtyTwoBits(0xC0000109)
    STATUS_PROCESS_IS_TERMINATING = ThirtyTwoBits(0xC000010A)
    STATUS_INVALID_LOGON_TYPE = ThirtyTwoBits(0xC000010B)
    STATUS_NO_GUID_TRANSLATION = ThirtyTwoBits(0xC000010C)
    STATUS_CANNOT_IMPERSONATE = ThirtyTwoBits(0xC000010D)
    STATUS_IMAGE_ALREADY_LOADED = ThirtyTwoBits(0xC000010E)
    STATUS_ABIOS_NOT_PRESENT = ThirtyTwoBits(0xC000010F)
    STATUS_ABIOS_LID_NOT_EXIST = ThirtyTwoBits(0xC0000110)
    STATUS_ABIOS_LID_ALREADY_OWNED = ThirtyTwoBits(0xC0000111)
    STATUS_ABIOS_NOT_LID_OWNER = ThirtyTwoBits(0xC0000112)
    STATUS_ABIOS_INVALID_COMMAND = ThirtyTwoBits(0xC0000113)
    STATUS_ABIOS_INVALID_LID = ThirtyTwoBits(0xC0000114)
    STATUS_ABIOS_SELECTOR_NOT_AVAILABLE = ThirtyTwoBits(0xC0000115)
    STATUS_ABIOS_INVALID_SELECTOR = ThirtyTwoBits(0xC0000116)
    STATUS_NO_LDT = ThirtyTwoBits(0xC0000117)
    STATUS_INVALID_LDT_SIZE = ThirtyTwoBits(0xC0000118)
    STATUS_INVALID_LDT_OFFSET = ThirtyTwoBits(0xC0000119)
    STATUS_INVALID_LDT_DESCRIPTOR = ThirtyTwoBits(0xC000011A)
    STATUS_INVALID_IMAGE_NE_FORMAT = ThirtyTwoBits(0xC000011B)
    STATUS_RXACT_INVALID_STATE = ThirtyTwoBits(0xC000011C)
    STATUS_RXACT_COMMIT_FAILURE = ThirtyTwoBits(0xC000011D)
    STATUS_MAPPED_FILE_SIZE_ZERO = ThirtyTwoBits(0xC000011E)
    STATUS_TOO_MANY_OPENED_FILES = ThirtyTwoBits(0xC000011F)
    STATUS_CANCELLED = ThirtyTwoBits(0xC0000120)
    STATUS_CANNOT_DELETE = ThirtyTwoBits(0xC0000121)
    STATUS_INVALID_COMPUTER_NAME = ThirtyTwoBits(0xC0000122)
    STATUS_FILE_DELETED = ThirtyTwoBits(0xC0000123)
    STATUS_SPECIAL_ACCOUNT = ThirtyTwoBits(0xC0000124)
    STATUS_SPECIAL_GROUP = ThirtyTwoBits(0xC0000125)
    STATUS_SPECIAL_USER = ThirtyTwoBits(0xC0000126)
    STATUS_MEMBERS_PRIMARY_GROUP = ThirtyTwoBits(0xC0000127)
    STATUS_FILE_CLOSED = ThirtyTwoBits(0xC0000128)
    STATUS_TOO_MANY_THREADS = ThirtyTwoBits(0xC0000129)
    STATUS_THREAD_NOT_IN_PROCESS = ThirtyTwoBits(0xC000012A)
    STATUS_TOKEN_ALREADY_IN_USE = ThirtyTwoBits(0xC000012B)
    STATUS_PAGEFILE_QUOTA_EXCEEDED = ThirtyTwoBits(0xC000012C)
    STATUS_COMMITMENT_LIMIT = ThirtyTwoBits(0xC000012D)
    STATUS_INVALID_IMAGE_LE_FORMAT = ThirtyTwoBits(0xC000012E)
    STATUS_INVALID_IMAGE_NOT_MZ = ThirtyTwoBits(0xC000012F)
    STATUS_INVALID_IMAGE_PROTECT = ThirtyTwoBits(0xC0000130)
    STATUS_INVALID_IMAGE_WIN_16 = ThirtyTwoBits(0xC0000131)
    STATUS_LOGON_SERVER_CONFLICT = ThirtyTwoBits(0xC0000132)
    STATUS_TIME_DIFFERENCE_AT_DC = ThirtyTwoBits(0xC0000133)
    STATUS_SYNCHRONIZATION_REQUIRED = ThirtyTwoBits(0xC0000134)
    STATUS_DLL_NOT_FOUND = ThirtyTwoBits(0xC0000135)
    STATUS_OPEN_FAILED = ThirtyTwoBits(0xC0000136)
    STATUS_IO_PRIVILEGE_FAILED = ThirtyTwoBits(0xC0000137)
    STATUS_ORDINAL_NOT_FOUND = ThirtyTwoBits(0xC0000138)
    STATUS_ENTRYPOINT_NOT_FOUND = ThirtyTwoBits(0xC0000139)
    STATUS_CONTROL_C_EXIT = ThirtyTwoBits(0xC000013A)
    STATUS_LOCAL_DISCONNECT = ThirtyTwoBits(0xC000013B)
    STATUS_REMOTE_DISCONNECT = ThirtyTwoBits(0xC000013C)
    STATUS_REMOTE_RESOURCES = ThirtyTwoBits(0xC000013D)
    STATUS_LINK_FAILED = ThirtyTwoBits(0xC000013E)
    STATUS_LINK_TIMEOUT = ThirtyTwoBits(0xC000013F)
    STATUS_INVALID_CONNECTION = ThirtyTwoBits(0xC0000140)
    STATUS_INVALID_ADDRESS = ThirtyTwoBits(0xC0000141)
    STATUS_DLL_INIT_FAILED = ThirtyTwoBits(0xC0000142)
    STATUS_MISSING_SYSTEMFILE = ThirtyTwoBits(0xC0000143)
    STATUS_UNHANDLED_EXCEPTION = ThirtyTwoBits(0xC0000144)
    STATUS_APP_INIT_FAILURE = ThirtyTwoBits(0xC0000145)
    STATUS_PAGEFILE_CREATE_FAILED = ThirtyTwoBits(0xC0000146)
    STATUS_NO_PAGEFILE = ThirtyTwoBits(0xC0000147)
    STATUS_INVALID_LEVEL = ThirtyTwoBits(0xC0000148)
    STATUS_WRONG_PASSWORD_CORE = ThirtyTwoBits(0xC0000149)
    STATUS_ILLEGAL_FLOAT_CONTEXT = ThirtyTwoBits(0xC000014A)
    STATUS_PIPE_BROKEN = ThirtyTwoBits(0xC000014B)
    STATUS_REGISTRY_CORRUPT = ThirtyTwoBits(0xC000014C)
    STATUS_REGISTRY_IO_FAILED = ThirtyTwoBits(0xC000014D)
    STATUS_NO_EVENT_PAIR = ThirtyTwoBits(0xC000014E)
    STATUS_UNRECOGNIZED_VOLUME = ThirtyTwoBits(0xC000014F)
    STATUS_SERIAL_NO_DEVICE_INITED = ThirtyTwoBits(0xC0000150)
    STATUS_NO_SUCH_ALIAS = ThirtyTwoBits(0xC0000151)
    STATUS_MEMBER_NOT_IN_ALIAS = ThirtyTwoBits(0xC0000152)
    STATUS_MEMBER_IN_ALIAS = ThirtyTwoBits(0xC0000153)
    STATUS_ALIAS_EXISTS = ThirtyTwoBits(0xC0000154)
    STATUS_LOGON_NOT_GRANTED = ThirtyTwoBits(0xC0000155)
    STATUS_TOO_MANY_SECRETS = ThirtyTwoBits(0xC0000156)
    STATUS_SECRET_TOO_LONG = ThirtyTwoBits(0xC0000157)
    STATUS_INTERNAL_DB_ERROR = ThirtyTwoBits(0xC0000158)
    STATUS_FULLSCREEN_MODE = ThirtyTwoBits(0xC0000159)
    STATUS_TOO_MANY_CONTEXT_IDS = ThirtyTwoBits(0xC000015A)
    STATUS_LOGON_TYPE_NOT_GRANTED = ThirtyTwoBits(0xC000015B)
    STATUS_NOT_REGISTRY_FILE = ThirtyTwoBits(0xC000015C)
    STATUS_NT_CROSS_ENCRYPTION_REQUIRED = ThirtyTwoBits(0xC000015D)
    STATUS_DOMAIN_CTRLR_CONFIG_ERROR = ThirtyTwoBits(0xC000015E)
    STATUS_FT_MISSING_MEMBER = ThirtyTwoBits(0xC000015F)
    STATUS_ILL_FORMED_SERVICE_ENTRY = ThirtyTwoBits(0xC0000160)
    STATUS_ILLEGAL_CHARACTER = ThirtyTwoBits(0xC0000161)
    STATUS_UNMAPPABLE_CHARACTER = ThirtyTwoBits(0xC0000162)
    STATUS_UNDEFINED_CHARACTER = ThirtyTwoBits(0xC0000163)
    STATUS_FLOPPY_VOLUME = ThirtyTwoBits(0xC0000164)
    STATUS_FLOPPY_ID_MARK_NOT_FOUND = ThirtyTwoBits(0xC0000165)
    STATUS_FLOPPY_WRONG_CYLINDER = ThirtyTwoBits(0xC0000166)
    STATUS_FLOPPY_UNKNOWN_ERROR = ThirtyTwoBits(0xC0000167)
    STATUS_FLOPPY_BAD_REGISTERS = ThirtyTwoBits(0xC0000168)
    STATUS_DISK_RECALIBRATE_FAILED = ThirtyTwoBits(0xC0000169)
    STATUS_DISK_OPERATION_FAILED = ThirtyTwoBits(0xC000016A)
    STATUS_DISK_RESET_FAILED = ThirtyTwoBits(0xC000016B)
    STATUS_SHARED_IRQ_BUSY = ThirtyTwoBits(0xC000016C)
    STATUS_FT_ORPHANING = ThirtyTwoBits(0xC000016D)
    STATUS_BIOS_FAILED_TO_CONNECT_INTERRUPT = ThirtyTwoBits(0xC000016E)
    STATUS_PARTITION_FAILURE = ThirtyTwoBits(0xC0000172)
    STATUS_INVALID_BLOCK_LENGTH = ThirtyTwoBits(0xC0000173)
    STATUS_DEVICE_NOT_PARTITIONED = ThirtyTwoBits(0xC0000174)
    STATUS_UNABLE_TO_LOCK_MEDIA = ThirtyTwoBits(0xC0000175)
    STATUS_UNABLE_TO_UNLOAD_MEDIA = ThirtyTwoBits(0xC0000176)
    STATUS_EOM_OVERFLOW = ThirtyTwoBits(0xC0000177)
    STATUS_NO_MEDIA = ThirtyTwoBits(0xC0000178)
    STATUS_NO_SUCH_MEMBER = ThirtyTwoBits(0xC000017A)
    STATUS_INVALID_MEMBER = ThirtyTwoBits(0xC000017B)
    STATUS_KEY_DELETED = ThirtyTwoBits(0xC000017C)
    STATUS_NO_LOG_SPACE = ThirtyTwoBits(0xC000017D)
    STATUS_TOO_MANY_SIDS = ThirtyTwoBits(0xC000017E)
    STATUS_LM_CROSS_ENCRYPTION_REQUIRED = ThirtyTwoBits(0xC000017F)
    STATUS_KEY_HAS_CHILDREN = ThirtyTwoBits(0xC0000180)
    STATUS_CHILD_MUST_BE_VOLATILE = ThirtyTwoBits(0xC0000181)
    STATUS_DEVICE_CONFIGURATION_ERROR = ThirtyTwoBits(0xC0000182)
    STATUS_DRIVER_INTERNAL_ERROR = ThirtyTwoBits(0xC0000183)
    STATUS_INVALID_DEVICE_STATE = ThirtyTwoBits(0xC0000184)
    STATUS_IO_DEVICE_ERROR = ThirtyTwoBits(0xC0000185)
    STATUS_DEVICE_PROTOCOL_ERROR = ThirtyTwoBits(0xC0000186)
    STATUS_BACKUP_CONTROLLER = ThirtyTwoBits(0xC0000187)
    STATUS_LOG_FILE_FULL = ThirtyTwoBits(0xC0000188)
    STATUS_TOO_LATE = ThirtyTwoBits(0xC0000189)
    STATUS_NO_TRUST_LSA_SECRET = ThirtyTwoBits(0xC000018A)
    STATUS_NO_TRUST_SAM_ACCOUNT = ThirtyTwoBits(0xC000018B)
    STATUS_TRUSTED_DOMAIN_FAILURE = ThirtyTwoBits(0xC000018C)
    STATUS_TRUSTED_RELATIONSHIP_FAILURE = ThirtyTwoBits(0xC000018D)
    STATUS_EVENTLOG_FILE_CORRUPT = ThirtyTwoBits(0xC000018E)
    STATUS_EVENTLOG_CANT_START = ThirtyTwoBits(0xC000018F)
    STATUS_TRUST_FAILURE = ThirtyTwoBits(0xC0000190)
    STATUS_MUTANT_LIMIT_EXCEEDED = ThirtyTwoBits(0xC0000191)
    STATUS_NETLOGON_NOT_STARTED = ThirtyTwoBits(0xC0000192)
    STATUS_ACCOUNT_EXPIRED = ThirtyTwoBits(0xC0000193)
    STATUS_POSSIBLE_DEADLOCK = ThirtyTwoBits(0xC0000194)
    STATUS_NETWORK_CREDENTIAL_CONFLICT = ThirtyTwoBits(0xC0000195)
    STATUS_REMOTE_SESSION_LIMIT = ThirtyTwoBits(0xC0000196)
    STATUS_EVENTLOG_FILE_CHANGED = ThirtyTwoBits(0xC0000197)
    STATUS_NOLOGON_INTERDOMAIN_TRUST_ACCOUNT = ThirtyTwoBits(0xC0000198)
    STATUS_NOLOGON_WORKSTATION_TRUST_ACCOUNT = ThirtyTwoBits(0xC0000199)
    STATUS_NOLOGON_SERVER_TRUST_ACCOUNT = ThirtyTwoBits(0xC000019A)
    STATUS_DOMAIN_TRUST_INCONSISTENT = ThirtyTwoBits(0xC000019B)
    STATUS_FS_DRIVER_REQUIRED = ThirtyTwoBits(0xC000019C)
    STATUS_IMAGE_ALREADY_LOADED_AS_DLL = ThirtyTwoBits(0xC000019D)
    STATUS_INCOMPATIBLE_WITH_GLOBAL_SHORT_NAME_REGISTRY_SETTING = ThirtyTwoBits(0xC000019E)
    STATUS_SHORT_NAMES_NOT_ENABLED_ON_VOLUME = ThirtyTwoBits(0xC000019F)
    STATUS_SECURITY_STREAM_IS_INCONSISTENT = ThirtyTwoBits(0xC00001A0)
    STATUS_INVALID_LOCK_RANGE = ThirtyTwoBits(0xC00001A1)
    STATUS_INVALID_ACE_CONDITION = ThirtyTwoBits(0xC00001A2)
    STATUS_IMAGE_SUBSYSTEM_NOT_PRESENT = ThirtyTwoBits(0xC00001A3)
    STATUS_NOTIFICATION_GUID_ALREADY_DEFINED = ThirtyTwoBits(0xC00001A4)
    STATUS_INVALID_EXCEPTION_HANDLER = ThirtyTwoBits(0xC00001A5)
    STATUS_DUPLICATE_PRIVILEGES = ThirtyTwoBits(0xC00001A6)
    STATUS_NOT_ALLOWED_ON_SYSTEM_FILE = ThirtyTwoBits(0xC00001A7)
    STATUS_REPAIR_NEEDED = ThirtyTwoBits(0xC00001A8)
    STATUS_QUOTA_NOT_ENABLED = ThirtyTwoBits(0xC00001A9)
    STATUS_NO_APPLICATION_PACKAGE = ThirtyTwoBits(0xC00001AA)
    STATUS_FILE_METADATA_OPTIMIZATION_IN_PROGRESS = ThirtyTwoBits(0xC00001AB)
    STATUS_NOT_SAME_OBJECT = ThirtyTwoBits(0xC00001AC)
    STATUS_FATAL_MEMORY_EXHAUSTION = ThirtyTwoBits(0xC00001AD)
    STATUS_ERROR_PROCESS_NOT_IN_JOB = ThirtyTwoBits(0xC00001AE)
    STATUS_CPU_SET_INVALID = ThirtyTwoBits(0xC00001AF)
    STATUS_IO_DEVICE_INVALID_DATA = ThirtyTwoBits(0xC00001B0)
    STATUS_IO_UNALIGNED_WRITE = ThirtyTwoBits(0xC00001B1)
    STATUS_CONTROL_STACK_VIOLATION = ThirtyTwoBits(0xC00001B2)
    STATUS_WEAK_WHFBKEY_BLOCKED = ThirtyTwoBits(0xC00001B3)
    STATUS_SERVER_TRANSPORT_CONFLICT = ThirtyTwoBits(0xC00001B4)
    STATUS_CERTIFICATE_VALIDATION_PREFERENCE_CONFLICT = ThirtyTwoBits(0xC00001B5)
    STATUS_NETWORK_OPEN_RESTRICTION = ThirtyTwoBits(0xC0000201)
    STATUS_NO_USER_SESSION_KEY = ThirtyTwoBits(0xC0000202)
    STATUS_USER_SESSION_DELETED = ThirtyTwoBits(0xC0000203)
    STATUS_RESOURCE_LANG_NOT_FOUND = ThirtyTwoBits(0xC0000204)
    STATUS_INSUFF_SERVER_RESOURCES = ThirtyTwoBits(0xC0000205)
    STATUS_INVALID_BUFFER_SIZE = ThirtyTwoBits(0xC0000206)
    STATUS_INVALID_ADDRESS_COMPONENT = ThirtyTwoBits(0xC0000207)
    STATUS_INVALID_ADDRESS_WILDCARD = ThirtyTwoBits(0xC0000208)
    STATUS_TOO_MANY_ADDRESSES = ThirtyTwoBits(0xC0000209)
    STATUS_ADDRESS_ALREADY_EXISTS = ThirtyTwoBits(0xC000020A)
    STATUS_ADDRESS_CLOSED = ThirtyTwoBits(0xC000020B)
    STATUS_CONNECTION_DISCONNECTED = ThirtyTwoBits(0xC000020C)
    STATUS_CONNECTION_RESET = ThirtyTwoBits(0xC000020D)
    STATUS_TOO_MANY_NODES = ThirtyTwoBits(0xC000020E)
    STATUS_TRANSACTION_ABORTED = ThirtyTwoBits(0xC000020F)
    STATUS_TRANSACTION_TIMED_OUT = ThirtyTwoBits(0xC0000210)
    STATUS_TRANSACTION_NO_RELEASE = ThirtyTwoBits(0xC0000211)
    STATUS_TRANSACTION_NO_MATCH = ThirtyTwoBits(0xC0000212)
    STATUS_TRANSACTION_RESPONDED = ThirtyTwoBits(0xC0000213)
    STATUS_TRANSACTION_INVALID_ID = ThirtyTwoBits(0xC0000214)
    STATUS_TRANSACTION_INVALID_TYPE = ThirtyTwoBits(0xC0000215)
    STATUS_NOT_SERVER_SESSION = ThirtyTwoBits(0xC0000216)
    STATUS_NOT_CLIENT_SESSION = ThirtyTwoBits(0xC0000217)
    STATUS_CANNOT_LOAD_REGISTRY_FILE = ThirtyTwoBits(0xC0000218)
    STATUS_DEBUG_ATTACH_FAILED = ThirtyTwoBits(0xC0000219)
    STATUS_SYSTEM_PROCESS_TERMINATED = ThirtyTwoBits(0xC000021A)
    STATUS_DATA_NOT_ACCEPTED = ThirtyTwoBits(0xC000021B)
    STATUS_NO_BROWSER_SERVERS_FOUND = ThirtyTwoBits(0xC000021C)
    STATUS_VDM_HARD_ERROR = ThirtyTwoBits(0xC000021D)
    STATUS_DRIVER_CANCEL_TIMEOUT = ThirtyTwoBits(0xC000021E)
    STATUS_REPLY_MESSAGE_MISMATCH = ThirtyTwoBits(0xC000021F)
    STATUS_MAPPED_ALIGNMENT = ThirtyTwoBits(0xC0000220)
    STATUS_IMAGE_CHECKSUM_MISMATCH = ThirtyTwoBits(0xC0000221)
    STATUS_LOST_WRITEBEHIND_DATA = ThirtyTwoBits(0xC0000222)
    STATUS_CLIENT_SERVER_PARAMETERS_INVALID = ThirtyTwoBits(0xC0000223)
    STATUS_PASSWORD_MUST_CHANGE = ThirtyTwoBits(0xC0000224)
    STATUS_NOT_FOUND = ThirtyTwoBits(0xC0000225)
    STATUS_NOT_TINY_STREAM = ThirtyTwoBits(0xC0000226)
    STATUS_RECOVERY_FAILURE = ThirtyTwoBits(0xC0000227)
    STATUS_STACK_OVERFLOW_READ = ThirtyTwoBits(0xC0000228)
    STATUS_FAIL_CHECK = ThirtyTwoBits(0xC0000229)
    STATUS_DUPLICATE_OBJECTID = ThirtyTwoBits(0xC000022A)
    STATUS_OBJECTID_EXISTS = ThirtyTwoBits(0xC000022B)
    STATUS_CONVERT_TO_LARGE = ThirtyTwoBits(0xC000022C)
    STATUS_RETRY = ThirtyTwoBits(0xC000022D)
    STATUS_FOUND_OUT_OF_SCOPE = ThirtyTwoBits(0xC000022E)
    STATUS_ALLOCATE_BUCKET = ThirtyTwoBits(0xC000022F)
    STATUS_PROPSET_NOT_FOUND = ThirtyTwoBits(0xC0000230)
    STATUS_MARSHALL_OVERFLOW = ThirtyTwoBits(0xC0000231)
    STATUS_INVALID_VARIANT = ThirtyTwoBits(0xC0000232)
    STATUS_DOMAIN_CONTROLLER_NOT_FOUND = ThirtyTwoBits(0xC0000233)
    STATUS_ACCOUNT_LOCKED_OUT = ThirtyTwoBits(0xC0000234)
    STATUS_HANDLE_NOT_CLOSABLE = ThirtyTwoBits(0xC0000235)
    STATUS_CONNECTION_REFUSED = ThirtyTwoBits(0xC0000236)
    STATUS_GRACEFUL_DISCONNECT = ThirtyTwoBits(0xC0000237)
    STATUS_ADDRESS_ALREADY_ASSOCIATED = ThirtyTwoBits(0xC0000238)
    STATUS_ADDRESS_NOT_ASSOCIATED = ThirtyTwoBits(0xC0000239)
    STATUS_CONNECTION_INVALID = ThirtyTwoBits(0xC000023A)
    STATUS_CONNECTION_ACTIVE = ThirtyTwoBits(0xC000023B)
    STATUS_NETWORK_UNREACHABLE = ThirtyTwoBits(0xC000023C)
    STATUS_HOST_UNREACHABLE = ThirtyTwoBits(0xC000023D)
    STATUS_PROTOCOL_UNREACHABLE = ThirtyTwoBits(0xC000023E)
    STATUS_PORT_UNREACHABLE = ThirtyTwoBits(0xC000023F)
    STATUS_REQUEST_ABORTED = ThirtyTwoBits(0xC0000240)
    STATUS_CONNECTION_ABORTED = ThirtyTwoBits(0xC0000241)
    STATUS_BAD_COMPRESSION_BUFFER = ThirtyTwoBits(0xC0000242)
    STATUS_USER_MAPPED_FILE = ThirtyTwoBits(0xC0000243)
    STATUS_AUDIT_FAILED = ThirtyTwoBits(0xC0000244)
    STATUS_TIMER_RESOLUTION_NOT_SET = ThirtyTwoBits(0xC0000245)
    STATUS_CONNECTION_COUNT_LIMIT = ThirtyTwoBits(0xC0000246)
    STATUS_LOGIN_TIME_RESTRICTION = ThirtyTwoBits(0xC0000247)
    STATUS_LOGIN_WKSTA_RESTRICTION = ThirtyTwoBits(0xC0000248)
    STATUS_IMAGE_MP_UP_MISMATCH = ThirtyTwoBits(0xC0000249)
    STATUS_INSUFFICIENT_LOGON_INFO = ThirtyTwoBits(0xC0000250)
    STATUS_BAD_DLL_ENTRYPOINT = ThirtyTwoBits(0xC0000251)
    STATUS_BAD_SERVICE_ENTRYPOINT = ThirtyTwoBits(0xC0000252)
    STATUS_LPC_REPLY_LOST = ThirtyTwoBits(0xC0000253)
    STATUS_IP_ADDRESS_CONFLICT1 = ThirtyTwoBits(0xC0000254)
    STATUS_IP_ADDRESS_CONFLICT2 = ThirtyTwoBits(0xC0000255)
    STATUS_REGISTRY_QUOTA_LIMIT = ThirtyTwoBits(0xC0000256)
    STATUS_PATH_NOT_COVERED = ThirtyTwoBits(0xC0000257)
    STATUS_NO_CALLBACK_ACTIVE = ThirtyTwoBits(0xC0000258)
    STATUS_LICENSE_QUOTA_EXCEEDED = ThirtyTwoBits(0xC0000259)
    STATUS_PWD_TOO_SHORT = ThirtyTwoBits(0xC000025A)
    STATUS_PWD_TOO_RECENT = ThirtyTwoBits(0xC000025B)
    STATUS_PWD_HISTORY_CONFLICT = ThirtyTwoBits(0xC000025C)
    STATUS_PLUGPLAY_NO_DEVICE = ThirtyTwoBits(0xC000025E)
    STATUS_UNSUPPORTED_COMPRESSION = ThirtyTwoBits(0xC000025F)
    STATUS_INVALID_HW_PROFILE = ThirtyTwoBits(0xC0000260)
    STATUS_INVALID_PLUGPLAY_DEVICE_PATH = ThirtyTwoBits(0xC0000261)
    STATUS_DRIVER_ORDINAL_NOT_FOUND = ThirtyTwoBits(0xC0000262)
    STATUS_DRIVER_ENTRYPOINT_NOT_FOUND = ThirtyTwoBits(0xC0000263)
    STATUS_RESOURCE_NOT_OWNED = ThirtyTwoBits(0xC0000264)
    STATUS_TOO_MANY_LINKS = ThirtyTwoBits(0xC0000265)
    STATUS_QUOTA_LIST_INCONSISTENT = ThirtyTwoBits(0xC0000266)
    STATUS_FILE_IS_OFFLINE = ThirtyTwoBits(0xC0000267)
    STATUS_EVALUATION_EXPIRATION = ThirtyTwoBits(0xC0000268)
    STATUS_ILLEGAL_DLL_RELOCATION = ThirtyTwoBits(0xC0000269)
    STATUS_LICENSE_VIOLATION = ThirtyTwoBits(0xC000026A)
    STATUS_DLL_INIT_FAILED_LOGOFF = ThirtyTwoBits(0xC000026B)
    STATUS_DRIVER_UNABLE_TO_LOAD = ThirtyTwoBits(0xC000026C)
    STATUS_DFS_UNAVAILABLE = ThirtyTwoBits(0xC000026D)
    STATUS_VOLUME_DISMOUNTED = ThirtyTwoBits(0xC000026E)
    STATUS_WX86_INTERNAL_ERROR = ThirtyTwoBits(0xC000026F)
    STATUS_WX86_FLOAT_STACK_CHECK = ThirtyTwoBits(0xC0000270)
    STATUS_VALIDATE_CONTINUE = ThirtyTwoBits(0xC0000271)
    STATUS_NO_MATCH = ThirtyTwoBits(0xC0000272)
    STATUS_NO_MORE_MATCHES = ThirtyTwoBits(0xC0000273)
    STATUS_NOT_A_REPARSE_POINT = ThirtyTwoBits(0xC0000275)
    STATUS_IO_REPARSE_TAG_INVALID = ThirtyTwoBits(0xC0000276)
    STATUS_IO_REPARSE_TAG_MISMATCH = ThirtyTwoBits(0xC0000277)
    STATUS_IO_REPARSE_DATA_INVALID = ThirtyTwoBits(0xC0000278)
    STATUS_IO_REPARSE_TAG_NOT_HANDLED = ThirtyTwoBits(0xC0000279)
    STATUS_PWD_TOO_LONG = ThirtyTwoBits(0xC000027A)
    STATUS_STOWED_EXCEPTION = ThirtyTwoBits(0xC000027B)
    STATUS_CONTEXT_STOWED_EXCEPTION = ThirtyTwoBits(0xC000027C)
    STATUS_REPARSE_POINT_NOT_RESOLVED = ThirtyTwoBits(0xC0000280)
    STATUS_DIRECTORY_IS_A_REPARSE_POINT = ThirtyTwoBits(0xC0000281)
    STATUS_RANGE_LIST_CONFLICT = ThirtyTwoBits(0xC0000282)
    STATUS_SOURCE_ELEMENT_EMPTY = ThirtyTwoBits(0xC0000283)
    STATUS_DESTINATION_ELEMENT_FULL = ThirtyTwoBits(0xC0000284)
    STATUS_ILLEGAL_ELEMENT_ADDRESS = ThirtyTwoBits(0xC0000285)
    STATUS_MAGAZINE_NOT_PRESENT = ThirtyTwoBits(0xC0000286)
    STATUS_REINITIALIZATION_NEEDED = ThirtyTwoBits(0xC0000287)
    STATUS_ENCRYPTION_FAILED = ThirtyTwoBits(0xC000028A)
    STATUS_DECRYPTION_FAILED = ThirtyTwoBits(0xC000028B)
    STATUS_RANGE_NOT_FOUND = ThirtyTwoBits(0xC000028C)
    STATUS_NO_RECOVERY_POLICY = ThirtyTwoBits(0xC000028D)
    STATUS_NO_EFS = ThirtyTwoBits(0xC000028E)
    STATUS_WRONG_EFS = ThirtyTwoBits(0xC000028F)
    STATUS_NO_USER_KEYS = ThirtyTwoBits(0xC0000290)
    STATUS_FILE_NOT_ENCRYPTED = ThirtyTwoBits(0xC0000291)
    STATUS_NOT_EXPORT_FORMAT = ThirtyTwoBits(0xC0000292)
    STATUS_FILE_ENCRYPTED = ThirtyTwoBits(0xC0000293)
    STATUS_WMI_GUID_NOT_FOUND = ThirtyTwoBits(0xC0000295)
    STATUS_WMI_INSTANCE_NOT_FOUND = ThirtyTwoBits(0xC0000296)
    STATUS_WMI_ITEMID_NOT_FOUND = ThirtyTwoBits(0xC0000297)
    STATUS_WMI_TRY_AGAIN = ThirtyTwoBits(0xC0000298)
    STATUS_SHARED_POLICY = ThirtyTwoBits(0xC0000299)
    STATUS_POLICY_OBJECT_NOT_FOUND = ThirtyTwoBits(0xC000029A)
    STATUS_POLICY_ONLY_IN_DS = ThirtyTwoBits(0xC000029B)
    STATUS_VOLUME_NOT_UPGRADED = ThirtyTwoBits(0xC000029C)
    STATUS_REMOTE_STORAGE_NOT_ACTIVE = ThirtyTwoBits(0xC000029D)
    STATUS_REMOTE_STORAGE_MEDIA_ERROR = ThirtyTwoBits(0xC000029E)
    STATUS_NO_TRACKING_SERVICE = ThirtyTwoBits(0xC000029F)
    STATUS_SERVER_SID_MISMATCH = ThirtyTwoBits(0xC00002A0)
    STATUS_DS_NO_ATTRIBUTE_OR_VALUE = ThirtyTwoBits(0xC00002A1)
    STATUS_DS_INVALID_ATTRIBUTE_SYNTAX = ThirtyTwoBits(0xC00002A2)
    STATUS_DS_ATTRIBUTE_TYPE_UNDEFINED = ThirtyTwoBits(0xC00002A3)
    STATUS_DS_ATTRIBUTE_OR_VALUE_EXISTS = ThirtyTwoBits(0xC00002A4)
    STATUS_DS_BUSY = ThirtyTwoBits(0xC00002A5)
    STATUS_DS_UNAVAILABLE = ThirtyTwoBits(0xC00002A6)
    STATUS_DS_NO_RIDS_ALLOCATED = ThirtyTwoBits(0xC00002A7)
    STATUS_DS_NO_MORE_RIDS = ThirtyTwoBits(0xC00002A8)
    STATUS_DS_INCORRECT_ROLE_OWNER = ThirtyTwoBits(0xC00002A9)
    STATUS_DS_RIDMGR_INIT_ERROR = ThirtyTwoBits(0xC00002AA)
    STATUS_DS_OBJ_CLASS_VIOLATION = ThirtyTwoBits(0xC00002AB)
    STATUS_DS_CANT_ON_NON_LEAF = ThirtyTwoBits(0xC00002AC)
    STATUS_DS_CANT_ON_RDN = ThirtyTwoBits(0xC00002AD)
    STATUS_DS_CANT_MOD_OBJ_CLASS = ThirtyTwoBits(0xC00002AE)
    STATUS_DS_CROSS_DOM_MOVE_FAILED = ThirtyTwoBits(0xC00002AF)
    STATUS_DS_GC_NOT_AVAILABLE = ThirtyTwoBits(0xC00002B0)
    STATUS_DIRECTORY_SERVICE_REQUIRED = ThirtyTwoBits(0xC00002B1)
    STATUS_REPARSE_ATTRIBUTE_CONFLICT = ThirtyTwoBits(0xC00002B2)
    STATUS_CANT_ENABLE_DENY_ONLY = ThirtyTwoBits(0xC00002B3)
    STATUS_FLOAT_MULTIPLE_FAULTS = ThirtyTwoBits(0xC00002B4)
    STATUS_FLOAT_MULTIPLE_TRAPS = ThirtyTwoBits(0xC00002B5)
    STATUS_DEVICE_REMOVED = ThirtyTwoBits(0xC00002B6)
    STATUS_JOURNAL_DELETE_IN_PROGRESS = ThirtyTwoBits(0xC00002B7)
    STATUS_JOURNAL_NOT_ACTIVE = ThirtyTwoBits(0xC00002B8)
    STATUS_NOINTERFACE = ThirtyTwoBits(0xC00002B9)
    STATUS_DS_RIDMGR_DISABLED = ThirtyTwoBits(0xC00002BA)
    STATUS_DS_ADMIN_LIMIT_EXCEEDED = ThirtyTwoBits(0xC00002C1)
    STATUS_DRIVER_FAILED_SLEEP = ThirtyTwoBits(0xC00002C2)
    STATUS_MUTUAL_AUTHENTICATION_FAILED = ThirtyTwoBits(0xC00002C3)
    STATUS_CORRUPT_SYSTEM_FILE = ThirtyTwoBits(0xC00002C4)
    STATUS_DATATYPE_MISALIGNMENT_ERROR = ThirtyTwoBits(0xC00002C5)
    STATUS_WMI_READ_ONLY = ThirtyTwoBits(0xC00002C6)
    STATUS_WMI_SET_FAILURE = ThirtyTwoBits(0xC00002C7)
    STATUS_COMMITMENT_MINIMUM = ThirtyTwoBits(0xC00002C8)
    STATUS_REG_NAT_CONSUMPTION = ThirtyTwoBits(0xC00002C9)
    STATUS_TRANSPORT_FULL = ThirtyTwoBits(0xC00002CA)
    STATUS_DS_SAM_INIT_FAILURE = ThirtyTwoBits(0xC00002CB)
    STATUS_ONLY_IF_CONNECTED = ThirtyTwoBits(0xC00002CC)
    STATUS_DS_SENSITIVE_GROUP_VIOLATION = ThirtyTwoBits(0xC00002CD)
    STATUS_PNP_RESTART_ENUMERATION = ThirtyTwoBits(0xC00002CE)
    STATUS_JOURNAL_ENTRY_DELETED = ThirtyTwoBits(0xC00002CF)
    STATUS_DS_CANT_MOD_PRIMARYGROUPID = ThirtyTwoBits(0xC00002D0)
    STATUS_SYSTEM_IMAGE_BAD_SIGNATURE = ThirtyTwoBits(0xC00002D1)
    STATUS_PNP_REBOOT_REQUIRED = ThirtyTwoBits(0xC00002D2)
    STATUS_POWER_STATE_INVALID = ThirtyTwoBits(0xC00002D3)
    STATUS_DS_INVALID_GROUP_TYPE = ThirtyTwoBits(0xC00002D4)
    STATUS_DS_NO_NEST_GLOBALGROUP_IN_MIXEDDOMAIN = ThirtyTwoBits(0xC00002D5)
    STATUS_DS_NO_NEST_LOCALGROUP_IN_MIXEDDOMAIN = ThirtyTwoBits(0xC00002D6)
    STATUS_DS_GLOBAL_CANT_HAVE_LOCAL_MEMBER = ThirtyTwoBits(0xC00002D7)
    STATUS_DS_GLOBAL_CANT_HAVE_UNIVERSAL_MEMBER = ThirtyTwoBits(0xC00002D8)
    STATUS_DS_UNIVERSAL_CANT_HAVE_LOCAL_MEMBER = ThirtyTwoBits(0xC00002D9)
    STATUS_DS_GLOBAL_CANT_HAVE_CROSSDOMAIN_MEMBER = ThirtyTwoBits(0xC00002DA)
    STATUS_DS_LOCAL_CANT_HAVE_CROSSDOMAIN_LOCAL_MEMBER = ThirtyTwoBits(0xC00002DB)
    STATUS_DS_HAVE_PRIMARY_MEMBERS = ThirtyTwoBits(0xC00002DC)
    STATUS_WMI_NOT_SUPPORTED = ThirtyTwoBits(0xC00002DD)
    STATUS_INSUFFICIENT_POWER = ThirtyTwoBits(0xC00002DE)
    STATUS_SAM_NEED_BOOTKEY_PASSWORD = ThirtyTwoBits(0xC00002DF)
    STATUS_SAM_NEED_BOOTKEY_FLOPPY = ThirtyTwoBits(0xC00002E0)
    STATUS_DS_CANT_START = ThirtyTwoBits(0xC00002E1)
    STATUS_DS_INIT_FAILURE = ThirtyTwoBits(0xC00002E2)
    STATUS_SAM_INIT_FAILURE = ThirtyTwoBits(0xC00002E3)
    STATUS_DS_GC_REQUIRED = ThirtyTwoBits(0xC00002E4)
    STATUS_DS_LOCAL_MEMBER_OF_LOCAL_ONLY = ThirtyTwoBits(0xC00002E5)
    STATUS_DS_NO_FPO_IN_UNIVERSAL_GROUPS = ThirtyTwoBits(0xC00002E6)
    STATUS_DS_MACHINE_ACCOUNT_QUOTA_EXCEEDED = ThirtyTwoBits(0xC00002E7)
    STATUS_MULTIPLE_FAULT_VIOLATION = ThirtyTwoBits(0xC00002E8)
    STATUS_CURRENT_DOMAIN_NOT_ALLOWED = ThirtyTwoBits(0xC00002E9)
    STATUS_CANNOT_MAKE = ThirtyTwoBits(0xC00002EA)
    STATUS_SYSTEM_SHUTDOWN = ThirtyTwoBits(0xC00002EB)
    STATUS_DS_INIT_FAILURE_CONSOLE = ThirtyTwoBits(0xC00002EC)
    STATUS_DS_SAM_INIT_FAILURE_CONSOLE = ThirtyTwoBits(0xC00002ED)
    STATUS_UNFINISHED_CONTEXT_DELETED = ThirtyTwoBits(0xC00002EE)
    STATUS_NO_TGT_REPLY = ThirtyTwoBits(0xC00002EF)
    STATUS_OBJECTID_NOT_FOUND = ThirtyTwoBits(0xC00002F0)
    STATUS_NO_IP_ADDRESSES = ThirtyTwoBits(0xC00002F1)
    STATUS_WRONG_CREDENTIAL_HANDLE = ThirtyTwoBits(0xC00002F2)
    STATUS_CRYPTO_SYSTEM_INVALID = ThirtyTwoBits(0xC00002F3)
    STATUS_MAX_REFERRALS_EXCEEDED = ThirtyTwoBits(0xC00002F4)
    STATUS_MUST_BE_KDC = ThirtyTwoBits(0xC00002F5)
    STATUS_STRONG_CRYPTO_NOT_SUPPORTED = ThirtyTwoBits(0xC00002F6)
    STATUS_TOO_MANY_PRINCIPALS = ThirtyTwoBits(0xC00002F7)
    STATUS_NO_PA_DATA = ThirtyTwoBits(0xC00002F8)
    STATUS_PKINIT_NAME_MISMATCH = ThirtyTwoBits(0xC00002F9)
    STATUS_SMARTCARD_LOGON_REQUIRED = ThirtyTwoBits(0xC00002FA)
    STATUS_KDC_INVALID_REQUEST = ThirtyTwoBits(0xC00002FB)
    STATUS_KDC_UNABLE_TO_REFER = ThirtyTwoBits(0xC00002FC)
    STATUS_KDC_UNKNOWN_ETYPE = ThirtyTwoBits(0xC00002FD)
    STATUS_SHUTDOWN_IN_PROGRESS = ThirtyTwoBits(0xC00002FE)
    STATUS_SERVER_SHUTDOWN_IN_PROGRESS = ThirtyTwoBits(0xC00002FF)
    STATUS_NOT_SUPPORTED_ON_SBS = ThirtyTwoBits(0xC0000300)
    STATUS_WMI_GUID_DISCONNECTED = ThirtyTwoBits(0xC0000301)
    STATUS_WMI_ALREADY_DISABLED = ThirtyTwoBits(0xC0000302)
    STATUS_WMI_ALREADY_ENABLED = ThirtyTwoBits(0xC0000303)
    STATUS_MFT_TOO_FRAGMENTED = ThirtyTwoBits(0xC0000304)
    STATUS_COPY_PROTECTION_FAILURE = ThirtyTwoBits(0xC0000305)
    STATUS_CSS_AUTHENTICATION_FAILURE = ThirtyTwoBits(0xC0000306)
    STATUS_CSS_KEY_NOT_PRESENT = ThirtyTwoBits(0xC0000307)
    STATUS_CSS_KEY_NOT_ESTABLISHED = ThirtyTwoBits(0xC0000308)
    STATUS_CSS_SCRAMBLED_SECTOR = ThirtyTwoBits(0xC0000309)
    STATUS_CSS_REGION_MISMATCH = ThirtyTwoBits(0xC000030A)
    STATUS_CSS_RESETS_EXHAUSTED = ThirtyTwoBits(0xC000030B)
    STATUS_PASSWORD_CHANGE_REQUIRED = ThirtyTwoBits(0xC000030C)
    STATUS_LOST_MODE_LOGON_RESTRICTION = ThirtyTwoBits(0xC000030D)
    STATUS_PKINIT_FAILURE = ThirtyTwoBits(0xC0000320)
    STATUS_SMARTCARD_SUBSYSTEM_FAILURE = ThirtyTwoBits(0xC0000321)
    STATUS_NO_KERB_KEY = ThirtyTwoBits(0xC0000322)
    STATUS_HOST_DOWN = ThirtyTwoBits(0xC0000350)
    STATUS_UNSUPPORTED_PREAUTH = ThirtyTwoBits(0xC0000351)
    STATUS_EFS_ALG_BLOB_TOO_BIG = ThirtyTwoBits(0xC0000352)
    STATUS_PORT_NOT_SET = ThirtyTwoBits(0xC0000353)
    STATUS_DEBUGGER_INACTIVE = ThirtyTwoBits(0xC0000354)
    STATUS_DS_VERSION_CHECK_FAILURE = ThirtyTwoBits(0xC0000355)
    STATUS_AUDITING_DISABLED = ThirtyTwoBits(0xC0000356)
    STATUS_PRENT4_MACHINE_ACCOUNT = ThirtyTwoBits(0xC0000357)
    STATUS_DS_AG_CANT_HAVE_UNIVERSAL_MEMBER = ThirtyTwoBits(0xC0000358)
    STATUS_INVALID_IMAGE_WIN_32 = ThirtyTwoBits(0xC0000359)
    STATUS_INVALID_IMAGE_WIN_64 = ThirtyTwoBits(0xC000035A)
    STATUS_BAD_BINDINGS = ThirtyTwoBits(0xC000035B)
    STATUS_NETWORK_SESSION_EXPIRED = ThirtyTwoBits(0xC000035C)
    STATUS_APPHELP_BLOCK = ThirtyTwoBits(0xC000035D)
    STATUS_ALL_SIDS_FILTERED = ThirtyTwoBits(0xC000035E)
    STATUS_NOT_SAFE_MODE_DRIVER = ThirtyTwoBits(0xC000035F)
    STATUS_ACCESS_DISABLED_BY_POLICY_DEFAULT = ThirtyTwoBits(0xC0000361)
    STATUS_ACCESS_DISABLED_BY_POLICY_PATH = ThirtyTwoBits(0xC0000362)
    STATUS_ACCESS_DISABLED_BY_POLICY_PUBLISHER = ThirtyTwoBits(0xC0000363)
    STATUS_ACCESS_DISABLED_BY_POLICY_OTHER = ThirtyTwoBits(0xC0000364)
    STATUS_FAILED_DRIVER_ENTRY = ThirtyTwoBits(0xC0000365)
    STATUS_DEVICE_ENUMERATION_ERROR = ThirtyTwoBits(0xC0000366)
    STATUS_MOUNT_POINT_NOT_RESOLVED = ThirtyTwoBits(0xC0000368)
    STATUS_INVALID_DEVICE_OBJECT_PARAMETER = ThirtyTwoBits(0xC0000369)
    STATUS_MCA_OCCURED = ThirtyTwoBits(0xC000036A)
    STATUS_DRIVER_BLOCKED_CRITICAL = ThirtyTwoBits(0xC000036B)
    STATUS_DRIVER_BLOCKED = ThirtyTwoBits(0xC000036C)
    STATUS_DRIVER_DATABASE_ERROR = ThirtyTwoBits(0xC000036D)
    STATUS_SYSTEM_HIVE_TOO_LARGE = ThirtyTwoBits(0xC000036E)
    STATUS_INVALID_IMPORT_OF_NON_DLL = ThirtyTwoBits(0xC000036F)
    STATUS_NO_SECRETS = ThirtyTwoBits(0xC0000371)
    STATUS_ACCESS_DISABLED_NO_SAFER_UI_BY_POLICY = ThirtyTwoBits(0xC0000372)
    STATUS_FAILED_STACK_SWITCH = ThirtyTwoBits(0xC0000373)
    STATUS_HEAP_CORRUPTION = ThirtyTwoBits(0xC0000374)
    STATUS_SMARTCARD_WRONG_PIN = ThirtyTwoBits(0xC0000380)
    STATUS_SMARTCARD_CARD_BLOCKED = ThirtyTwoBits(0xC0000381)
    STATUS_SMARTCARD_CARD_NOT_AUTHENTICATED = ThirtyTwoBits(0xC0000382)
    STATUS_SMARTCARD_NO_CARD = ThirtyTwoBits(0xC0000383)
    STATUS_SMARTCARD_NO_KEY_CONTAINER = ThirtyTwoBits(0xC0000384)
    STATUS_SMARTCARD_NO_CERTIFICATE = ThirtyTwoBits(0xC0000385)
    STATUS_SMARTCARD_NO_KEYSET = ThirtyTwoBits(0xC0000386)
    STATUS_SMARTCARD_IO_ERROR = ThirtyTwoBits(0xC0000387)
    STATUS_DOWNGRADE_DETECTED = ThirtyTwoBits(0xC0000388)
    STATUS_SMARTCARD_CERT_REVOKED = ThirtyTwoBits(0xC0000389)
    STATUS_ISSUING_CA_UNTRUSTED = ThirtyTwoBits(0xC000038A)
    STATUS_REVOCATION_OFFLINE_C = ThirtyTwoBits(0xC000038B)
    STATUS_PKINIT_CLIENT_FAILURE = ThirtyTwoBits(0xC000038C)
    STATUS_SMARTCARD_CERT_EXPIRED = ThirtyTwoBits(0xC000038D)
    STATUS_DRIVER_FAILED_PRIOR_UNLOAD = ThirtyTwoBits(0xC000038E)
    STATUS_SMARTCARD_SILENT_CONTEXT = ThirtyTwoBits(0xC000038F)
    STATUS_PER_USER_TRUST_QUOTA_EXCEEDED = ThirtyTwoBits(0xC0000401)
    STATUS_ALL_USER_TRUST_QUOTA_EXCEEDED = ThirtyTwoBits(0xC0000402)
    STATUS_USER_DELETE_TRUST_QUOTA_EXCEEDED = ThirtyTwoBits(0xC0000403)
    STATUS_DS_NAME_NOT_UNIQUE = ThirtyTwoBits(0xC0000404)
    STATUS_DS_DUPLICATE_ID_FOUND = ThirtyTwoBits(0xC0000405)
    STATUS_DS_GROUP_CONVERSION_ERROR = ThirtyTwoBits(0xC0000406)
    STATUS_VOLSNAP_PREPARE_HIBERNATE = ThirtyTwoBits(0xC0000407)
    STATUS_USER2USER_REQUIRED = ThirtyTwoBits(0xC0000408)
    STATUS_STACK_BUFFER_OVERRUN = ThirtyTwoBits(0xC0000409)
    STATUS_NO_S4U_PROT_SUPPORT = ThirtyTwoBits(0xC000040A)
    STATUS_CROSSREALM_DELEGATION_FAILURE = ThirtyTwoBits(0xC000040B)
    STATUS_REVOCATION_OFFLINE_KDC = ThirtyTwoBits(0xC000040C)
    STATUS_ISSUING_CA_UNTRUSTED_KDC = ThirtyTwoBits(0xC000040D)
    STATUS_KDC_CERT_EXPIRED = ThirtyTwoBits(0xC000040E)
    STATUS_KDC_CERT_REVOKED = ThirtyTwoBits(0xC000040F)
    STATUS_PARAMETER_QUOTA_EXCEEDED = ThirtyTwoBits(0xC0000410)
    STATUS_HIBERNATION_FAILURE = ThirtyTwoBits(0xC0000411)
    STATUS_DELAY_LOAD_FAILED = ThirtyTwoBits(0xC0000412)
    STATUS_AUTHENTICATION_FIREWALL_FAILED = ThirtyTwoBits(0xC0000413)
    STATUS_VDM_DISALLOWED = ThirtyTwoBits(0xC0000414)
    STATUS_HUNG_DISPLAY_DRIVER_THREAD = ThirtyTwoBits(0xC0000415)
    STATUS_INSUFFICIENT_RESOURCE_FOR_SPECIFIED_SHARED_SECTION_SIZE = ThirtyTwoBits(0xC0000416)
    STATUS_INVALID_CRUNTIME_PARAMETER = ThirtyTwoBits(0xC0000417)
    STATUS_NTLM_BLOCKED = ThirtyTwoBits(0xC0000418)
    STATUS_DS_SRC_SID_EXISTS_IN_FOREST = ThirtyTwoBits(0xC0000419)
    STATUS_DS_DOMAIN_NAME_EXISTS_IN_FOREST = ThirtyTwoBits(0xC000041A)
    STATUS_DS_FLAT_NAME_EXISTS_IN_FOREST = ThirtyTwoBits(0xC000041B)
    STATUS_INVALID_USER_PRINCIPAL_NAME = ThirtyTwoBits(0xC000041C)
    STATUS_FATAL_USER_CALLBACK_EXCEPTION = ThirtyTwoBits(0xC000041D)
    STATUS_ASSERTION_FAILURE = ThirtyTwoBits(0xC0000420)
    STATUS_VERIFIER_STOP = ThirtyTwoBits(0xC0000421)
    STATUS_CALLBACK_POP_STACK = ThirtyTwoBits(0xC0000423)
    STATUS_INCOMPATIBLE_DRIVER_BLOCKED = ThirtyTwoBits(0xC0000424)
    STATUS_HIVE_UNLOADED = ThirtyTwoBits(0xC0000425)
    STATUS_COMPRESSION_DISABLED = ThirtyTwoBits(0xC0000426)
    STATUS_FILE_SYSTEM_LIMITATION = ThirtyTwoBits(0xC0000427)
    STATUS_INVALID_IMAGE_HASH = ThirtyTwoBits(0xC0000428)
    STATUS_NOT_CAPABLE = ThirtyTwoBits(0xC0000429)
    STATUS_REQUEST_OUT_OF_SEQUENCE = ThirtyTwoBits(0xC000042A)
    STATUS_IMPLEMENTATION_LIMIT = ThirtyTwoBits(0xC000042B)
    STATUS_ELEVATION_REQUIRED = ThirtyTwoBits(0xC000042C)
    STATUS_NO_SECURITY_CONTEXT = ThirtyTwoBits(0xC000042D)
    STATUS_PKU2U_CERT_FAILURE = ThirtyTwoBits(0xC000042F)
    STATUS_BEYOND_VDL = ThirtyTwoBits(0xC0000432)
    STATUS_ENCOUNTERED_WRITE_IN_PROGRESS = ThirtyTwoBits(0xC0000433)
    STATUS_PTE_CHANGED = ThirtyTwoBits(0xC0000434)
    STATUS_PURGE_FAILED = ThirtyTwoBits(0xC0000435)
    STATUS_CRED_REQUIRES_CONFIRMATION = ThirtyTwoBits(0xC0000440)
    STATUS_CS_ENCRYPTION_INVALID_SERVER_RESPONSE = ThirtyTwoBits(0xC0000441)
    STATUS_CS_ENCRYPTION_UNSUPPORTED_SERVER = ThirtyTwoBits(0xC0000442)
    STATUS_CS_ENCRYPTION_EXISTING_ENCRYPTED_FILE = ThirtyTwoBits(0xC0000443)
    STATUS_CS_ENCRYPTION_NEW_ENCRYPTED_FILE = ThirtyTwoBits(0xC0000444)
    STATUS_CS_ENCRYPTION_FILE_NOT_CSE = ThirtyTwoBits(0xC0000445)
    STATUS_INVALID_LABEL = ThirtyTwoBits(0xC0000446)
    STATUS_DRIVER_PROCESS_TERMINATED = ThirtyTwoBits(0xC0000450)
    STATUS_AMBIGUOUS_SYSTEM_DEVICE = ThirtyTwoBits(0xC0000451)
    STATUS_SYSTEM_DEVICE_NOT_FOUND = ThirtyTwoBits(0xC0000452)
    STATUS_RESTART_BOOT_APPLICATION = ThirtyTwoBits(0xC0000453)
    STATUS_INSUFFICIENT_NVRAM_RESOURCES = ThirtyTwoBits(0xC0000454)
    STATUS_INVALID_SESSION = ThirtyTwoBits(0xC0000455)
    STATUS_THREAD_ALREADY_IN_SESSION = ThirtyTwoBits(0xC0000456)
    STATUS_THREAD_NOT_IN_SESSION = ThirtyTwoBits(0xC0000457)
    STATUS_INVALID_WEIGHT = ThirtyTwoBits(0xC0000458)
    STATUS_REQUEST_PAUSED = ThirtyTwoBits(0xC0000459)
    STATUS_NO_RANGES_PROCESSED = ThirtyTwoBits(0xC0000460)
    STATUS_DISK_RESOURCES_EXHAUSTED = ThirtyTwoBits(0xC0000461)
    STATUS_NEEDS_REMEDIATION = ThirtyTwoBits(0xC0000462)
    STATUS_DEVICE_FEATURE_NOT_SUPPORTED = ThirtyTwoBits(0xC0000463)
    STATUS_DEVICE_UNREACHABLE = ThirtyTwoBits(0xC0000464)
    STATUS_INVALID_TOKEN = ThirtyTwoBits(0xC0000465)
    STATUS_SERVER_UNAVAILABLE = ThirtyTwoBits(0xC0000466)
    STATUS_FILE_NOT_AVAILABLE = ThirtyTwoBits(0xC0000467)
    STATUS_DEVICE_INSUFFICIENT_RESOURCES = ThirtyTwoBits(0xC0000468)
    STATUS_PACKAGE_UPDATING = ThirtyTwoBits(0xC0000469)
    STATUS_NOT_READ_FROM_COPY = ThirtyTwoBits(0xC000046A)
    STATUS_FT_WRITE_FAILURE = ThirtyTwoBits(0xC000046B)
    STATUS_FT_DI_SCAN_REQUIRED = ThirtyTwoBits(0xC000046C)
    STATUS_OBJECT_NOT_EXTERNALLY_BACKED = ThirtyTwoBits(0xC000046D)
    STATUS_EXTERNAL_BACKING_PROVIDER_UNKNOWN = ThirtyTwoBits(0xC000046E)
    STATUS_COMPRESSION_NOT_BENEFICIAL = ThirtyTwoBits(0xC000046F)
    STATUS_DATA_CHECKSUM_ERROR = ThirtyTwoBits(0xC0000470)
    STATUS_INTERMIXED_KERNEL_EA_OPERATION = ThirtyTwoBits(0xC0000471)
    STATUS_TRIM_READ_ZERO_NOT_SUPPORTED = ThirtyTwoBits(0xC0000472)
    STATUS_TOO_MANY_SEGMENT_DESCRIPTORS = ThirtyTwoBits(0xC0000473)
    STATUS_INVALID_OFFSET_ALIGNMENT = ThirtyTwoBits(0xC0000474)
    STATUS_INVALID_FIELD_IN_PARAMETER_LIST = ThirtyTwoBits(0xC0000475)
    STATUS_OPERATION_IN_PROGRESS = ThirtyTwoBits(0xC0000476)
    STATUS_INVALID_INITIATOR_TARGET_PATH = ThirtyTwoBits(0xC0000477)
    STATUS_SCRUB_DATA_DISABLED = ThirtyTwoBits(0xC0000478)
    STATUS_NOT_REDUNDANT_STORAGE = ThirtyTwoBits(0xC0000479)
    STATUS_RESIDENT_FILE_NOT_SUPPORTED = ThirtyTwoBits(0xC000047A)
    STATUS_COMPRESSED_FILE_NOT_SUPPORTED = ThirtyTwoBits(0xC000047B)
    STATUS_DIRECTORY_NOT_SUPPORTED = ThirtyTwoBits(0xC000047C)
    STATUS_IO_OPERATION_TIMEOUT = ThirtyTwoBits(0xC000047D)
    STATUS_SYSTEM_NEEDS_REMEDIATION = ThirtyTwoBits(0xC000047E)
    STATUS_APPX_INTEGRITY_FAILURE_CLR_NGEN = ThirtyTwoBits(0xC000047F)
    STATUS_SHARE_UNAVAILABLE = ThirtyTwoBits(0xC0000480)
    STATUS_APISET_NOT_HOSTED = ThirtyTwoBits(0xC0000481)
    STATUS_APISET_NOT_PRESENT = ThirtyTwoBits(0xC0000482)
    STATUS_DEVICE_HARDWARE_ERROR = ThirtyTwoBits(0xC0000483)
    STATUS_FIRMWARE_SLOT_INVALID = ThirtyTwoBits(0xC0000484)
    STATUS_FIRMWARE_IMAGE_INVALID = ThirtyTwoBits(0xC0000485)
    STATUS_STORAGE_TOPOLOGY_ID_MISMATCH = ThirtyTwoBits(0xC0000486)
    STATUS_WIM_NOT_BOOTABLE = ThirtyTwoBits(0xC0000487)
    STATUS_BLOCKED_BY_PARENTAL_CONTROLS = ThirtyTwoBits(0xC0000488)
    STATUS_NEEDS_REGISTRATION = ThirtyTwoBits(0xC0000489)
    STATUS_QUOTA_ACTIVITY = ThirtyTwoBits(0xC000048A)
    STATUS_CALLBACK_INVOKE_INLINE = ThirtyTwoBits(0xC000048B)
    STATUS_BLOCK_TOO_MANY_REFERENCES = ThirtyTwoBits(0xC000048C)
    STATUS_MARKED_TO_DISALLOW_WRITES = ThirtyTwoBits(0xC000048D)
    STATUS_NETWORK_ACCESS_DENIED_EDP = ThirtyTwoBits(0xC000048E)
    STATUS_ENCLAVE_FAILURE = ThirtyTwoBits(0xC000048F)
    STATUS_PNP_NO_COMPAT_DRIVERS = ThirtyTwoBits(0xC0000490)
    STATUS_PNP_DRIVER_PACKAGE_NOT_FOUND = ThirtyTwoBits(0xC0000491)
    STATUS_PNP_DRIVER_CONFIGURATION_NOT_FOUND = ThirtyTwoBits(0xC0000492)
    STATUS_PNP_DRIVER_CONFIGURATION_INCOMPLETE = ThirtyTwoBits(0xC0000493)
    STATUS_PNP_FUNCTION_DRIVER_REQUIRED = ThirtyTwoBits(0xC0000494)
    STATUS_PNP_DEVICE_CONFIGURATION_PENDING = ThirtyTwoBits(0xC0000495)
    STATUS_DEVICE_HINT_NAME_BUFFER_TOO_SMALL = ThirtyTwoBits(0xC0000496)
    STATUS_PACKAGE_NOT_AVAILABLE = ThirtyTwoBits(0xC0000497)
    STATUS_DEVICE_IN_MAINTENANCE = ThirtyTwoBits(0xC0000499)
    STATUS_NOT_SUPPORTED_ON_DAX = ThirtyTwoBits(0xC000049A)
    STATUS_FREE_SPACE_TOO_FRAGMENTED = ThirtyTwoBits(0xC000049B)
    STATUS_DAX_MAPPING_EXISTS = ThirtyTwoBits(0xC000049C)
    STATUS_CHILD_PROCESS_BLOCKED = ThirtyTwoBits(0xC000049D)
    STATUS_STORAGE_LOST_DATA_PERSISTENCE = ThirtyTwoBits(0xC000049E)
    STATUS_PARTITION_TERMINATING = ThirtyTwoBits(0xC00004A0)
    STATUS_EXTERNAL_SYSKEY_NOT_SUPPORTED = ThirtyTwoBits(0xC00004A1)
    STATUS_ENCLAVE_VIOLATION = ThirtyTwoBits(0xC00004A2)
    STATUS_FILE_PROTECTED_UNDER_DPL = ThirtyTwoBits(0xC00004A3)
    STATUS_VOLUME_NOT_CLUSTER_ALIGNED = ThirtyTwoBits(0xC00004A4)
    STATUS_NO_PHYSICALLY_ALIGNED_FREE_SPACE_FOUND = ThirtyTwoBits(0xC00004A5)
    STATUS_APPX_FILE_NOT_ENCRYPTED = ThirtyTwoBits(0xC00004A6)
    STATUS_RWRAW_ENCRYPTED_FILE_NOT_ENCRYPTED = ThirtyTwoBits(0xC00004A7)
    STATUS_RWRAW_ENCRYPTED_INVALID_EDATAINFO_FILEOFFSET = ThirtyTwoBits(0xC00004A8)
    STATUS_RWRAW_ENCRYPTED_INVALID_EDATAINFO_FILERANGE = ThirtyTwoBits(0xC00004A9)
    STATUS_RWRAW_ENCRYPTED_INVALID_EDATAINFO_PARAMETER = ThirtyTwoBits(0xC00004AA)
    STATUS_FT_READ_FAILURE = ThirtyTwoBits(0xC00004AB)
    STATUS_PATCH_CONFLICT = ThirtyTwoBits(0xC00004AC)
    STATUS_STORAGE_RESERVE_ID_INVALID = ThirtyTwoBits(0xC00004AD)
    STATUS_STORAGE_RESERVE_DOES_NOT_EXIST = ThirtyTwoBits(0xC00004AE)
    STATUS_STORAGE_RESERVE_ALREADY_EXISTS = ThirtyTwoBits(0xC00004AF)
    STATUS_STORAGE_RESERVE_NOT_EMPTY = ThirtyTwoBits(0xC00004B0)
    STATUS_NOT_A_DAX_VOLUME = ThirtyTwoBits(0xC00004B1)
    STATUS_NOT_DAX_MAPPABLE = ThirtyTwoBits(0xC00004B2)
    STATUS_CASE_DIFFERING_NAMES_IN_DIR = ThirtyTwoBits(0xC00004B3)
    STATUS_FILE_NOT_SUPPORTED = ThirtyTwoBits(0xC00004B4)
    STATUS_NOT_SUPPORTED_WITH_BTT = ThirtyTwoBits(0xC00004B5)
    STATUS_ENCRYPTION_DISABLED = ThirtyTwoBits(0xC00004B6)
    STATUS_ENCRYPTING_METADATA_DISALLOWED = ThirtyTwoBits(0xC00004B7)
    STATUS_CANT_CLEAR_ENCRYPTION_FLAG = ThirtyTwoBits(0xC00004B8)
    STATUS_UNSATISFIED_DEPENDENCIES = ThirtyTwoBits(0xC00004B9)
    STATUS_CASE_SENSITIVE_PATH = ThirtyTwoBits(0xC00004BA)
    STATUS_UNSUPPORTED_PAGING_MODE = ThirtyTwoBits(0xC00004BB)
    STATUS_UNTRUSTED_MOUNT_POINT = ThirtyTwoBits(0xC00004BC)
    STATUS_HAS_SYSTEM_CRITICAL_FILES = ThirtyTwoBits(0xC00004BD)
    STATUS_OBJECT_IS_IMMUTABLE = ThirtyTwoBits(0xC00004BE)
    STATUS_FT_READ_FROM_COPY_FAILURE = ThirtyTwoBits(0xC00004BF)
    STATUS_IMAGE_LOADED_AS_PATCH_IMAGE = ThirtyTwoBits(0xC00004C0)
    STATUS_STORAGE_STACK_ACCESS_DENIED = ThirtyTwoBits(0xC00004C1)
    STATUS_INSUFFICIENT_VIRTUAL_ADDR_RESOURCES = ThirtyTwoBits(0xC00004C2)
    STATUS_ENCRYPTED_FILE_NOT_SUPPORTED = ThirtyTwoBits(0xC00004C3)
    STATUS_SPARSE_FILE_NOT_SUPPORTED = ThirtyTwoBits(0xC00004C4)
    STATUS_PAGEFILE_NOT_SUPPORTED = ThirtyTwoBits(0xC00004C5)
    STATUS_VOLUME_NOT_SUPPORTED = ThirtyTwoBits(0xC00004C6)
    STATUS_NOT_SUPPORTED_WITH_BYPASSIO = ThirtyTwoBits(0xC00004C7)
    STATUS_NO_BYPASSIO_DRIVER_SUPPORT = ThirtyTwoBits(0xC00004C8)
    STATUS_NOT_SUPPORTED_WITH_ENCRYPTION = ThirtyTwoBits(0xC00004C9)
    STATUS_NOT_SUPPORTED_WITH_COMPRESSION = ThirtyTwoBits(0xC00004CA)
    STATUS_NOT_SUPPORTED_WITH_REPLICATION = ThirtyTwoBits(0xC00004CB)
    STATUS_NOT_SUPPORTED_WITH_DEDUPLICATION = ThirtyTwoBits(0xC00004CC)
    STATUS_NOT_SUPPORTED_WITH_AUDITING = ThirtyTwoBits(0xC00004CD)
    STATUS_NOT_SUPPORTED_WITH_MONITORING = ThirtyTwoBits(0xC00004CE)
    STATUS_NOT_SUPPORTED_WITH_SNAPSHOT = ThirtyTwoBits(0xC00004CF)
    STATUS_NOT_SUPPORTED_WITH_VIRTUALIZATION = ThirtyTwoBits(0xC00004D0)
    STATUS_INDEX_OUT_OF_BOUNDS = ThirtyTwoBits(0xC00004D1)
    STATUS_BYPASSIO_FLT_NOT_SUPPORTED = ThirtyTwoBits(0xC00004D2)
    STATUS_VOLUME_WRITE_ACCESS_DENIED = ThirtyTwoBits(0xC00004D3)
    STATUS_PATCH_NOT_REGISTERED = ThirtyTwoBits(0xC00004D4)
    STATUS_NOT_SUPPORTED_WITH_CACHED_HANDLE = ThirtyTwoBits(0xC00004D5)
    STATUS_VOLUME_UPGRADE_NOT_NEEDED = ThirtyTwoBits(0xC00004D9)
    STATUS_VOLUME_UPGRADE_PENDING = ThirtyTwoBits(0xC00004DA)
    STATUS_VOLUME_UPGRADE_DISABLED = ThirtyTwoBits(0xC00004DB)
    STATUS_VOLUME_UPGRADE_DISABLED_TILL_OS_DOWNGRADE_EXPIRED = ThirtyTwoBits(0xC00004DC)
    STATUS_NOT_A_DEV_VOLUME = ThirtyTwoBits(0xC00004DD)
    STATUS_FS_GUID_MISMATCH = ThirtyTwoBits(0xC00004DE)
    STATUS_CANT_ATTACH_TO_DEV_VOLUME = ThirtyTwoBits(0xC00004DF)
    STATUS_INVALID_CONFIG_VALUE = ThirtyTwoBits(0xC00004E0)
    STATUS_INVALID_TASK_NAME = ThirtyTwoBits(0xC0000500)
    STATUS_INVALID_TASK_INDEX = ThirtyTwoBits(0xC0000501)
    STATUS_THREAD_ALREADY_IN_TASK = ThirtyTwoBits(0xC0000502)
    STATUS_CALLBACK_BYPASS = ThirtyTwoBits(0xC0000503)
    STATUS_UNDEFINED_SCOPE = ThirtyTwoBits(0xC0000504)
    STATUS_INVALID_CAP = ThirtyTwoBits(0xC0000505)
    STATUS_NOT_GUI_PROCESS = ThirtyTwoBits(0xC0000506)
    STATUS_DEVICE_HUNG = ThirtyTwoBits(0xC0000507)
    STATUS_CONTAINER_ASSIGNED = ThirtyTwoBits(0xC0000508)
    STATUS_JOB_NO_CONTAINER = ThirtyTwoBits(0xC0000509)
    STATUS_DEVICE_UNRESPONSIVE = ThirtyTwoBits(0xC000050A)
    STATUS_REPARSE_POINT_ENCOUNTERED = ThirtyTwoBits(0xC000050B)
    STATUS_ATTRIBUTE_NOT_PRESENT = ThirtyTwoBits(0xC000050C)
    STATUS_NOT_A_TIERED_VOLUME = ThirtyTwoBits(0xC000050D)
    STATUS_ALREADY_HAS_STREAM_ID = ThirtyTwoBits(0xC000050E)
    STATUS_JOB_NOT_EMPTY = ThirtyTwoBits(0xC000050F)
    STATUS_ALREADY_INITIALIZED = ThirtyTwoBits(0xC0000510)
    STATUS_ENCLAVE_NOT_TERMINATED = ThirtyTwoBits(0xC0000511)
    STATUS_ENCLAVE_IS_TERMINATING = ThirtyTwoBits(0xC0000512)
    STATUS_SMB1_NOT_AVAILABLE = ThirtyTwoBits(0xC0000513)
    STATUS_SMR_GARBAGE_COLLECTION_REQUIRED = ThirtyTwoBits(0xC0000514)
    STATUS_INTERRUPTED = ThirtyTwoBits(0xC0000515)
    STATUS_THREAD_NOT_RUNNING = ThirtyTwoBits(0xC0000516)
    STATUS_SESSION_KEY_TOO_SHORT = ThirtyTwoBits(0xC0000517)
    STATUS_FS_METADATA_INCONSISTENT = ThirtyTwoBits(0xC0000518)
    STATUS_FAIL_FAST_EXCEPTION = ThirtyTwoBits(0xC0000602)
    STATUS_IMAGE_CERT_REVOKED = ThirtyTwoBits(0xC0000603)
    STATUS_DYNAMIC_CODE_BLOCKED = ThirtyTwoBits(0xC0000604)
    STATUS_IMAGE_CERT_EXPIRED = ThirtyTwoBits(0xC0000605)
    STATUS_STRICT_CFG_VIOLATION = ThirtyTwoBits(0xC0000606)
    STATUS_SET_CONTEXT_DENIED = ThirtyTwoBits(0xC000060A)
    STATUS_CROSS_PARTITION_VIOLATION = ThirtyTwoBits(0xC000060B)
    STATUS_PORT_CLOSED = ThirtyTwoBits(0xC0000700)
    STATUS_MESSAGE_LOST = ThirtyTwoBits(0xC0000701)
    STATUS_INVALID_MESSAGE = ThirtyTwoBits(0xC0000702)
    STATUS_REQUEST_CANCELED = ThirtyTwoBits(0xC0000703)
    STATUS_RECURSIVE_DISPATCH = ThirtyTwoBits(0xC0000704)
    STATUS_LPC_RECEIVE_BUFFER_EXPECTED = ThirtyTwoBits(0xC0000705)
    STATUS_LPC_INVALID_CONNECTION_USAGE = ThirtyTwoBits(0xC0000706)
    STATUS_LPC_REQUESTS_NOT_ALLOWED = ThirtyTwoBits(0xC0000707)
    STATUS_RESOURCE_IN_USE = ThirtyTwoBits(0xC0000708)
    STATUS_HARDWARE_MEMORY_ERROR = ThirtyTwoBits(0xC0000709)
    STATUS_THREADPOOL_HANDLE_EXCEPTION = ThirtyTwoBits(0xC000070A)
    STATUS_THREADPOOL_SET_EVENT_ON_COMPLETION_FAILED = ThirtyTwoBits(0xC000070B)
    STATUS_THREADPOOL_RELEASE_SEMAPHORE_ON_COMPLETION_FAILED = ThirtyTwoBits(0xC000070C)
    STATUS_THREADPOOL_RELEASE_MUTEX_ON_COMPLETION_FAILED = ThirtyTwoBits(0xC000070D)
    STATUS_THREADPOOL_FREE_LIBRARY_ON_COMPLETION_FAILED = ThirtyTwoBits(0xC000070E)
    STATUS_THREADPOOL_RELEASED_DURING_OPERATION = ThirtyTwoBits(0xC000070F)
    STATUS_CALLBACK_RETURNED_WHILE_IMPERSONATING = ThirtyTwoBits(0xC0000710)
    STATUS_APC_RETURNED_WHILE_IMPERSONATING = ThirtyTwoBits(0xC0000711)
    STATUS_PROCESS_IS_PROTECTED = ThirtyTwoBits(0xC0000712)
    STATUS_MCA_EXCEPTION = ThirtyTwoBits(0xC0000713)
    STATUS_CERTIFICATE_MAPPING_NOT_UNIQUE = ThirtyTwoBits(0xC0000714)
    STATUS_SYMLINK_CLASS_DISABLED = ThirtyTwoBits(0xC0000715)
    STATUS_INVALID_IDN_NORMALIZATION = ThirtyTwoBits(0xC0000716)
    STATUS_NO_UNICODE_TRANSLATION = ThirtyTwoBits(0xC0000717)
    STATUS_ALREADY_REGISTERED = ThirtyTwoBits(0xC0000718)
    STATUS_CONTEXT_MISMATCH = ThirtyTwoBits(0xC0000719)
    STATUS_PORT_ALREADY_HAS_COMPLETION_LIST = ThirtyTwoBits(0xC000071A)
    STATUS_CALLBACK_RETURNED_THREAD_PRIORITY = ThirtyTwoBits(0xC000071B)
    STATUS_INVALID_THREAD = ThirtyTwoBits(0xC000071C)
    STATUS_CALLBACK_RETURNED_TRANSACTION = ThirtyTwoBits(0xC000071D)
    STATUS_CALLBACK_RETURNED_LDR_LOCK = ThirtyTwoBits(0xC000071E)
    STATUS_CALLBACK_RETURNED_LANG = ThirtyTwoBits(0xC000071F)
    STATUS_CALLBACK_RETURNED_PRI_BACK = ThirtyTwoBits(0xC0000720)
    STATUS_CALLBACK_RETURNED_THREAD_AFFINITY = ThirtyTwoBits(0xC0000721)
    STATUS_LPC_HANDLE_COUNT_EXCEEDED = ThirtyTwoBits(0xC0000722)
    STATUS_EXECUTABLE_MEMORY_WRITE = ThirtyTwoBits(0xC0000723)
    STATUS_KERNEL_EXECUTABLE_MEMORY_WRITE = ThirtyTwoBits(0xC0000724)
    STATUS_ATTACHED_EXECUTABLE_MEMORY_WRITE = ThirtyTwoBits(0xC0000725)
    STATUS_TRIGGERED_EXECUTABLE_MEMORY_WRITE = ThirtyTwoBits(0xC0000726)
    STATUS_DISK_REPAIR_DISABLED = ThirtyTwoBits(0xC0000800)
    STATUS_DS_DOMAIN_RENAME_IN_PROGRESS = ThirtyTwoBits(0xC0000801)
    STATUS_DISK_QUOTA_EXCEEDED = ThirtyTwoBits(0xC0000802)
    STATUS_CONTENT_BLOCKED = ThirtyTwoBits(0xC0000804)
    STATUS_BAD_CLUSTERS = ThirtyTwoBits(0xC0000805)
    STATUS_VOLUME_DIRTY = ThirtyTwoBits(0xC0000806)
    STATUS_DISK_REPAIR_UNSUCCESSFUL = ThirtyTwoBits(0xC0000808)
    STATUS_CORRUPT_LOG_OVERFULL = ThirtyTwoBits(0xC0000809)
    STATUS_CORRUPT_LOG_CORRUPTED = ThirtyTwoBits(0xC000080A)
    STATUS_CORRUPT_LOG_UNAVAILABLE = ThirtyTwoBits(0xC000080B)
    STATUS_CORRUPT_LOG_DELETED_FULL = ThirtyTwoBits(0xC000080C)
    STATUS_CORRUPT_LOG_CLEARED = ThirtyTwoBits(0xC000080D)
    STATUS_ORPHAN_NAME_EXHAUSTED = ThirtyTwoBits(0xC000080E)
    STATUS_PROACTIVE_SCAN_IN_PROGRESS = ThirtyTwoBits(0xC000080F)
    STATUS_ENCRYPTED_IO_NOT_POSSIBLE = ThirtyTwoBits(0xC0000810)
    STATUS_CORRUPT_LOG_UPLEVEL_RECORDS = ThirtyTwoBits(0xC0000811)
    STATUS_FILE_CHECKED_OUT = ThirtyTwoBits(0xC0000901)
    STATUS_CHECKOUT_REQUIRED = ThirtyTwoBits(0xC0000902)
    STATUS_BAD_FILE_TYPE = ThirtyTwoBits(0xC0000903)
    STATUS_FILE_TOO_LARGE = ThirtyTwoBits(0xC0000904)
    STATUS_FORMS_AUTH_REQUIRED = ThirtyTwoBits(0xC0000905)
    STATUS_VIRUS_INFECTED = ThirtyTwoBits(0xC0000906)
    STATUS_VIRUS_DELETED = ThirtyTwoBits(0xC0000907)
    STATUS_BAD_MCFG_TABLE = ThirtyTwoBits(0xC0000908)
    STATUS_CANNOT_BREAK_OPLOCK = ThirtyTwoBits(0xC0000909)
    STATUS_BAD_KEY = ThirtyTwoBits(0xC000090A)
    STATUS_BAD_DATA = ThirtyTwoBits(0xC000090B)
    STATUS_NO_KEY = ThirtyTwoBits(0xC000090C)
    STATUS_FILE_HANDLE_REVOKED = ThirtyTwoBits(0xC0000910)
    STATUS_SECTION_DIRECT_MAP_ONLY = ThirtyTwoBits(0xC0000911)
    STATUS_BLOCK_WEAK_REFERENCE_INVALID = ThirtyTwoBits(0xC0000912)
    STATUS_BLOCK_SOURCE_WEAK_REFERENCE_INVALID = ThirtyTwoBits(0xC0000913)
    STATUS_BLOCK_TARGET_WEAK_REFERENCE_INVALID = ThirtyTwoBits(0xC0000914)
    STATUS_BLOCK_SHARED = ThirtyTwoBits(0xC0000915)
    STATUS_VRF_VOLATILE_CFG_AND_IO_ENABLED = ThirtyTwoBits(0xC0000C08)
    STATUS_VRF_VOLATILE_NOT_STOPPABLE = ThirtyTwoBits(0xC0000C09)
    STATUS_VRF_VOLATILE_SAFE_MODE = ThirtyTwoBits(0xC0000C0A)
    STATUS_VRF_VOLATILE_NOT_RUNNABLE_SYSTEM = ThirtyTwoBits(0xC0000C0B)
    STATUS_VRF_VOLATILE_NOT_SUPPORTED_RULECLASS = ThirtyTwoBits(0xC0000C0C)
    STATUS_VRF_VOLATILE_PROTECTED_DRIVER = ThirtyTwoBits(0xC0000C0D)
    STATUS_VRF_VOLATILE_NMI_REGISTERED = ThirtyTwoBits(0xC0000C0E)
    STATUS_VRF_VOLATILE_SETTINGS_CONFLICT = ThirtyTwoBits(0xC0000C0F)
    STATUS_DIF_IOCALLBACK_NOT_REPLACED = ThirtyTwoBits(0xC0000C76)
    STATUS_DIF_LIVEDUMP_LIMIT_EXCEEDED = ThirtyTwoBits(0xC0000C77)
    STATUS_DIF_VOLATILE_SECTION_NOT_LOCKED = ThirtyTwoBits(0xC0000C78)
    STATUS_DIF_VOLATILE_DRIVER_HOTPATCHED = ThirtyTwoBits(0xC0000C79)
    STATUS_DIF_VOLATILE_INVALID_INFO = ThirtyTwoBits(0xC0000C7A)
    STATUS_DIF_VOLATILE_DRIVER_IS_NOT_RUNNING = ThirtyTwoBits(0xC0000C7B)
    STATUS_DIF_VOLATILE_PLUGIN_IS_NOT_RUNNING = ThirtyTwoBits(0xC0000C7C)
    STATUS_DIF_VOLATILE_PLUGIN_CHANGE_NOT_ALLOWED = ThirtyTwoBits(0xC0000C7D)
    STATUS_DIF_VOLATILE_NOT_ALLOWED = ThirtyTwoBits(0xC0000C7E)
    STATUS_DIF_BINDING_API_NOT_FOUND = ThirtyTwoBits(0xC0000C7F)
    STATUS_WOW_ASSERTION = ThirtyTwoBits(0xC0009898)
    STATUS_INVALID_SIGNATURE = ThirtyTwoBits(0xC000A000)
    STATUS_HMAC_NOT_SUPPORTED = ThirtyTwoBits(0xC000A001)
    STATUS_AUTH_TAG_MISMATCH = ThirtyTwoBits(0xC000A002)
    STATUS_INVALID_STATE_TRANSITION = ThirtyTwoBits(0xC000A003)
    STATUS_INVALID_KERNEL_INFO_VERSION = ThirtyTwoBits(0xC000A004)
    STATUS_INVALID_PEP_INFO_VERSION = ThirtyTwoBits(0xC000A005)
    STATUS_HANDLE_REVOKED = ThirtyTwoBits(0xC000A006)
    STATUS_EOF_ON_GHOSTED_RANGE = ThirtyTwoBits(0xC000A007)
    STATUS_CC_NEEDS_CALLBACK_SECTION_DRAIN = ThirtyTwoBits(0xC000A008)
    STATUS_IPSEC_QUEUE_OVERFLOW = ThirtyTwoBits(0xC000A010)
    STATUS_ND_QUEUE_OVERFLOW = ThirtyTwoBits(0xC000A011)
    STATUS_HOPLIMIT_EXCEEDED = ThirtyTwoBits(0xC000A012)
    STATUS_PROTOCOL_NOT_SUPPORTED = ThirtyTwoBits(0xC000A013)
    STATUS_FASTPATH_REJECTED = ThirtyTwoBits(0xC000A014)
    STATUS_LOST_WRITEBEHIND_DATA_NETWORK_DISCONNECTED = ThirtyTwoBits(0xC000A080)
    STATUS_LOST_WRITEBEHIND_DATA_NETWORK_SERVER_ERROR = ThirtyTwoBits(0xC000A081)
    STATUS_LOST_WRITEBEHIND_DATA_LOCAL_DISK_ERROR = ThirtyTwoBits(0xC000A082)
    STATUS_XML_PARSE_ERROR = ThirtyTwoBits(0xC000A083)
    STATUS_XMLDSIG_ERROR = ThirtyTwoBits(0xC000A084)
    STATUS_WRONG_COMPARTMENT = ThirtyTwoBits(0xC000A085)
    STATUS_AUTHIP_FAILURE = ThirtyTwoBits(0xC000A086)
    STATUS_DS_OID_MAPPED_GROUP_CANT_HAVE_MEMBERS = ThirtyTwoBits(0xC000A087)
    STATUS_DS_OID_NOT_FOUND = ThirtyTwoBits(0xC000A088)
    STATUS_INCORRECT_ACCOUNT_TYPE = ThirtyTwoBits(0xC000A089)
    STATUS_LOCAL_POLICY_MODIFICATION_NOT_SUPPORTED = ThirtyTwoBits(0xC000A08A)
    STATUS_POLICY_CONTROLLED_ACCOUNT = ThirtyTwoBits(0xC000A08B)
    STATUS_LAPS_LEGACY_SCHEMA_MISSING = ThirtyTwoBits(0xC000A08C)
    STATUS_LAPS_SCHEMA_MISSING = ThirtyTwoBits(0xC000A08D)
    STATUS_LAPS_ENCRYPTION_REQUIRES_2016_DFL = ThirtyTwoBits(0xC000A08E)
    STATUS_HASH_NOT_SUPPORTED = ThirtyTwoBits(0xC000A100)
    STATUS_HASH_NOT_PRESENT = ThirtyTwoBits(0xC000A101)
    STATUS_SECONDARY_IC_PROVIDER_NOT_REGISTERED = ThirtyTwoBits(0xC000A121)
    STATUS_GPIO_CLIENT_INFORMATION_INVALID = ThirtyTwoBits(0xC000A122)
    STATUS_GPIO_VERSION_NOT_SUPPORTED = ThirtyTwoBits(0xC000A123)
    STATUS_GPIO_INVALID_REGISTRATION_PACKET = ThirtyTwoBits(0xC000A124)
    STATUS_GPIO_OPERATION_DENIED = ThirtyTwoBits(0xC000A125)
    STATUS_GPIO_INCOMPATIBLE_CONNECT_MODE = ThirtyTwoBits(0xC000A126)
    STATUS_CANNOT_SWITCH_RUNLEVEL = ThirtyTwoBits(0xC000A141)
    STATUS_INVALID_RUNLEVEL_SETTING = ThirtyTwoBits(0xC000A142)
    STATUS_RUNLEVEL_SWITCH_TIMEOUT = ThirtyTwoBits(0xC000A143)
    STATUS_RUNLEVEL_SWITCH_AGENT_TIMEOUT = ThirtyTwoBits(0xC000A145)
    STATUS_RUNLEVEL_SWITCH_IN_PROGRESS = ThirtyTwoBits(0xC000A146)
    STATUS_NOT_APPCONTAINER = ThirtyTwoBits(0xC000A200)
    STATUS_NOT_SUPPORTED_IN_APPCONTAINER = ThirtyTwoBits(0xC000A201)
    STATUS_INVALID_PACKAGE_SID_LENGTH = ThirtyTwoBits(0xC000A202)
    STATUS_LPAC_ACCESS_DENIED = ThirtyTwoBits(0xC000A203)
    STATUS_ADMINLESS_ACCESS_DENIED = ThirtyTwoBits(0xC000A204)
    STATUS_APP_DATA_NOT_FOUND = ThirtyTwoBits(0xC000A281)
    STATUS_APP_DATA_EXPIRED = ThirtyTwoBits(0xC000A282)
    STATUS_APP_DATA_CORRUPT = ThirtyTwoBits(0xC000A283)
    STATUS_APP_DATA_LIMIT_EXCEEDED = ThirtyTwoBits(0xC000A284)
    STATUS_APP_DATA_REBOOT_REQUIRED = ThirtyTwoBits(0xC000A285)
    STATUS_OFFLOAD_READ_FLT_NOT_SUPPORTED = ThirtyTwoBits(0xC000A2A1)
    STATUS_OFFLOAD_WRITE_FLT_NOT_SUPPORTED = ThirtyTwoBits(0xC000A2A2)
    STATUS_OFFLOAD_READ_FILE_NOT_SUPPORTED = ThirtyTwoBits(0xC000A2A3)
    STATUS_OFFLOAD_WRITE_FILE_NOT_SUPPORTED = ThirtyTwoBits(0xC000A2A4)
    STATUS_WOF_WIM_HEADER_CORRUPT = ThirtyTwoBits(0xC000A2A5)
    STATUS_WOF_WIM_RESOURCE_TABLE_CORRUPT = ThirtyTwoBits(0xC000A2A6)
    STATUS_WOF_FILE_RESOURCE_TABLE_CORRUPT = ThirtyTwoBits(0xC000A2A7)
    STATUS_CIMFS_IMAGE_CORRUPT = ThirtyTwoBits(0xC000C001)
    STATUS_CIMFS_IMAGE_VERSION_NOT_SUPPORTED = ThirtyTwoBits(0xC000C002)
    STATUS_FILE_SYSTEM_VIRTUALIZATION_UNAVAILABLE = ThirtyTwoBits(0xC000CE01)
    STATUS_FILE_SYSTEM_VIRTUALIZATION_METADATA_CORRUPT = ThirtyTwoBits(0xC000CE02)
    STATUS_FILE_SYSTEM_VIRTUALIZATION_BUSY = ThirtyTwoBits(0xC000CE03)
    STATUS_FILE_SYSTEM_VIRTUALIZATION_PROVIDER_UNKNOWN = ThirtyTwoBits(0xC000CE04)
    STATUS_FILE_SYSTEM_VIRTUALIZATION_INVALID_OPERATION = ThirtyTwoBits(0xC000CE05)
    STATUS_CLOUD_FILE_SYNC_ROOT_METADATA_CORRUPT = ThirtyTwoBits(0xC000CF00)
    STATUS_CLOUD_FILE_PROVIDER_NOT_RUNNING = ThirtyTwoBits(0xC000CF01)
    STATUS_CLOUD_FILE_METADATA_CORRUPT = ThirtyTwoBits(0xC000CF02)
    STATUS_CLOUD_FILE_METADATA_TOO_LARGE = ThirtyTwoBits(0xC000CF03)
    STATUS_CLOUD_FILE_PROPERTY_VERSION_NOT_SUPPORTED = ThirtyTwoBits(0xC000CF06)
    STATUS_NOT_A_CLOUD_FILE = ThirtyTwoBits(0xC000CF07)
    STATUS_CLOUD_FILE_NOT_IN_SYNC = ThirtyTwoBits(0xC000CF08)
    STATUS_CLOUD_FILE_ALREADY_CONNECTED = ThirtyTwoBits(0xC000CF09)
    STATUS_CLOUD_FILE_NOT_SUPPORTED = ThirtyTwoBits(0xC000CF0A)
    STATUS_CLOUD_FILE_INVALID_REQUEST = ThirtyTwoBits(0xC000CF0B)
    STATUS_CLOUD_FILE_READ_ONLY_VOLUME = ThirtyTwoBits(0xC000CF0C)
    STATUS_CLOUD_FILE_CONNECTED_PROVIDER_ONLY = ThirtyTwoBits(0xC000CF0D)
    STATUS_CLOUD_FILE_VALIDATION_FAILED = ThirtyTwoBits(0xC000CF0E)
    STATUS_CLOUD_FILE_AUTHENTICATION_FAILED = ThirtyTwoBits(0xC000CF0F)
    STATUS_CLOUD_FILE_INSUFFICIENT_RESOURCES = ThirtyTwoBits(0xC000CF10)
    STATUS_CLOUD_FILE_NETWORK_UNAVAILABLE = ThirtyTwoBits(0xC000CF11)
    STATUS_CLOUD_FILE_UNSUCCESSFUL = ThirtyTwoBits(0xC000CF12)
    STATUS_CLOUD_FILE_NOT_UNDER_SYNC_ROOT = ThirtyTwoBits(0xC000CF13)
    STATUS_CLOUD_FILE_IN_USE = ThirtyTwoBits(0xC000CF14)
    STATUS_CLOUD_FILE_PINNED = ThirtyTwoBits(0xC000CF15)
    STATUS_CLOUD_FILE_REQUEST_ABORTED = ThirtyTwoBits(0xC000CF16)
    STATUS_CLOUD_FILE_PROPERTY_CORRUPT = ThirtyTwoBits(0xC000CF17)
    STATUS_CLOUD_FILE_ACCESS_DENIED = ThirtyTwoBits(0xC000CF18)
    STATUS_CLOUD_FILE_INCOMPATIBLE_HARDLINKS = ThirtyTwoBits(0xC000CF19)
    STATUS_CLOUD_FILE_PROPERTY_LOCK_CONFLICT = ThirtyTwoBits(0xC000CF1A)
    STATUS_CLOUD_FILE_REQUEST_CANCELED = ThirtyTwoBits(0xC000CF1B)
    STATUS_CLOUD_FILE_PROVIDER_TERMINATED = ThirtyTwoBits(0xC000CF1D)
    STATUS_NOT_A_CLOUD_SYNC_ROOT = ThirtyTwoBits(0xC000CF1E)
    STATUS_CLOUD_FILE_REQUEST_TIMEOUT = ThirtyTwoBits(0xC000CF1F)
    STATUS_CLOUD_FILE_DEHYDRATION_DISALLOWED = ThirtyTwoBits(0xC000CF20)
    STATUS_CLOUD_FILE_US_MESSAGE_TIMEOUT = ThirtyTwoBits(0xC000CF21)
    STATUS_FILE_SNAP_IN_PROGRESS = ThirtyTwoBits(0xC000F500)
    STATUS_FILE_SNAP_USER_SECTION_NOT_SUPPORTED = ThirtyTwoBits(0xC000F501)
    STATUS_FILE_SNAP_MODIFY_NOT_SUPPORTED = ThirtyTwoBits(0xC000F502)
    STATUS_FILE_SNAP_IO_NOT_COORDINATED = ThirtyTwoBits(0xC000F503)
    STATUS_FILE_SNAP_UNEXPECTED_ERROR = ThirtyTwoBits(0xC000F504)
    STATUS_FILE_SNAP_INVALID_PARAMETER = ThirtyTwoBits(0xC000F505)
    STATUS_PNP_BAD_MPS_TABLE = ThirtyTwoBits(0xC0040035)
    STATUS_PNP_TRANSLATION_FAILED = ThirtyTwoBits(0xC0040036)
    STATUS_PNP_IRQ_TRANSLATION_FAILED = ThirtyTwoBits(0xC0040037)
    STATUS_PNP_INVALID_ID = ThirtyTwoBits(0xC0040038)
    STATUS_IO_REISSUE_AS_CACHED = ThirtyTwoBits(0xC0040039)
    STATUS_CTX_WINSTATION_NAME_INVALID = ThirtyTwoBits(0xC00A0001)
    STATUS_CTX_INVALID_PD = ThirtyTwoBits(0xC00A0002)
    STATUS_CTX_PD_NOT_FOUND = ThirtyTwoBits(0xC00A0003)
    STATUS_CTX_CLOSE_PENDING = ThirtyTwoBits(0xC00A0006)
    STATUS_CTX_NO_OUTBUF = ThirtyTwoBits(0xC00A0007)
    STATUS_CTX_MODEM_INF_NOT_FOUND = ThirtyTwoBits(0xC00A0008)
    STATUS_CTX_INVALID_MODEMNAME = ThirtyTwoBits(0xC00A0009)
    STATUS_CTX_RESPONSE_ERROR = ThirtyTwoBits(0xC00A000A)
    STATUS_CTX_MODEM_RESPONSE_TIMEOUT = ThirtyTwoBits(0xC00A000B)
    STATUS_CTX_MODEM_RESPONSE_NO_CARRIER = ThirtyTwoBits(0xC00A000C)
    STATUS_CTX_MODEM_RESPONSE_NO_DIALTONE = ThirtyTwoBits(0xC00A000D)
    STATUS_CTX_MODEM_RESPONSE_BUSY = ThirtyTwoBits(0xC00A000E)
    STATUS_CTX_MODEM_RESPONSE_VOICE = ThirtyTwoBits(0xC00A000F)
    STATUS_CTX_TD_ERROR = ThirtyTwoBits(0xC00A0010)
    STATUS_CTX_LICENSE_CLIENT_INVALID = ThirtyTwoBits(0xC00A0012)
    STATUS_CTX_LICENSE_NOT_AVAILABLE = ThirtyTwoBits(0xC00A0013)
    STATUS_CTX_LICENSE_EXPIRED = ThirtyTwoBits(0xC00A0014)
    STATUS_CTX_WINSTATION_NOT_FOUND = ThirtyTwoBits(0xC00A0015)
    STATUS_CTX_WINSTATION_NAME_COLLISION = ThirtyTwoBits(0xC00A0016)
    STATUS_CTX_WINSTATION_BUSY = ThirtyTwoBits(0xC00A0017)
    STATUS_CTX_BAD_VIDEO_MODE = ThirtyTwoBits(0xC00A0018)
    STATUS_CTX_GRAPHICS_INVALID = ThirtyTwoBits(0xC00A0022)
    STATUS_CTX_NOT_CONSOLE = ThirtyTwoBits(0xC00A0024)
    STATUS_CTX_CLIENT_QUERY_TIMEOUT = ThirtyTwoBits(0xC00A0026)
    STATUS_CTX_CONSOLE_DISCONNECT = ThirtyTwoBits(0xC00A0027)
    STATUS_CTX_CONSOLE_CONNECT = ThirtyTwoBits(0xC00A0028)
    STATUS_CTX_SHADOW_DENIED = ThirtyTwoBits(0xC00A002A)
    STATUS_CTX_WINSTATION_ACCESS_DENIED = ThirtyTwoBits(0xC00A002B)
    STATUS_CTX_INVALID_WD = ThirtyTwoBits(0xC00A002E)
    STATUS_CTX_WD_NOT_FOUND = ThirtyTwoBits(0xC00A002F)
    STATUS_CTX_SHADOW_INVALID = ThirtyTwoBits(0xC00A0030)
    STATUS_CTX_SHADOW_DISABLED = ThirtyTwoBits(0xC00A0031)
    STATUS_RDP_PROTOCOL_ERROR = ThirtyTwoBits(0xC00A0032)
    STATUS_CTX_CLIENT_LICENSE_NOT_SET = ThirtyTwoBits(0xC00A0033)
    STATUS_CTX_CLIENT_LICENSE_IN_USE = ThirtyTwoBits(0xC00A0034)
    STATUS_CTX_SHADOW_ENDED_BY_MODE_CHANGE = ThirtyTwoBits(0xC00A0035)
    STATUS_CTX_SHADOW_NOT_RUNNING = ThirtyTwoBits(0xC00A0036)
    STATUS_CTX_LOGON_DISABLED = ThirtyTwoBits(0xC00A0037)
    STATUS_CTX_SECURITY_LAYER_ERROR = ThirtyTwoBits(0xC00A0038)
    STATUS_TS_INCOMPATIBLE_SESSIONS = ThirtyTwoBits(0xC00A0039)
    STATUS_TS_VIDEO_SUBSYSTEM_ERROR = ThirtyTwoBits(0xC00A003A)
    STATUS_MUI_FILE_NOT_FOUND = ThirtyTwoBits(0xC00B0001)
    STATUS_MUI_INVALID_FILE = ThirtyTwoBits(0xC00B0002)
    STATUS_MUI_INVALID_RC_CONFIG = ThirtyTwoBits(0xC00B0003)
    STATUS_MUI_INVALID_LOCALE_NAME = ThirtyTwoBits(0xC00B0004)
    STATUS_MUI_INVALID_ULTIMATEFALLBACK_NAME = ThirtyTwoBits(0xC00B0005)
    STATUS_MUI_FILE_NOT_LOADED = ThirtyTwoBits(0xC00B0006)
    STATUS_RESOURCE_ENUM_USER_STOP = ThirtyTwoBits(0xC00B0007)
    STATUS_CLUSTER_INVALID_NODE = ThirtyTwoBits(0xC0130001)
    STATUS_CLUSTER_NODE_EXISTS = ThirtyTwoBits(0xC0130002)
    STATUS_CLUSTER_JOIN_IN_PROGRESS = ThirtyTwoBits(0xC0130003)
    STATUS_CLUSTER_NODE_NOT_FOUND = ThirtyTwoBits(0xC0130004)
    STATUS_CLUSTER_LOCAL_NODE_NOT_FOUND = ThirtyTwoBits(0xC0130005)
    STATUS_CLUSTER_NETWORK_EXISTS = ThirtyTwoBits(0xC0130006)
    STATUS_CLUSTER_NETWORK_NOT_FOUND = ThirtyTwoBits(0xC0130007)
    STATUS_CLUSTER_NETINTERFACE_EXISTS = ThirtyTwoBits(0xC0130008)
    STATUS_CLUSTER_NETINTERFACE_NOT_FOUND = ThirtyTwoBits(0xC0130009)
    STATUS_CLUSTER_INVALID_REQUEST = ThirtyTwoBits(0xC013000A)
    STATUS_CLUSTER_INVALID_NETWORK_PROVIDER = ThirtyTwoBits(0xC013000B)
    STATUS_CLUSTER_NODE_DOWN = ThirtyTwoBits(0xC013000C)
    STATUS_CLUSTER_NODE_UNREACHABLE = ThirtyTwoBits(0xC013000D)
    STATUS_CLUSTER_NODE_NOT_MEMBER = ThirtyTwoBits(0xC013000E)
    STATUS_CLUSTER_JOIN_NOT_IN_PROGRESS = ThirtyTwoBits(0xC013000F)
    STATUS_CLUSTER_INVALID_NETWORK = ThirtyTwoBits(0xC0130010)
    STATUS_CLUSTER_NO_NET_ADAPTERS = ThirtyTwoBits(0xC0130011)
    STATUS_CLUSTER_NODE_UP = ThirtyTwoBits(0xC0130012)
    STATUS_CLUSTER_NODE_PAUSED = ThirtyTwoBits(0xC0130013)
    STATUS_CLUSTER_NODE_NOT_PAUSED = ThirtyTwoBits(0xC0130014)
    STATUS_CLUSTER_NO_SECURITY_CONTEXT = ThirtyTwoBits(0xC0130015)
    STATUS_CLUSTER_NETWORK_NOT_INTERNAL = ThirtyTwoBits(0xC0130016)
    STATUS_CLUSTER_POISONED = ThirtyTwoBits(0xC0130017)
    STATUS_CLUSTER_NON_CSV_PATH = ThirtyTwoBits(0xC0130018)
    STATUS_CLUSTER_CSV_VOLUME_NOT_LOCAL = ThirtyTwoBits(0xC0130019)
    STATUS_CLUSTER_CSV_READ_OPLOCK_BREAK_IN_PROGRESS = ThirtyTwoBits(0xC0130020)
    STATUS_CLUSTER_CSV_AUTO_PAUSE_ERROR = ThirtyTwoBits(0xC0130021)
    STATUS_CLUSTER_CSV_REDIRECTED = ThirtyTwoBits(0xC0130022)
    STATUS_CLUSTER_CSV_NOT_REDIRECTED = ThirtyTwoBits(0xC0130023)
    STATUS_CLUSTER_CSV_VOLUME_DRAINING = ThirtyTwoBits(0xC0130024)
    STATUS_CLUSTER_CSV_SNAPSHOT_CREATION_IN_PROGRESS = ThirtyTwoBits(0xC0130025)
    STATUS_CLUSTER_CSV_VOLUME_DRAINING_SUCCEEDED_DOWNLEVEL = ThirtyTwoBits(0xC0130026)
    STATUS_CLUSTER_CSV_NO_SNAPSHOTS = ThirtyTwoBits(0xC0130027)
    STATUS_CSV_IO_PAUSE_TIMEOUT = ThirtyTwoBits(0xC0130028)
    STATUS_CLUSTER_CSV_INVALID_HANDLE = ThirtyTwoBits(0xC0130029)
    STATUS_CLUSTER_CSV_SUPPORTED_ONLY_ON_COORDINATOR = ThirtyTwoBits(0xC0130030)
    STATUS_CLUSTER_CAM_TICKET_REPLAY_DETECTED = ThirtyTwoBits(0xC0130031)
    STATUS_ACPI_INVALID_OPCODE = ThirtyTwoBits(0xC0140001)
    STATUS_ACPI_STACK_OVERFLOW = ThirtyTwoBits(0xC0140002)
    STATUS_ACPI_ASSERT_FAILED = ThirtyTwoBits(0xC0140003)
    STATUS_ACPI_INVALID_INDEX = ThirtyTwoBits(0xC0140004)
    STATUS_ACPI_INVALID_ARGUMENT = ThirtyTwoBits(0xC0140005)
    STATUS_ACPI_FATAL = ThirtyTwoBits(0xC0140006)
    STATUS_ACPI_INVALID_SUPERNAME = ThirtyTwoBits(0xC0140007)
    STATUS_ACPI_INVALID_ARGTYPE = ThirtyTwoBits(0xC0140008)
    STATUS_ACPI_INVALID_OBJTYPE = ThirtyTwoBits(0xC0140009)
    STATUS_ACPI_INVALID_TARGETTYPE = ThirtyTwoBits(0xC014000A)
    STATUS_ACPI_INCORRECT_ARGUMENT_COUNT = ThirtyTwoBits(0xC014000B)
    STATUS_ACPI_ADDRESS_NOT_MAPPED = ThirtyTwoBits(0xC014000C)
    STATUS_ACPI_INVALID_EVENTTYPE = ThirtyTwoBits(0xC014000D)
    STATUS_ACPI_HANDLER_COLLISION = ThirtyTwoBits(0xC014000E)
    STATUS_ACPI_INVALID_DATA = ThirtyTwoBits(0xC014000F)
    STATUS_ACPI_INVALID_REGION = ThirtyTwoBits(0xC0140010)
    STATUS_ACPI_INVALID_ACCESS_SIZE = ThirtyTwoBits(0xC0140011)
    STATUS_ACPI_ACQUIRE_GLOBAL_LOCK = ThirtyTwoBits(0xC0140012)
    STATUS_ACPI_ALREADY_INITIALIZED = ThirtyTwoBits(0xC0140013)
    STATUS_ACPI_NOT_INITIALIZED = ThirtyTwoBits(0xC0140014)
    STATUS_ACPI_INVALID_MUTEX_LEVEL = ThirtyTwoBits(0xC0140015)
    STATUS_ACPI_MUTEX_NOT_OWNED = ThirtyTwoBits(0xC0140016)
    STATUS_ACPI_MUTEX_NOT_OWNER = ThirtyTwoBits(0xC0140017)
    STATUS_ACPI_RS_ACCESS = ThirtyTwoBits(0xC0140018)
    STATUS_ACPI_INVALID_TABLE = ThirtyTwoBits(0xC0140019)
    STATUS_ACPI_REG_HANDLER_FAILED = ThirtyTwoBits(0xC0140020)
    STATUS_ACPI_POWER_REQUEST_FAILED = ThirtyTwoBits(0xC0140021)
    STATUS_SXS_SECTION_NOT_FOUND = ThirtyTwoBits(0xC0150001)
    STATUS_SXS_CANT_GEN_ACTCTX = ThirtyTwoBits(0xC0150002)
    STATUS_SXS_INVALID_ACTCTXDATA_FORMAT = ThirtyTwoBits(0xC0150003)
    STATUS_SXS_ASSEMBLY_NOT_FOUND = ThirtyTwoBits(0xC0150004)
    STATUS_SXS_MANIFEST_FORMAT_ERROR = ThirtyTwoBits(0xC0150005)
    STATUS_SXS_MANIFEST_PARSE_ERROR = ThirtyTwoBits(0xC0150006)
    STATUS_SXS_ACTIVATION_CONTEXT_DISABLED = ThirtyTwoBits(0xC0150007)
    STATUS_SXS_KEY_NOT_FOUND = ThirtyTwoBits(0xC0150008)
    STATUS_SXS_VERSION_CONFLICT = ThirtyTwoBits(0xC0150009)
    STATUS_SXS_WRONG_SECTION_TYPE = ThirtyTwoBits(0xC015000A)
    STATUS_SXS_THREAD_QUERIES_DISABLED = ThirtyTwoBits(0xC015000B)
    STATUS_SXS_ASSEMBLY_MISSING = ThirtyTwoBits(0xC015000C)
    STATUS_SXS_PROCESS_DEFAULT_ALREADY_SET = ThirtyTwoBits(0xC015000E)
    STATUS_SXS_EARLY_DEACTIVATION = ThirtyTwoBits(0xC015000F)
    STATUS_SXS_INVALID_DEACTIVATION = ThirtyTwoBits(0xC0150010)
    STATUS_SXS_MULTIPLE_DEACTIVATION = ThirtyTwoBits(0xC0150011)
    STATUS_SXS_SYSTEM_DEFAULT_ACTIVATION_CONTEXT_EMPTY = ThirtyTwoBits(0xC0150012)
    STATUS_SXS_PROCESS_TERMINATION_REQUESTED = ThirtyTwoBits(0xC0150013)
    STATUS_SXS_CORRUPT_ACTIVATION_STACK = ThirtyTwoBits(0xC0150014)
    STATUS_SXS_CORRUPTION = ThirtyTwoBits(0xC0150015)
    STATUS_SXS_INVALID_IDENTITY_ATTRIBUTE_VALUE = ThirtyTwoBits(0xC0150016)
    STATUS_SXS_INVALID_IDENTITY_ATTRIBUTE_NAME = ThirtyTwoBits(0xC0150017)
    STATUS_SXS_IDENTITY_DUPLICATE_ATTRIBUTE = ThirtyTwoBits(0xC0150018)
    STATUS_SXS_IDENTITY_PARSE_ERROR = ThirtyTwoBits(0xC0150019)
    STATUS_SXS_COMPONENT_STORE_CORRUPT = ThirtyTwoBits(0xC015001A)
    STATUS_SXS_FILE_HASH_MISMATCH = ThirtyTwoBits(0xC015001B)
    STATUS_SXS_MANIFEST_IDENTITY_SAME_BUT_CONTENTS_DIFFERENT = ThirtyTwoBits(0xC015001C)
    STATUS_SXS_IDENTITIES_DIFFERENT = ThirtyTwoBits(0xC015001D)
    STATUS_SXS_ASSEMBLY_IS_NOT_A_DEPLOYMENT = ThirtyTwoBits(0xC015001E)
    STATUS_SXS_FILE_NOT_PART_OF_ASSEMBLY = ThirtyTwoBits(0xC015001F)
    STATUS_ADVANCED_INSTALLER_FAILED = ThirtyTwoBits(0xC0150020)
    STATUS_XML_ENCODING_MISMATCH = ThirtyTwoBits(0xC0150021)
    STATUS_SXS_MANIFEST_TOO_BIG = ThirtyTwoBits(0xC0150022)
    STATUS_SXS_SETTING_NOT_REGISTERED = ThirtyTwoBits(0xC0150023)
    STATUS_SXS_TRANSACTION_CLOSURE_INCOMPLETE = ThirtyTwoBits(0xC0150024)
    STATUS_SMI_PRIMITIVE_INSTALLER_FAILED = ThirtyTwoBits(0xC0150025)
    STATUS_GENERIC_COMMAND_FAILED = ThirtyTwoBits(0xC0150026)
    STATUS_SXS_FILE_HASH_MISSING = ThirtyTwoBits(0xC0150027)
    STATUS_TRANSACTIONAL_CONFLICT = ThirtyTwoBits(0xC0190001)
    STATUS_INVALID_TRANSACTION = ThirtyTwoBits(0xC0190002)
    STATUS_TRANSACTION_NOT_ACTIVE = ThirtyTwoBits(0xC0190003)
    STATUS_TM_INITIALIZATION_FAILED = ThirtyTwoBits(0xC0190004)
    STATUS_RM_NOT_ACTIVE = ThirtyTwoBits(0xC0190005)
    STATUS_RM_METADATA_CORRUPT = ThirtyTwoBits(0xC0190006)
    STATUS_TRANSACTION_NOT_JOINED = ThirtyTwoBits(0xC0190007)
    STATUS_DIRECTORY_NOT_RM = ThirtyTwoBits(0xC0190008)
    STATUS_TRANSACTIONS_UNSUPPORTED_REMOTE = ThirtyTwoBits(0xC019000A)
    STATUS_LOG_RESIZE_INVALID_SIZE = ThirtyTwoBits(0xC019000B)
    STATUS_REMOTE_FILE_VERSION_MISMATCH = ThirtyTwoBits(0xC019000C)
    STATUS_CRM_PROTOCOL_ALREADY_EXISTS = ThirtyTwoBits(0xC019000F)
    STATUS_TRANSACTION_PROPAGATION_FAILED = ThirtyTwoBits(0xC0190010)
    STATUS_CRM_PROTOCOL_NOT_FOUND = ThirtyTwoBits(0xC0190011)
    STATUS_TRANSACTION_SUPERIOR_EXISTS = ThirtyTwoBits(0xC0190012)
    STATUS_TRANSACTION_REQUEST_NOT_VALID = ThirtyTwoBits(0xC0190013)
    STATUS_TRANSACTION_NOT_REQUESTED = ThirtyTwoBits(0xC0190014)
    STATUS_TRANSACTION_ALREADY_ABORTED = ThirtyTwoBits(0xC0190015)
    STATUS_TRANSACTION_ALREADY_COMMITTED = ThirtyTwoBits(0xC0190016)
    STATUS_TRANSACTION_INVALID_MARSHALL_BUFFER = ThirtyTwoBits(0xC0190017)
    STATUS_CURRENT_TRANSACTION_NOT_VALID = ThirtyTwoBits(0xC0190018)
    STATUS_LOG_GROWTH_FAILED = ThirtyTwoBits(0xC0190019)
    STATUS_OBJECT_NO_LONGER_EXISTS = ThirtyTwoBits(0xC0190021)
    STATUS_STREAM_MINIVERSION_NOT_FOUND = ThirtyTwoBits(0xC0190022)
    STATUS_STREAM_MINIVERSION_NOT_VALID = ThirtyTwoBits(0xC0190023)
    STATUS_MINIVERSION_INACCESSIBLE_FROM_SPECIFIED_TRANSACTION = ThirtyTwoBits(0xC0190024)
    STATUS_CANT_OPEN_MINIVERSION_WITH_MODIFY_INTENT = ThirtyTwoBits(0xC0190025)
    STATUS_CANT_CREATE_MORE_STREAM_MINIVERSIONS = ThirtyTwoBits(0xC0190026)
    STATUS_HANDLE_NO_LONGER_VALID = ThirtyTwoBits(0xC0190028)
    STATUS_LOG_CORRUPTION_DETECTED = ThirtyTwoBits(0xC0190030)
    STATUS_RM_DISCONNECTED = ThirtyTwoBits(0xC0190032)
    STATUS_ENLISTMENT_NOT_SUPERIOR = ThirtyTwoBits(0xC0190033)
    STATUS_FILE_IDENTITY_NOT_PERSISTENT = ThirtyTwoBits(0xC0190036)
    STATUS_CANT_BREAK_TRANSACTIONAL_DEPENDENCY = ThirtyTwoBits(0xC0190037)
    STATUS_CANT_CROSS_RM_BOUNDARY = ThirtyTwoBits(0xC0190038)
    STATUS_TXF_DIR_NOT_EMPTY = ThirtyTwoBits(0xC0190039)
    STATUS_INDOUBT_TRANSACTIONS_EXIST = ThirtyTwoBits(0xC019003A)
    STATUS_TM_VOLATILE = ThirtyTwoBits(0xC019003B)
    STATUS_ROLLBACK_TIMER_EXPIRED = ThirtyTwoBits(0xC019003C)
    STATUS_TXF_ATTRIBUTE_CORRUPT = ThirtyTwoBits(0xC019003D)
    STATUS_EFS_NOT_ALLOWED_IN_TRANSACTION = ThirtyTwoBits(0xC019003E)
    STATUS_TRANSACTIONAL_OPEN_NOT_ALLOWED = ThirtyTwoBits(0xC019003F)
    STATUS_TRANSACTED_MAPPING_UNSUPPORTED_REMOTE = ThirtyTwoBits(0xC0190040)
    STATUS_TRANSACTION_REQUIRED_PROMOTION = ThirtyTwoBits(0xC0190043)
    STATUS_CANNOT_EXECUTE_FILE_IN_TRANSACTION = ThirtyTwoBits(0xC0190044)
    STATUS_TRANSACTIONS_NOT_FROZEN = ThirtyTwoBits(0xC0190045)
    STATUS_TRANSACTION_FREEZE_IN_PROGRESS = ThirtyTwoBits(0xC0190046)
    STATUS_NOT_SNAPSHOT_VOLUME = ThirtyTwoBits(0xC0190047)
    STATUS_NO_SAVEPOINT_WITH_OPEN_FILES = ThirtyTwoBits(0xC0190048)
    STATUS_SPARSE_NOT_ALLOWED_IN_TRANSACTION = ThirtyTwoBits(0xC0190049)
    STATUS_TM_IDENTITY_MISMATCH = ThirtyTwoBits(0xC019004A)
    STATUS_FLOATED_SECTION = ThirtyTwoBits(0xC019004B)
    STATUS_CANNOT_ACCEPT_TRANSACTED_WORK = ThirtyTwoBits(0xC019004C)
    STATUS_CANNOT_ABORT_TRANSACTIONS = ThirtyTwoBits(0xC019004D)
    STATUS_TRANSACTION_NOT_FOUND = ThirtyTwoBits(0xC019004E)
    STATUS_RESOURCEMANAGER_NOT_FOUND = ThirtyTwoBits(0xC019004F)
    STATUS_ENLISTMENT_NOT_FOUND = ThirtyTwoBits(0xC0190050)
    STATUS_TRANSACTIONMANAGER_NOT_FOUND = ThirtyTwoBits(0xC0190051)
    STATUS_TRANSACTIONMANAGER_NOT_ONLINE = ThirtyTwoBits(0xC0190052)
    STATUS_TRANSACTIONMANAGER_RECOVERY_NAME_COLLISION = ThirtyTwoBits(0xC0190053)
    STATUS_TRANSACTION_NOT_ROOT = ThirtyTwoBits(0xC0190054)
    STATUS_TRANSACTION_OBJECT_EXPIRED = ThirtyTwoBits(0xC0190055)
    STATUS_COMPRESSION_NOT_ALLOWED_IN_TRANSACTION = ThirtyTwoBits(0xC0190056)
    STATUS_TRANSACTION_RESPONSE_NOT_ENLISTED = ThirtyTwoBits(0xC0190057)
    STATUS_TRANSACTION_RECORD_TOO_LONG = ThirtyTwoBits(0xC0190058)
    STATUS_NO_LINK_TRACKING_IN_TRANSACTION = ThirtyTwoBits(0xC0190059)
    STATUS_OPERATION_NOT_SUPPORTED_IN_TRANSACTION = ThirtyTwoBits(0xC019005A)
    STATUS_TRANSACTION_INTEGRITY_VIOLATED = ThirtyTwoBits(0xC019005B)
    STATUS_TRANSACTIONMANAGER_IDENTITY_MISMATCH = ThirtyTwoBits(0xC019005C)
    STATUS_RM_CANNOT_BE_FROZEN_FOR_SNAPSHOT = ThirtyTwoBits(0xC019005D)
    STATUS_TRANSACTION_MUST_WRITETHROUGH = ThirtyTwoBits(0xC019005E)
    STATUS_TRANSACTION_NO_SUPERIOR = ThirtyTwoBits(0xC019005F)
    STATUS_EXPIRED_HANDLE = ThirtyTwoBits(0xC0190060)
    STATUS_TRANSACTION_NOT_ENLISTED = ThirtyTwoBits(0xC0190061)
    STATUS_LOG_SECTOR_INVALID = ThirtyTwoBits(0xC01A0001)
    STATUS_LOG_SECTOR_PARITY_INVALID = ThirtyTwoBits(0xC01A0002)
    STATUS_LOG_SECTOR_REMAPPED = ThirtyTwoBits(0xC01A0003)
    STATUS_LOG_BLOCK_INCOMPLETE = ThirtyTwoBits(0xC01A0004)
    STATUS_LOG_INVALID_RANGE = ThirtyTwoBits(0xC01A0005)
    STATUS_LOG_BLOCKS_EXHAUSTED = ThirtyTwoBits(0xC01A0006)
    STATUS_LOG_READ_CONTEXT_INVALID = ThirtyTwoBits(0xC01A0007)
    STATUS_LOG_RESTART_INVALID = ThirtyTwoBits(0xC01A0008)
    STATUS_LOG_BLOCK_VERSION = ThirtyTwoBits(0xC01A0009)
    STATUS_LOG_BLOCK_INVALID = ThirtyTwoBits(0xC01A000A)
    STATUS_LOG_READ_MODE_INVALID = ThirtyTwoBits(0xC01A000B)
    STATUS_LOG_METADATA_CORRUPT = ThirtyTwoBits(0xC01A000D)
    STATUS_LOG_METADATA_INVALID = ThirtyTwoBits(0xC01A000E)
    STATUS_LOG_METADATA_INCONSISTENT = ThirtyTwoBits(0xC01A000F)
    STATUS_LOG_RESERVATION_INVALID = ThirtyTwoBits(0xC01A0010)
    STATUS_LOG_CANT_DELETE = ThirtyTwoBits(0xC01A0011)
    STATUS_LOG_CONTAINER_LIMIT_EXCEEDED = ThirtyTwoBits(0xC01A0012)
    STATUS_LOG_START_OF_LOG = ThirtyTwoBits(0xC01A0013)
    STATUS_LOG_POLICY_ALREADY_INSTALLED = ThirtyTwoBits(0xC01A0014)
    STATUS_LOG_POLICY_NOT_INSTALLED = ThirtyTwoBits(0xC01A0015)
    STATUS_LOG_POLICY_INVALID = ThirtyTwoBits(0xC01A0016)
    STATUS_LOG_POLICY_CONFLICT = ThirtyTwoBits(0xC01A0017)
    STATUS_LOG_PINNED_ARCHIVE_TAIL = ThirtyTwoBits(0xC01A0018)
    STATUS_LOG_RECORD_NONEXISTENT = ThirtyTwoBits(0xC01A0019)
    STATUS_LOG_RECORDS_RESERVED_INVALID = ThirtyTwoBits(0xC01A001A)
    STATUS_LOG_SPACE_RESERVED_INVALID = ThirtyTwoBits(0xC01A001B)
    STATUS_LOG_TAIL_INVALID = ThirtyTwoBits(0xC01A001C)
    STATUS_LOG_FULL = ThirtyTwoBits(0xC01A001D)
    STATUS_LOG_MULTIPLEXED = ThirtyTwoBits(0xC01A001E)
    STATUS_LOG_DEDICATED = ThirtyTwoBits(0xC01A001F)
    STATUS_LOG_ARCHIVE_NOT_IN_PROGRESS = ThirtyTwoBits(0xC01A0020)
    STATUS_LOG_ARCHIVE_IN_PROGRESS = ThirtyTwoBits(0xC01A0021)
    STATUS_LOG_EPHEMERAL = ThirtyTwoBits(0xC01A0022)
    STATUS_LOG_NOT_ENOUGH_CONTAINERS = ThirtyTwoBits(0xC01A0023)
    STATUS_LOG_CLIENT_ALREADY_REGISTERED = ThirtyTwoBits(0xC01A0024)
    STATUS_LOG_CLIENT_NOT_REGISTERED = ThirtyTwoBits(0xC01A0025)
    STATUS_LOG_FULL_HANDLER_IN_PROGRESS = ThirtyTwoBits(0xC01A0026)
    STATUS_LOG_CONTAINER_READ_FAILED = ThirtyTwoBits(0xC01A0027)
    STATUS_LOG_CONTAINER_WRITE_FAILED = ThirtyTwoBits(0xC01A0028)
    STATUS_LOG_CONTAINER_OPEN_FAILED = ThirtyTwoBits(0xC01A0029)
    STATUS_LOG_CONTAINER_STATE_INVALID = ThirtyTwoBits(0xC01A002A)
    STATUS_LOG_STATE_INVALID = ThirtyTwoBits(0xC01A002B)
    STATUS_LOG_PINNED = ThirtyTwoBits(0xC01A002C)
    STATUS_LOG_METADATA_FLUSH_FAILED = ThirtyTwoBits(0xC01A002D)
    STATUS_LOG_INCONSISTENT_SECURITY = ThirtyTwoBits(0xC01A002E)
    STATUS_LOG_APPENDED_FLUSH_FAILED = ThirtyTwoBits(0xC01A002F)
    STATUS_LOG_PINNED_RESERVATION = ThirtyTwoBits(0xC01A0030)
    STATUS_VIDEO_HUNG_DISPLAY_DRIVER_THREAD = ThirtyTwoBits(0xC01B00EA)
    STATUS_FLT_NO_HANDLER_DEFINED = ThirtyTwoBits(0xC01C0001)
    STATUS_FLT_CONTEXT_ALREADY_DEFINED = ThirtyTwoBits(0xC01C0002)
    STATUS_FLT_INVALID_ASYNCHRONOUS_REQUEST = ThirtyTwoBits(0xC01C0003)
    STATUS_FLT_DISALLOW_FAST_IO = ThirtyTwoBits(0xC01C0004)
    STATUS_FLT_INVALID_NAME_REQUEST = ThirtyTwoBits(0xC01C0005)
    STATUS_FLT_NOT_SAFE_TO_POST_OPERATION = ThirtyTwoBits(0xC01C0006)
    STATUS_FLT_NOT_INITIALIZED = ThirtyTwoBits(0xC01C0007)
    STATUS_FLT_FILTER_NOT_READY = ThirtyTwoBits(0xC01C0008)
    STATUS_FLT_POST_OPERATION_CLEANUP = ThirtyTwoBits(0xC01C0009)
    STATUS_FLT_INTERNAL_ERROR = ThirtyTwoBits(0xC01C000A)
    STATUS_FLT_DELETING_OBJECT = ThirtyTwoBits(0xC01C000B)
    STATUS_FLT_MUST_BE_NONPAGED_POOL = ThirtyTwoBits(0xC01C000C)
    STATUS_FLT_DUPLICATE_ENTRY = ThirtyTwoBits(0xC01C000D)
    STATUS_FLT_CBDQ_DISABLED = ThirtyTwoBits(0xC01C000E)
    STATUS_FLT_DO_NOT_ATTACH = ThirtyTwoBits(0xC01C000F)
    STATUS_FLT_DO_NOT_DETACH = ThirtyTwoBits(0xC01C0010)
    STATUS_FLT_INSTANCE_ALTITUDE_COLLISION = ThirtyTwoBits(0xC01C0011)
    STATUS_FLT_INSTANCE_NAME_COLLISION = ThirtyTwoBits(0xC01C0012)
    STATUS_FLT_FILTER_NOT_FOUND = ThirtyTwoBits(0xC01C0013)
    STATUS_FLT_VOLUME_NOT_FOUND = ThirtyTwoBits(0xC01C0014)
    STATUS_FLT_INSTANCE_NOT_FOUND = ThirtyTwoBits(0xC01C0015)
    STATUS_FLT_CONTEXT_ALLOCATION_NOT_FOUND = ThirtyTwoBits(0xC01C0016)
    STATUS_FLT_INVALID_CONTEXT_REGISTRATION = ThirtyTwoBits(0xC01C0017)
    STATUS_FLT_NAME_CACHE_MISS = ThirtyTwoBits(0xC01C0018)
    STATUS_FLT_NO_DEVICE_OBJECT = ThirtyTwoBits(0xC01C0019)
    STATUS_FLT_VOLUME_ALREADY_MOUNTED = ThirtyTwoBits(0xC01C001A)
    STATUS_FLT_ALREADY_ENLISTED = ThirtyTwoBits(0xC01C001B)
    STATUS_FLT_CONTEXT_ALREADY_LINKED = ThirtyTwoBits(0xC01C001C)
    STATUS_FLT_NO_WAITER_FOR_REPLY = ThirtyTwoBits(0xC01C0020)
    STATUS_FLT_REGISTRATION_BUSY = ThirtyTwoBits(0xC01C0023)
    STATUS_FLT_WCOS_NOT_SUPPORTED = ThirtyTwoBits(0xC01C0024)
    STATUS_MONITOR_NO_DESCRIPTOR = ThirtyTwoBits(0xC01D0001)
    STATUS_MONITOR_UNKNOWN_DESCRIPTOR_FORMAT = ThirtyTwoBits(0xC01D0002)
    STATUS_MONITOR_INVALID_DESCRIPTOR_CHECKSUM = ThirtyTwoBits(0xC01D0003)
    STATUS_MONITOR_INVALID_STANDARD_TIMING_BLOCK = ThirtyTwoBits(0xC01D0004)
    STATUS_MONITOR_WMI_DATABLOCK_REGISTRATION_FAILED = ThirtyTwoBits(0xC01D0005)
    STATUS_MONITOR_INVALID_SERIAL_NUMBER_MONDSC_BLOCK = ThirtyTwoBits(0xC01D0006)
    STATUS_MONITOR_INVALID_USER_FRIENDLY_MONDSC_BLOCK = ThirtyTwoBits(0xC01D0007)
    STATUS_MONITOR_NO_MORE_DESCRIPTOR_DATA = ThirtyTwoBits(0xC01D0008)
    STATUS_MONITOR_INVALID_DETAILED_TIMING_BLOCK = ThirtyTwoBits(0xC01D0009)
    STATUS_MONITOR_INVALID_MANUFACTURE_DATE = ThirtyTwoBits(0xC01D000A)
    STATUS_GRAPHICS_NOT_EXCLUSIVE_MODE_OWNER = ThirtyTwoBits(0xC01E0000)
    STATUS_GRAPHICS_INSUFFICIENT_DMA_BUFFER = ThirtyTwoBits(0xC01E0001)
    STATUS_GRAPHICS_INVALID_DISPLAY_ADAPTER = ThirtyTwoBits(0xC01E0002)
    STATUS_GRAPHICS_ADAPTER_WAS_RESET = ThirtyTwoBits(0xC01E0003)
    STATUS_GRAPHICS_INVALID_DRIVER_MODEL = ThirtyTwoBits(0xC01E0004)
    STATUS_GRAPHICS_PRESENT_MODE_CHANGED = ThirtyTwoBits(0xC01E0005)
    STATUS_GRAPHICS_PRESENT_OCCLUDED = ThirtyTwoBits(0xC01E0006)
    STATUS_GRAPHICS_PRESENT_DENIED = ThirtyTwoBits(0xC01E0007)
    STATUS_GRAPHICS_CANNOTCOLORCONVERT = ThirtyTwoBits(0xC01E0008)
    STATUS_GRAPHICS_DRIVER_MISMATCH = ThirtyTwoBits(0xC01E0009)
    STATUS_GRAPHICS_PRESENT_REDIRECTION_DISABLED = ThirtyTwoBits(0xC01E000B)
    STATUS_GRAPHICS_PRESENT_UNOCCLUDED = ThirtyTwoBits(0xC01E000C)
    STATUS_GRAPHICS_WINDOWDC_NOT_AVAILABLE = ThirtyTwoBits(0xC01E000D)
    STATUS_GRAPHICS_WINDOWLESS_PRESENT_DISABLED = ThirtyTwoBits(0xC01E000E)
    STATUS_GRAPHICS_PRESENT_INVALID_WINDOW = ThirtyTwoBits(0xC01E000F)
    STATUS_GRAPHICS_PRESENT_BUFFER_NOT_BOUND = ThirtyTwoBits(0xC01E0010)
    STATUS_GRAPHICS_VAIL_STATE_CHANGED = ThirtyTwoBits(0xC01E0011)
    STATUS_GRAPHICS_INDIRECT_DISPLAY_ABANDON_SWAPCHAIN = ThirtyTwoBits(0xC01E0012)
    STATUS_GRAPHICS_INDIRECT_DISPLAY_DEVICE_STOPPED = ThirtyTwoBits(0xC01E0013)
    STATUS_GRAPHICS_MPO_ALLOCATION_UNPINNED = ThirtyTwoBits(0xC01E0018)
    STATUS_GRAPHICS_NO_VIDEO_MEMORY = ThirtyTwoBits(0xC01E0100)
    STATUS_GRAPHICS_CANT_LOCK_MEMORY = ThirtyTwoBits(0xC01E0101)
    STATUS_GRAPHICS_ALLOCATION_BUSY = ThirtyTwoBits(0xC01E0102)
    STATUS_GRAPHICS_TOO_MANY_REFERENCES = ThirtyTwoBits(0xC01E0103)
    STATUS_GRAPHICS_TRY_AGAIN_LATER = ThirtyTwoBits(0xC01E0104)
    STATUS_GRAPHICS_TRY_AGAIN_NOW = ThirtyTwoBits(0xC01E0105)
    STATUS_GRAPHICS_ALLOCATION_INVALID = ThirtyTwoBits(0xC01E0106)
    STATUS_GRAPHICS_UNSWIZZLING_APERTURE_UNAVAILABLE = ThirtyTwoBits(0xC01E0107)
    STATUS_GRAPHICS_UNSWIZZLING_APERTURE_UNSUPPORTED = ThirtyTwoBits(0xC01E0108)
    STATUS_GRAPHICS_CANT_EVICT_PINNED_ALLOCATION = ThirtyTwoBits(0xC01E0109)
    STATUS_GRAPHICS_INVALID_ALLOCATION_USAGE = ThirtyTwoBits(0xC01E0110)
    STATUS_GRAPHICS_CANT_RENDER_LOCKED_ALLOCATION = ThirtyTwoBits(0xC01E0111)
    STATUS_GRAPHICS_ALLOCATION_CLOSED = ThirtyTwoBits(0xC01E0112)
    STATUS_GRAPHICS_INVALID_ALLOCATION_INSTANCE = ThirtyTwoBits(0xC01E0113)
    STATUS_GRAPHICS_INVALID_ALLOCATION_HANDLE = ThirtyTwoBits(0xC01E0114)
    STATUS_GRAPHICS_WRONG_ALLOCATION_DEVICE = ThirtyTwoBits(0xC01E0115)
    STATUS_GRAPHICS_ALLOCATION_CONTENT_LOST = ThirtyTwoBits(0xC01E0116)
    STATUS_GRAPHICS_GPU_EXCEPTION_ON_DEVICE = ThirtyTwoBits(0xC01E0200)
    STATUS_GRAPHICS_INVALID_VIDPN_TOPOLOGY = ThirtyTwoBits(0xC01E0300)
    STATUS_GRAPHICS_VIDPN_TOPOLOGY_NOT_SUPPORTED = ThirtyTwoBits(0xC01E0301)
    STATUS_GRAPHICS_VIDPN_TOPOLOGY_CURRENTLY_NOT_SUPPORTED = ThirtyTwoBits(0xC01E0302)
    STATUS_GRAPHICS_INVALID_VIDPN = ThirtyTwoBits(0xC01E0303)
    STATUS_GRAPHICS_INVALID_VIDEO_PRESENT_SOURCE = ThirtyTwoBits(0xC01E0304)
    STATUS_GRAPHICS_INVALID_VIDEO_PRESENT_TARGET = ThirtyTwoBits(0xC01E0305)
    STATUS_GRAPHICS_VIDPN_MODALITY_NOT_SUPPORTED = ThirtyTwoBits(0xC01E0306)
    STATUS_GRAPHICS_INVALID_VIDPN_SOURCEMODESET = ThirtyTwoBits(0xC01E0308)
    STATUS_GRAPHICS_INVALID_VIDPN_TARGETMODESET = ThirtyTwoBits(0xC01E0309)
    STATUS_GRAPHICS_INVALID_FREQUENCY = ThirtyTwoBits(0xC01E030A)
    STATUS_GRAPHICS_INVALID_ACTIVE_REGION = ThirtyTwoBits(0xC01E030B)
    STATUS_GRAPHICS_INVALID_TOTAL_REGION = ThirtyTwoBits(0xC01E030C)
    STATUS_GRAPHICS_INVALID_VIDEO_PRESENT_SOURCE_MODE = ThirtyTwoBits(0xC01E0310)
    STATUS_GRAPHICS_INVALID_VIDEO_PRESENT_TARGET_MODE = ThirtyTwoBits(0xC01E0311)
    STATUS_GRAPHICS_PINNED_MODE_MUST_REMAIN_IN_SET = ThirtyTwoBits(0xC01E0312)
    STATUS_GRAPHICS_PATH_ALREADY_IN_TOPOLOGY = ThirtyTwoBits(0xC01E0313)
    STATUS_GRAPHICS_MODE_ALREADY_IN_MODESET = ThirtyTwoBits(0xC01E0314)
    STATUS_GRAPHICS_INVALID_VIDEOPRESENTSOURCESET = ThirtyTwoBits(0xC01E0315)
    STATUS_GRAPHICS_INVALID_VIDEOPRESENTTARGETSET = ThirtyTwoBits(0xC01E0316)
    STATUS_GRAPHICS_SOURCE_ALREADY_IN_SET = ThirtyTwoBits(0xC01E0317)
    STATUS_GRAPHICS_TARGET_ALREADY_IN_SET = ThirtyTwoBits(0xC01E0318)
    STATUS_GRAPHICS_INVALID_VIDPN_PRESENT_PATH = ThirtyTwoBits(0xC01E0319)
    STATUS_GRAPHICS_NO_RECOMMENDED_VIDPN_TOPOLOGY = ThirtyTwoBits(0xC01E031A)
    STATUS_GRAPHICS_INVALID_MONITOR_FREQUENCYRANGESET = ThirtyTwoBits(0xC01E031B)
    STATUS_GRAPHICS_INVALID_MONITOR_FREQUENCYRANGE = ThirtyTwoBits(0xC01E031C)
    STATUS_GRAPHICS_FREQUENCYRANGE_NOT_IN_SET = ThirtyTwoBits(0xC01E031D)
    STATUS_GRAPHICS_FREQUENCYRANGE_ALREADY_IN_SET = ThirtyTwoBits(0xC01E031F)
    STATUS_GRAPHICS_STALE_MODESET = ThirtyTwoBits(0xC01E0320)
    STATUS_GRAPHICS_INVALID_MONITOR_SOURCEMODESET = ThirtyTwoBits(0xC01E0321)
    STATUS_GRAPHICS_INVALID_MONITOR_SOURCE_MODE = ThirtyTwoBits(0xC01E0322)
    STATUS_GRAPHICS_NO_RECOMMENDED_FUNCTIONAL_VIDPN = ThirtyTwoBits(0xC01E0323)
    STATUS_GRAPHICS_MODE_ID_MUST_BE_UNIQUE = ThirtyTwoBits(0xC01E0324)
    STATUS_GRAPHICS_EMPTY_ADAPTER_MONITOR_MODE_SUPPORT_INTERSECTION = ThirtyTwoBits(0xC01E0325)
    STATUS_GRAPHICS_VIDEO_PRESENT_TARGETS_LESS_THAN_SOURCES = ThirtyTwoBits(0xC01E0326)
    STATUS_GRAPHICS_PATH_NOT_IN_TOPOLOGY = ThirtyTwoBits(0xC01E0327)
    STATUS_GRAPHICS_ADAPTER_MUST_HAVE_AT_LEAST_ONE_SOURCE = ThirtyTwoBits(0xC01E0328)
    STATUS_GRAPHICS_ADAPTER_MUST_HAVE_AT_LEAST_ONE_TARGET = ThirtyTwoBits(0xC01E0329)
    STATUS_GRAPHICS_INVALID_MONITORDESCRIPTORSET = ThirtyTwoBits(0xC01E032A)
    STATUS_GRAPHICS_INVALID_MONITORDESCRIPTOR = ThirtyTwoBits(0xC01E032B)
    STATUS_GRAPHICS_MONITORDESCRIPTOR_NOT_IN_SET = ThirtyTwoBits(0xC01E032C)
    STATUS_GRAPHICS_MONITORDESCRIPTOR_ALREADY_IN_SET = ThirtyTwoBits(0xC01E032D)
    STATUS_GRAPHICS_MONITORDESCRIPTOR_ID_MUST_BE_UNIQUE = ThirtyTwoBits(0xC01E032E)
    STATUS_GRAPHICS_INVALID_VIDPN_TARGET_SUBSET_TYPE = ThirtyTwoBits(0xC01E032F)
    STATUS_GRAPHICS_RESOURCES_NOT_RELATED = ThirtyTwoBits(0xC01E0330)
    STATUS_GRAPHICS_SOURCE_ID_MUST_BE_UNIQUE = ThirtyTwoBits(0xC01E0331)
    STATUS_GRAPHICS_TARGET_ID_MUST_BE_UNIQUE = ThirtyTwoBits(0xC01E0332)
    STATUS_GRAPHICS_NO_AVAILABLE_VIDPN_TARGET = ThirtyTwoBits(0xC01E0333)
    STATUS_GRAPHICS_MONITOR_COULD_NOT_BE_ASSOCIATED_WITH_ADAPTER = ThirtyTwoBits(0xC01E0334)
    STATUS_GRAPHICS_NO_VIDPNMGR = ThirtyTwoBits(0xC01E0335)
    STATUS_GRAPHICS_NO_ACTIVE_VIDPN = ThirtyTwoBits(0xC01E0336)
    STATUS_GRAPHICS_STALE_VIDPN_TOPOLOGY = ThirtyTwoBits(0xC01E0337)
    STATUS_GRAPHICS_MONITOR_NOT_CONNECTED = ThirtyTwoBits(0xC01E0338)
    STATUS_GRAPHICS_SOURCE_NOT_IN_TOPOLOGY = ThirtyTwoBits(0xC01E0339)
    STATUS_GRAPHICS_INVALID_PRIMARYSURFACE_SIZE = ThirtyTwoBits(0xC01E033A)
    STATUS_GRAPHICS_INVALID_VISIBLEREGION_SIZE = ThirtyTwoBits(0xC01E033B)
    STATUS_GRAPHICS_INVALID_STRIDE = ThirtyTwoBits(0xC01E033C)
    STATUS_GRAPHICS_INVALID_PIXELFORMAT = ThirtyTwoBits(0xC01E033D)
    STATUS_GRAPHICS_INVALID_COLORBASIS = ThirtyTwoBits(0xC01E033E)
    STATUS_GRAPHICS_INVALID_PIXELVALUEACCESSMODE = ThirtyTwoBits(0xC01E033F)
    STATUS_GRAPHICS_TARGET_NOT_IN_TOPOLOGY = ThirtyTwoBits(0xC01E0340)
    STATUS_GRAPHICS_NO_DISPLAY_MODE_MANAGEMENT_SUPPORT = ThirtyTwoBits(0xC01E0341)
    STATUS_GRAPHICS_VIDPN_SOURCE_IN_USE = ThirtyTwoBits(0xC01E0342)
    STATUS_GRAPHICS_CANT_ACCESS_ACTIVE_VIDPN = ThirtyTwoBits(0xC01E0343)
    STATUS_GRAPHICS_INVALID_PATH_IMPORTANCE_ORDINAL = ThirtyTwoBits(0xC01E0344)
    STATUS_GRAPHICS_INVALID_PATH_CONTENT_GEOMETRY_TRANSFORMATION = ThirtyTwoBits(0xC01E0345)
    STATUS_GRAPHICS_PATH_CONTENT_GEOMETRY_TRANSFORMATION_NOT_SUPPORTED = ThirtyTwoBits(0xC01E0346)
    STATUS_GRAPHICS_INVALID_GAMMA_RAMP = ThirtyTwoBits(0xC01E0347)
    STATUS_GRAPHICS_GAMMA_RAMP_NOT_SUPPORTED = ThirtyTwoBits(0xC01E0348)
    STATUS_GRAPHICS_MULTISAMPLING_NOT_SUPPORTED = ThirtyTwoBits(0xC01E0349)
    STATUS_GRAPHICS_MODE_NOT_IN_MODESET = ThirtyTwoBits(0xC01E034A)
    STATUS_GRAPHICS_INVALID_VIDPN_TOPOLOGY_RECOMMENDATION_REASON = ThirtyTwoBits(0xC01E034D)
    STATUS_GRAPHICS_INVALID_PATH_CONTENT_TYPE = ThirtyTwoBits(0xC01E034E)
    STATUS_GRAPHICS_INVALID_COPYPROTECTION_TYPE = ThirtyTwoBits(0xC01E034F)
    STATUS_GRAPHICS_UNASSIGNED_MODESET_ALREADY_EXISTS = ThirtyTwoBits(0xC01E0350)
    STATUS_GRAPHICS_INVALID_SCANLINE_ORDERING = ThirtyTwoBits(0xC01E0352)
    STATUS_GRAPHICS_TOPOLOGY_CHANGES_NOT_ALLOWED = ThirtyTwoBits(0xC01E0353)
    STATUS_GRAPHICS_NO_AVAILABLE_IMPORTANCE_ORDINALS = ThirtyTwoBits(0xC01E0354)
    STATUS_GRAPHICS_INCOMPATIBLE_PRIVATE_FORMAT = ThirtyTwoBits(0xC01E0355)
    STATUS_GRAPHICS_INVALID_MODE_PRUNING_ALGORITHM = ThirtyTwoBits(0xC01E0356)
    STATUS_GRAPHICS_INVALID_MONITOR_CAPABILITY_ORIGIN = ThirtyTwoBits(0xC01E0357)
    STATUS_GRAPHICS_INVALID_MONITOR_FREQUENCYRANGE_CONSTRAINT = ThirtyTwoBits(0xC01E0358)
    STATUS_GRAPHICS_MAX_NUM_PATHS_REACHED = ThirtyTwoBits(0xC01E0359)
    STATUS_GRAPHICS_CANCEL_VIDPN_TOPOLOGY_AUGMENTATION = ThirtyTwoBits(0xC01E035A)
    STATUS_GRAPHICS_INVALID_CLIENT_TYPE = ThirtyTwoBits(0xC01E035B)
    STATUS_GRAPHICS_CLIENTVIDPN_NOT_SET = ThirtyTwoBits(0xC01E035C)
    STATUS_GRAPHICS_SPECIFIED_CHILD_ALREADY_CONNECTED = ThirtyTwoBits(0xC01E0400)
    STATUS_GRAPHICS_CHILD_DESCRIPTOR_NOT_SUPPORTED = ThirtyTwoBits(0xC01E0401)
    STATUS_GRAPHICS_NOT_A_LINKED_ADAPTER = ThirtyTwoBits(0xC01E0430)
    STATUS_GRAPHICS_LEADLINK_NOT_ENUMERATED = ThirtyTwoBits(0xC01E0431)
    STATUS_GRAPHICS_CHAINLINKS_NOT_ENUMERATED = ThirtyTwoBits(0xC01E0432)
    STATUS_GRAPHICS_ADAPTER_CHAIN_NOT_READY = ThirtyTwoBits(0xC01E0433)
    STATUS_GRAPHICS_CHAINLINKS_NOT_STARTED = ThirtyTwoBits(0xC01E0434)
    STATUS_GRAPHICS_CHAINLINKS_NOT_POWERED_ON = ThirtyTwoBits(0xC01E0435)
    STATUS_GRAPHICS_INCONSISTENT_DEVICE_LINK_STATE = ThirtyTwoBits(0xC01E0436)
    STATUS_GRAPHICS_NOT_POST_DEVICE_DRIVER = ThirtyTwoBits(0xC01E0438)
    STATUS_GRAPHICS_ADAPTER_ACCESS_NOT_EXCLUDED = ThirtyTwoBits(0xC01E043B)
    STATUS_GRAPHICS_OPM_NOT_SUPPORTED = ThirtyTwoBits(0xC01E0500)
    STATUS_GRAPHICS_COPP_NOT_SUPPORTED = ThirtyTwoBits(0xC01E0501)
    STATUS_GRAPHICS_UAB_NOT_SUPPORTED = ThirtyTwoBits(0xC01E0502)
    STATUS_GRAPHICS_OPM_INVALID_ENCRYPTED_PARAMETERS = ThirtyTwoBits(0xC01E0503)
    STATUS_GRAPHICS_OPM_NO_PROTECTED_OUTPUTS_EXIST = ThirtyTwoBits(0xC01E0505)
    STATUS_GRAPHICS_OPM_INTERNAL_ERROR = ThirtyTwoBits(0xC01E050B)
    STATUS_GRAPHICS_OPM_INVALID_HANDLE = ThirtyTwoBits(0xC01E050C)
    STATUS_GRAPHICS_PVP_INVALID_CERTIFICATE_LENGTH = ThirtyTwoBits(0xC01E050E)
    STATUS_GRAPHICS_OPM_SPANNING_MODE_ENABLED = ThirtyTwoBits(0xC01E050F)
    STATUS_GRAPHICS_OPM_THEATER_MODE_ENABLED = ThirtyTwoBits(0xC01E0510)
    STATUS_GRAPHICS_PVP_HFS_FAILED = ThirtyTwoBits(0xC01E0511)
    STATUS_GRAPHICS_OPM_INVALID_SRM = ThirtyTwoBits(0xC01E0512)
    STATUS_GRAPHICS_OPM_OUTPUT_DOES_NOT_SUPPORT_HDCP = ThirtyTwoBits(0xC01E0513)
    STATUS_GRAPHICS_OPM_OUTPUT_DOES_NOT_SUPPORT_ACP = ThirtyTwoBits(0xC01E0514)
    STATUS_GRAPHICS_OPM_OUTPUT_DOES_NOT_SUPPORT_CGMSA = ThirtyTwoBits(0xC01E0515)
    STATUS_GRAPHICS_OPM_HDCP_SRM_NEVER_SET = ThirtyTwoBits(0xC01E0516)
    STATUS_GRAPHICS_OPM_RESOLUTION_TOO_HIGH = ThirtyTwoBits(0xC01E0517)
    STATUS_GRAPHICS_OPM_ALL_HDCP_HARDWARE_ALREADY_IN_USE = ThirtyTwoBits(0xC01E0518)
    STATUS_GRAPHICS_OPM_PROTECTED_OUTPUT_NO_LONGER_EXISTS = ThirtyTwoBits(0xC01E051A)
    STATUS_GRAPHICS_OPM_PROTECTED_OUTPUT_DOES_NOT_HAVE_COPP_SEMANTICS = ThirtyTwoBits(0xC01E051C)
    STATUS_GRAPHICS_OPM_INVALID_INFORMATION_REQUEST = ThirtyTwoBits(0xC01E051D)
    STATUS_GRAPHICS_OPM_DRIVER_INTERNAL_ERROR = ThirtyTwoBits(0xC01E051E)
    STATUS_GRAPHICS_OPM_PROTECTED_OUTPUT_DOES_NOT_HAVE_OPM_SEMANTICS = ThirtyTwoBits(0xC01E051F)
    STATUS_GRAPHICS_OPM_SIGNALING_NOT_SUPPORTED = ThirtyTwoBits(0xC01E0520)
    STATUS_GRAPHICS_OPM_INVALID_CONFIGURATION_REQUEST = ThirtyTwoBits(0xC01E0521)
    STATUS_GRAPHICS_I2C_NOT_SUPPORTED = ThirtyTwoBits(0xC01E0580)
    STATUS_GRAPHICS_I2C_DEVICE_DOES_NOT_EXIST = ThirtyTwoBits(0xC01E0581)
    STATUS_GRAPHICS_I2C_ERROR_TRANSMITTING_DATA = ThirtyTwoBits(0xC01E0582)
    STATUS_GRAPHICS_I2C_ERROR_RECEIVING_DATA = ThirtyTwoBits(0xC01E0583)
    STATUS_GRAPHICS_DDCCI_VCP_NOT_SUPPORTED = ThirtyTwoBits(0xC01E0584)
    STATUS_GRAPHICS_DDCCI_INVALID_DATA = ThirtyTwoBits(0xC01E0585)
    STATUS_GRAPHICS_DDCCI_MONITOR_RETURNED_INVALID_TIMING_STATUS_BYTE = ThirtyTwoBits(0xC01E0586)
    STATUS_GRAPHICS_DDCCI_INVALID_CAPABILITIES_STRING = ThirtyTwoBits(0xC01E0587)
    STATUS_GRAPHICS_MCA_INTERNAL_ERROR = ThirtyTwoBits(0xC01E0588)
    STATUS_GRAPHICS_DDCCI_INVALID_MESSAGE_COMMAND = ThirtyTwoBits(0xC01E0589)
    STATUS_GRAPHICS_DDCCI_INVALID_MESSAGE_LENGTH = ThirtyTwoBits(0xC01E058A)
    STATUS_GRAPHICS_DDCCI_INVALID_MESSAGE_CHECKSUM = ThirtyTwoBits(0xC01E058B)
    STATUS_GRAPHICS_INVALID_PHYSICAL_MONITOR_HANDLE = ThirtyTwoBits(0xC01E058C)
    STATUS_GRAPHICS_MONITOR_NO_LONGER_EXISTS = ThirtyTwoBits(0xC01E058D)
    STATUS_GRAPHICS_ONLY_CONSOLE_SESSION_SUPPORTED = ThirtyTwoBits(0xC01E05E0)
    STATUS_GRAPHICS_NO_DISPLAY_DEVICE_CORRESPONDS_TO_NAME = ThirtyTwoBits(0xC01E05E1)
    STATUS_GRAPHICS_DISPLAY_DEVICE_NOT_ATTACHED_TO_DESKTOP = ThirtyTwoBits(0xC01E05E2)
    STATUS_GRAPHICS_MIRRORING_DEVICES_NOT_SUPPORTED = ThirtyTwoBits(0xC01E05E3)
    STATUS_GRAPHICS_INVALID_POINTER = ThirtyTwoBits(0xC01E05E4)
    STATUS_GRAPHICS_NO_MONITORS_CORRESPOND_TO_DISPLAY_DEVICE = ThirtyTwoBits(0xC01E05E5)
    STATUS_GRAPHICS_PARAMETER_ARRAY_TOO_SMALL = ThirtyTwoBits(0xC01E05E6)
    STATUS_GRAPHICS_INTERNAL_ERROR = ThirtyTwoBits(0xC01E05E7)
    STATUS_GRAPHICS_SESSION_TYPE_CHANGE_IN_PROGRESS = ThirtyTwoBits(0xC01E05E8)
    STATUS_FVE_LOCKED_VOLUME = ThirtyTwoBits(0xC0210000)
    STATUS_FVE_NOT_ENCRYPTED = ThirtyTwoBits(0xC0210001)
    STATUS_FVE_BAD_INFORMATION = ThirtyTwoBits(0xC0210002)
    STATUS_FVE_TOO_SMALL = ThirtyTwoBits(0xC0210003)
    STATUS_FVE_FAILED_WRONG_FS = ThirtyTwoBits(0xC0210004)
    STATUS_FVE_BAD_PARTITION_SIZE = ThirtyTwoBits(0xC0210005)
    STATUS_FVE_FS_NOT_EXTENDED = ThirtyTwoBits(0xC0210006)
    STATUS_FVE_FS_MOUNTED = ThirtyTwoBits(0xC0210007)
    STATUS_FVE_NO_LICENSE = ThirtyTwoBits(0xC0210008)
    STATUS_FVE_ACTION_NOT_ALLOWED = ThirtyTwoBits(0xC0210009)
    STATUS_FVE_BAD_DATA = ThirtyTwoBits(0xC021000A)
    STATUS_FVE_VOLUME_NOT_BOUND = ThirtyTwoBits(0xC021000B)
    STATUS_FVE_NOT_DATA_VOLUME = ThirtyTwoBits(0xC021000C)
    STATUS_FVE_CONV_READ_ERROR = ThirtyTwoBits(0xC021000D)
    STATUS_FVE_CONV_WRITE_ERROR = ThirtyTwoBits(0xC021000E)
    STATUS_FVE_OVERLAPPED_UPDATE = ThirtyTwoBits(0xC021000F)
    STATUS_FVE_FAILED_SECTOR_SIZE = ThirtyTwoBits(0xC0210010)
    STATUS_FVE_FAILED_AUTHENTICATION = ThirtyTwoBits(0xC0210011)
    STATUS_FVE_NOT_OS_VOLUME = ThirtyTwoBits(0xC0210012)
    STATUS_FVE_KEYFILE_NOT_FOUND = ThirtyTwoBits(0xC0210013)
    STATUS_FVE_KEYFILE_INVALID = ThirtyTwoBits(0xC0210014)
    STATUS_FVE_KEYFILE_NO_VMK = ThirtyTwoBits(0xC0210015)
    STATUS_FVE_TPM_DISABLED = ThirtyTwoBits(0xC0210016)
    STATUS_FVE_TPM_SRK_AUTH_NOT_ZERO = ThirtyTwoBits(0xC0210017)
    STATUS_FVE_TPM_INVALID_PCR = ThirtyTwoBits(0xC0210018)
    STATUS_FVE_TPM_NO_VMK = ThirtyTwoBits(0xC0210019)
    STATUS_FVE_PIN_INVALID = ThirtyTwoBits(0xC021001A)
    STATUS_FVE_AUTH_INVALID_APPLICATION = ThirtyTwoBits(0xC021001B)
    STATUS_FVE_AUTH_INVALID_CONFIG = ThirtyTwoBits(0xC021001C)
    STATUS_FVE_DEBUGGER_ENABLED = ThirtyTwoBits(0xC021001D)
    STATUS_FVE_DRY_RUN_FAILED = ThirtyTwoBits(0xC021001E)
    STATUS_FVE_BAD_METADATA_POINTER = ThirtyTwoBits(0xC021001F)
    STATUS_FVE_OLD_METADATA_COPY = ThirtyTwoBits(0xC0210020)
    STATUS_FVE_REBOOT_REQUIRED = ThirtyTwoBits(0xC0210021)
    STATUS_FVE_RAW_ACCESS = ThirtyTwoBits(0xC0210022)
    STATUS_FVE_RAW_BLOCKED = ThirtyTwoBits(0xC0210023)
    STATUS_FVE_NO_AUTOUNLOCK_MASTER_KEY = ThirtyTwoBits(0xC0210024)
    STATUS_FVE_MOR_FAILED = ThirtyTwoBits(0xC0210025)
    STATUS_FVE_NO_FEATURE_LICENSE = ThirtyTwoBits(0xC0210026)
    STATUS_FVE_POLICY_USER_DISABLE_RDV_NOT_ALLOWED = ThirtyTwoBits(0xC0210027)
    STATUS_FVE_CONV_RECOVERY_FAILED = ThirtyTwoBits(0xC0210028)
    STATUS_FVE_VIRTUALIZED_SPACE_TOO_BIG = ThirtyTwoBits(0xC0210029)
    STATUS_FVE_INVALID_DATUM_TYPE = ThirtyTwoBits(0xC021002A)
    STATUS_FVE_VOLUME_TOO_SMALL = ThirtyTwoBits(0xC0210030)
    STATUS_FVE_ENH_PIN_INVALID = ThirtyTwoBits(0xC0210031)
    STATUS_FVE_FULL_ENCRYPTION_NOT_ALLOWED_ON_TP_STORAGE = ThirtyTwoBits(0xC0210032)
    STATUS_FVE_WIPE_NOT_ALLOWED_ON_TP_STORAGE = ThirtyTwoBits(0xC0210033)
    STATUS_FVE_NOT_ALLOWED_ON_CSV_STACK = ThirtyTwoBits(0xC0210034)
    STATUS_FVE_NOT_ALLOWED_ON_CLUSTER = ThirtyTwoBits(0xC0210035)
    STATUS_FVE_NOT_ALLOWED_TO_UPGRADE_WHILE_CONVERTING = ThirtyTwoBits(0xC0210036)
    STATUS_FVE_WIPE_CANCEL_NOT_APPLICABLE = ThirtyTwoBits(0xC0210037)
    STATUS_FVE_EDRIVE_DRY_RUN_FAILED = ThirtyTwoBits(0xC0210038)
    STATUS_FVE_SECUREBOOT_DISABLED = ThirtyTwoBits(0xC0210039)
    STATUS_FVE_SECUREBOOT_CONFIG_CHANGE = ThirtyTwoBits(0xC021003A)
    STATUS_FVE_DEVICE_LOCKEDOUT = ThirtyTwoBits(0xC021003B)
    STATUS_FVE_VOLUME_EXTEND_PREVENTS_EOW_DECRYPT = ThirtyTwoBits(0xC021003C)
    STATUS_FVE_NOT_DE_VOLUME = ThirtyTwoBits(0xC021003D)
    STATUS_FVE_PROTECTION_DISABLED = ThirtyTwoBits(0xC021003E)
    STATUS_FVE_PROTECTION_CANNOT_BE_DISABLED = ThirtyTwoBits(0xC021003F)
    STATUS_FVE_OSV_KSR_NOT_ALLOWED = ThirtyTwoBits(0xC0210040)
    STATUS_FVE_EDRIVE_BAND_ENUMERATION_FAILED = ThirtyTwoBits(0xC0210041)
    STATUS_FVE_POLICY_ON_RDV_EXCLUSION_LIST = ThirtyTwoBits(0xC0210042)
    STATUS_FVE_DATASET_FULL = ThirtyTwoBits(0xC0210043)
    STATUS_FVE_METADATA_FULL = ThirtyTwoBits(0xC0210044)
    STATUS_FWP_CALLOUT_NOT_FOUND = ThirtyTwoBits(0xC0220001)
    STATUS_FWP_CONDITION_NOT_FOUND = ThirtyTwoBits(0xC0220002)
    STATUS_FWP_FILTER_NOT_FOUND = ThirtyTwoBits(0xC0220003)
    STATUS_FWP_LAYER_NOT_FOUND = ThirtyTwoBits(0xC0220004)
    STATUS_FWP_PROVIDER_NOT_FOUND = ThirtyTwoBits(0xC0220005)
    STATUS_FWP_PROVIDER_CONTEXT_NOT_FOUND = ThirtyTwoBits(0xC0220006)
    STATUS_FWP_SUBLAYER_NOT_FOUND = ThirtyTwoBits(0xC0220007)
    STATUS_FWP_NOT_FOUND = ThirtyTwoBits(0xC0220008)
    STATUS_FWP_ALREADY_EXISTS = ThirtyTwoBits(0xC0220009)
    STATUS_FWP_IN_USE = ThirtyTwoBits(0xC022000A)
    STATUS_FWP_DYNAMIC_SESSION_IN_PROGRESS = ThirtyTwoBits(0xC022000B)
    STATUS_FWP_WRONG_SESSION = ThirtyTwoBits(0xC022000C)
    STATUS_FWP_NO_TXN_IN_PROGRESS = ThirtyTwoBits(0xC022000D)
    STATUS_FWP_TXN_IN_PROGRESS = ThirtyTwoBits(0xC022000E)
    STATUS_FWP_TXN_ABORTED = ThirtyTwoBits(0xC022000F)
    STATUS_FWP_SESSION_ABORTED = ThirtyTwoBits(0xC0220010)
    STATUS_FWP_INCOMPATIBLE_TXN = ThirtyTwoBits(0xC0220011)
    STATUS_FWP_TIMEOUT = ThirtyTwoBits(0xC0220012)
    STATUS_FWP_NET_EVENTS_DISABLED = ThirtyTwoBits(0xC0220013)
    STATUS_FWP_INCOMPATIBLE_LAYER = ThirtyTwoBits(0xC0220014)
    STATUS_FWP_KM_CLIENTS_ONLY = ThirtyTwoBits(0xC0220015)
    STATUS_FWP_LIFETIME_MISMATCH = ThirtyTwoBits(0xC0220016)
    STATUS_FWP_BUILTIN_OBJECT = ThirtyTwoBits(0xC0220017)
    STATUS_FWP_TOO_MANY_CALLOUTS = ThirtyTwoBits(0xC0220018)
    STATUS_FWP_NOTIFICATION_DROPPED = ThirtyTwoBits(0xC0220019)
    STATUS_FWP_TRAFFIC_MISMATCH = ThirtyTwoBits(0xC022001A)
    STATUS_FWP_INCOMPATIBLE_SA_STATE = ThirtyTwoBits(0xC022001B)
    STATUS_FWP_NULL_POINTER = ThirtyTwoBits(0xC022001C)
    STATUS_FWP_INVALID_ENUMERATOR = ThirtyTwoBits(0xC022001D)
    STATUS_FWP_INVALID_FLAGS = ThirtyTwoBits(0xC022001E)
    STATUS_FWP_INVALID_NET_MASK = ThirtyTwoBits(0xC022001F)
    STATUS_FWP_INVALID_RANGE = ThirtyTwoBits(0xC0220020)
    STATUS_FWP_INVALID_INTERVAL = ThirtyTwoBits(0xC0220021)
    STATUS_FWP_ZERO_LENGTH_ARRAY = ThirtyTwoBits(0xC0220022)
    STATUS_FWP_NULL_DISPLAY_NAME = ThirtyTwoBits(0xC0220023)
    STATUS_FWP_INVALID_ACTION_TYPE = ThirtyTwoBits(0xC0220024)
    STATUS_FWP_INVALID_WEIGHT = ThirtyTwoBits(0xC0220025)
    STATUS_FWP_MATCH_TYPE_MISMATCH = ThirtyTwoBits(0xC0220026)
    STATUS_FWP_TYPE_MISMATCH = ThirtyTwoBits(0xC0220027)
    STATUS_FWP_OUT_OF_BOUNDS = ThirtyTwoBits(0xC0220028)
    STATUS_FWP_RESERVED = ThirtyTwoBits(0xC0220029)
    STATUS_FWP_DUPLICATE_CONDITION = ThirtyTwoBits(0xC022002A)
    STATUS_FWP_DUPLICATE_KEYMOD = ThirtyTwoBits(0xC022002B)
    STATUS_FWP_ACTION_INCOMPATIBLE_WITH_LAYER = ThirtyTwoBits(0xC022002C)
    STATUS_FWP_ACTION_INCOMPATIBLE_WITH_SUBLAYER = ThirtyTwoBits(0xC022002D)
    STATUS_FWP_CONTEXT_INCOMPATIBLE_WITH_LAYER = ThirtyTwoBits(0xC022002E)
    STATUS_FWP_CONTEXT_INCOMPATIBLE_WITH_CALLOUT = ThirtyTwoBits(0xC022002F)
    STATUS_FWP_INCOMPATIBLE_AUTH_METHOD = ThirtyTwoBits(0xC0220030)
    STATUS_FWP_INCOMPATIBLE_DH_GROUP = ThirtyTwoBits(0xC0220031)
    STATUS_FWP_EM_NOT_SUPPORTED = ThirtyTwoBits(0xC0220032)
    STATUS_FWP_NEVER_MATCH = ThirtyTwoBits(0xC0220033)
    STATUS_FWP_PROVIDER_CONTEXT_MISMATCH = ThirtyTwoBits(0xC0220034)
    STATUS_FWP_INVALID_PARAMETER = ThirtyTwoBits(0xC0220035)
    STATUS_FWP_TOO_MANY_SUBLAYERS = ThirtyTwoBits(0xC0220036)
    STATUS_FWP_CALLOUT_NOTIFICATION_FAILED = ThirtyTwoBits(0xC0220037)
    STATUS_FWP_INVALID_AUTH_TRANSFORM = ThirtyTwoBits(0xC0220038)
    STATUS_FWP_INVALID_CIPHER_TRANSFORM = ThirtyTwoBits(0xC0220039)
    STATUS_FWP_INCOMPATIBLE_CIPHER_TRANSFORM = ThirtyTwoBits(0xC022003A)
    STATUS_FWP_INVALID_TRANSFORM_COMBINATION = ThirtyTwoBits(0xC022003B)
    STATUS_FWP_DUPLICATE_AUTH_METHOD = ThirtyTwoBits(0xC022003C)
    STATUS_FWP_INVALID_TUNNEL_ENDPOINT = ThirtyTwoBits(0xC022003D)
    STATUS_FWP_L2_DRIVER_NOT_READY = ThirtyTwoBits(0xC022003E)
    STATUS_FWP_KEY_DICTATOR_ALREADY_REGISTERED = ThirtyTwoBits(0xC022003F)
    STATUS_FWP_KEY_DICTATION_INVALID_KEYING_MATERIAL = ThirtyTwoBits(0xC0220040)
    STATUS_FWP_CONNECTIONS_DISABLED = ThirtyTwoBits(0xC0220041)
    STATUS_FWP_INVALID_DNS_NAME = ThirtyTwoBits(0xC0220042)
    STATUS_FWP_STILL_ON = ThirtyTwoBits(0xC0220043)
    STATUS_FWP_IKEEXT_NOT_RUNNING = ThirtyTwoBits(0xC0220044)
    STATUS_FWP_TCPIP_NOT_READY = ThirtyTwoBits(0xC0220100)
    STATUS_FWP_INJECT_HANDLE_CLOSING = ThirtyTwoBits(0xC0220101)
    STATUS_FWP_INJECT_HANDLE_STALE = ThirtyTwoBits(0xC0220102)
    STATUS_FWP_CANNOT_PEND = ThirtyTwoBits(0xC0220103)
    STATUS_FWP_DROP_NOICMP = ThirtyTwoBits(0xC0220104)
    STATUS_NDIS_CLOSING = ThirtyTwoBits(0xC0230002)
    STATUS_NDIS_BAD_VERSION = ThirtyTwoBits(0xC0230004)
    STATUS_NDIS_BAD_CHARACTERISTICS = ThirtyTwoBits(0xC0230005)
    STATUS_NDIS_ADAPTER_NOT_FOUND = ThirtyTwoBits(0xC0230006)
    STATUS_NDIS_OPEN_FAILED = ThirtyTwoBits(0xC0230007)
    STATUS_NDIS_DEVICE_FAILED = ThirtyTwoBits(0xC0230008)
    STATUS_NDIS_MULTICAST_FULL = ThirtyTwoBits(0xC0230009)
    STATUS_NDIS_MULTICAST_EXISTS = ThirtyTwoBits(0xC023000A)
    STATUS_NDIS_MULTICAST_NOT_FOUND = ThirtyTwoBits(0xC023000B)
    STATUS_NDIS_REQUEST_ABORTED = ThirtyTwoBits(0xC023000C)
    STATUS_NDIS_RESET_IN_PROGRESS = ThirtyTwoBits(0xC023000D)
    STATUS_NDIS_INVALID_PACKET = ThirtyTwoBits(0xC023000F)
    STATUS_NDIS_INVALID_DEVICE_REQUEST = ThirtyTwoBits(0xC0230010)
    STATUS_NDIS_ADAPTER_NOT_READY = ThirtyTwoBits(0xC0230011)
    STATUS_NDIS_INVALID_LENGTH = ThirtyTwoBits(0xC0230014)
    STATUS_NDIS_INVALID_DATA = ThirtyTwoBits(0xC0230015)
    STATUS_NDIS_BUFFER_TOO_SHORT = ThirtyTwoBits(0xC0230016)
    STATUS_NDIS_INVALID_OID = ThirtyTwoBits(0xC0230017)
    STATUS_NDIS_ADAPTER_REMOVED = ThirtyTwoBits(0xC0230018)
    STATUS_NDIS_UNSUPPORTED_MEDIA = ThirtyTwoBits(0xC0230019)
    STATUS_NDIS_GROUP_ADDRESS_IN_USE = ThirtyTwoBits(0xC023001A)
    STATUS_NDIS_FILE_NOT_FOUND = ThirtyTwoBits(0xC023001B)
    STATUS_NDIS_ERROR_READING_FILE = ThirtyTwoBits(0xC023001C)
    STATUS_NDIS_ALREADY_MAPPED = ThirtyTwoBits(0xC023001D)
    STATUS_NDIS_RESOURCE_CONFLICT = ThirtyTwoBits(0xC023001E)
    STATUS_NDIS_MEDIA_DISCONNECTED = ThirtyTwoBits(0xC023001F)
    STATUS_NDIS_INVALID_ADDRESS = ThirtyTwoBits(0xC0230022)
    STATUS_NDIS_PAUSED = ThirtyTwoBits(0xC023002A)
    STATUS_NDIS_INTERFACE_NOT_FOUND = ThirtyTwoBits(0xC023002B)
    STATUS_NDIS_UNSUPPORTED_REVISION = ThirtyTwoBits(0xC023002C)
    STATUS_NDIS_INVALID_PORT = ThirtyTwoBits(0xC023002D)
    STATUS_NDIS_INVALID_PORT_STATE = ThirtyTwoBits(0xC023002E)
    STATUS_NDIS_LOW_POWER_STATE = ThirtyTwoBits(0xC023002F)
    STATUS_NDIS_REINIT_REQUIRED = ThirtyTwoBits(0xC0230030)
    STATUS_NDIS_NO_QUEUES = ThirtyTwoBits(0xC0230031)
    STATUS_NDIS_NOT_SUPPORTED = ThirtyTwoBits(0xC02300BB)
    STATUS_NDIS_OFFLOAD_POLICY = ThirtyTwoBits(0xC023100F)
    STATUS_NDIS_OFFLOAD_CONNECTION_REJECTED = ThirtyTwoBits(0xC0231012)
    STATUS_NDIS_OFFLOAD_PATH_REJECTED = ThirtyTwoBits(0xC0231013)
    STATUS_NDIS_DOT11_AUTO_CONFIG_ENABLED = ThirtyTwoBits(0xC0232000)
    STATUS_NDIS_DOT11_MEDIA_IN_USE = ThirtyTwoBits(0xC0232001)
    STATUS_NDIS_DOT11_POWER_STATE_INVALID = ThirtyTwoBits(0xC0232002)
    STATUS_NDIS_PM_WOL_PATTERN_LIST_FULL = ThirtyTwoBits(0xC0232003)
    STATUS_NDIS_PM_PROTOCOL_OFFLOAD_LIST_FULL = ThirtyTwoBits(0xC0232004)
    STATUS_NDIS_DOT11_AP_CHANNEL_CURRENTLY_NOT_AVAILABLE = ThirtyTwoBits(0xC0232005)
    STATUS_NDIS_DOT11_AP_BAND_CURRENTLY_NOT_AVAILABLE = ThirtyTwoBits(0xC0232006)
    STATUS_NDIS_DOT11_AP_CHANNEL_NOT_ALLOWED = ThirtyTwoBits(0xC0232007)
    STATUS_NDIS_DOT11_AP_BAND_NOT_ALLOWED = ThirtyTwoBits(0xC0232008)
    STATUS_QUIC_HANDSHAKE_FAILURE = ThirtyTwoBits(0xC0240000)
    STATUS_QUIC_VER_NEG_FAILURE = ThirtyTwoBits(0xC0240001)
    STATUS_QUIC_USER_CANCELED = ThirtyTwoBits(0xC0240002)
    STATUS_QUIC_INTERNAL_ERROR = ThirtyTwoBits(0xC0240003)
    STATUS_QUIC_PROTOCOL_VIOLATION = ThirtyTwoBits(0xC0240004)
    STATUS_QUIC_CONNECTION_IDLE = ThirtyTwoBits(0xC0240005)
    STATUS_QUIC_CONNECTION_TIMEOUT = ThirtyTwoBits(0xC0240006)
    STATUS_QUIC_ALPN_NEG_FAILURE = ThirtyTwoBits(0xC0240007)
    STATUS_TPM_ERROR_MASK = ThirtyTwoBits(0xC0290000)
    STATUS_TPM_AUTHFAIL = ThirtyTwoBits(0xC0290001)
    STATUS_TPM_BADINDEX = ThirtyTwoBits(0xC0290002)
    STATUS_TPM_BAD_PARAMETER = ThirtyTwoBits(0xC0290003)
    STATUS_TPM_AUDITFAILURE = ThirtyTwoBits(0xC0290004)
    STATUS_TPM_CLEAR_DISABLED = ThirtyTwoBits(0xC0290005)
    STATUS_TPM_DEACTIVATED = ThirtyTwoBits(0xC0290006)
    STATUS_TPM_DISABLED = ThirtyTwoBits(0xC0290007)
    STATUS_TPM_DISABLED_CMD = ThirtyTwoBits(0xC0290008)
    STATUS_TPM_FAIL = ThirtyTwoBits(0xC0290009)
    STATUS_TPM_BAD_ORDINAL = ThirtyTwoBits(0xC029000A)
    STATUS_TPM_INSTALL_DISABLED = ThirtyTwoBits(0xC029000B)
    STATUS_TPM_INVALID_KEYHANDLE = ThirtyTwoBits(0xC029000C)
    STATUS_TPM_KEYNOTFOUND = ThirtyTwoBits(0xC029000D)
    STATUS_TPM_INAPPROPRIATE_ENC = ThirtyTwoBits(0xC029000E)
    STATUS_TPM_MIGRATEFAIL = ThirtyTwoBits(0xC029000F)
    STATUS_TPM_INVALID_PCR_INFO = ThirtyTwoBits(0xC0290010)
    STATUS_TPM_NOSPACE = ThirtyTwoBits(0xC0290011)
    STATUS_TPM_NOSRK = ThirtyTwoBits(0xC0290012)
    STATUS_TPM_NOTSEALED_BLOB = ThirtyTwoBits(0xC0290013)
    STATUS_TPM_OWNER_SET = ThirtyTwoBits(0xC0290014)
    STATUS_TPM_RESOURCES = ThirtyTwoBits(0xC0290015)
    STATUS_TPM_SHORTRANDOM = ThirtyTwoBits(0xC0290016)
    STATUS_TPM_SIZE = ThirtyTwoBits(0xC0290017)
    STATUS_TPM_WRONGPCRVAL = ThirtyTwoBits(0xC0290018)
    STATUS_TPM_BAD_PARAM_SIZE = ThirtyTwoBits(0xC0290019)
    STATUS_TPM_SHA_THREAD = ThirtyTwoBits(0xC029001A)
    STATUS_TPM_SHA_ERROR = ThirtyTwoBits(0xC029001B)
    STATUS_TPM_FAILEDSELFTEST = ThirtyTwoBits(0xC029001C)
    STATUS_TPM_AUTH2FAIL = ThirtyTwoBits(0xC029001D)
    STATUS_TPM_BADTAG = ThirtyTwoBits(0xC029001E)
    STATUS_TPM_IOERROR = ThirtyTwoBits(0xC029001F)
    STATUS_TPM_ENCRYPT_ERROR = ThirtyTwoBits(0xC0290020)
    STATUS_TPM_DECRYPT_ERROR = ThirtyTwoBits(0xC0290021)
    STATUS_TPM_INVALID_AUTHHANDLE = ThirtyTwoBits(0xC0290022)
    STATUS_TPM_NO_ENDORSEMENT = ThirtyTwoBits(0xC0290023)
    STATUS_TPM_INVALID_KEYUSAGE = ThirtyTwoBits(0xC0290024)
    STATUS_TPM_WRONG_ENTITYTYPE = ThirtyTwoBits(0xC0290025)
    STATUS_TPM_INVALID_POSTINIT = ThirtyTwoBits(0xC0290026)
    STATUS_TPM_INAPPROPRIATE_SIG = ThirtyTwoBits(0xC0290027)
    STATUS_TPM_BAD_KEY_PROPERTY = ThirtyTwoBits(0xC0290028)
    STATUS_TPM_BAD_MIGRATION = ThirtyTwoBits(0xC0290029)
    STATUS_TPM_BAD_SCHEME = ThirtyTwoBits(0xC029002A)
    STATUS_TPM_BAD_DATASIZE = ThirtyTwoBits(0xC029002B)
    STATUS_TPM_BAD_MODE = ThirtyTwoBits(0xC029002C)
    STATUS_TPM_BAD_PRESENCE = ThirtyTwoBits(0xC029002D)
    STATUS_TPM_BAD_VERSION = ThirtyTwoBits(0xC029002E)
    STATUS_TPM_NO_WRAP_TRANSPORT = ThirtyTwoBits(0xC029002F)
    STATUS_TPM_AUDITFAIL_UNSUCCESSFUL = ThirtyTwoBits(0xC0290030)
    STATUS_TPM_AUDITFAIL_SUCCESSFUL = ThirtyTwoBits(0xC0290031)
    STATUS_TPM_NOTRESETABLE = ThirtyTwoBits(0xC0290032)
    STATUS_TPM_NOTLOCAL = ThirtyTwoBits(0xC0290033)
    STATUS_TPM_BAD_TYPE = ThirtyTwoBits(0xC0290034)
    STATUS_TPM_INVALID_RESOURCE = ThirtyTwoBits(0xC0290035)
    STATUS_TPM_NOTFIPS = ThirtyTwoBits(0xC0290036)
    STATUS_TPM_INVALID_FAMILY = ThirtyTwoBits(0xC0290037)
    STATUS_TPM_NO_NV_PERMISSION = ThirtyTwoBits(0xC0290038)
    STATUS_TPM_REQUIRES_SIGN = ThirtyTwoBits(0xC0290039)
    STATUS_TPM_KEY_NOTSUPPORTED = ThirtyTwoBits(0xC029003A)
    STATUS_TPM_AUTH_CONFLICT = ThirtyTwoBits(0xC029003B)
    STATUS_TPM_AREA_LOCKED = ThirtyTwoBits(0xC029003C)
    STATUS_TPM_BAD_LOCALITY = ThirtyTwoBits(0xC029003D)
    STATUS_TPM_READ_ONLY = ThirtyTwoBits(0xC029003E)
    STATUS_TPM_PER_NOWRITE = ThirtyTwoBits(0xC029003F)
    STATUS_TPM_FAMILYCOUNT = ThirtyTwoBits(0xC0290040)
    STATUS_TPM_WRITE_LOCKED = ThirtyTwoBits(0xC0290041)
    STATUS_TPM_BAD_ATTRIBUTES = ThirtyTwoBits(0xC0290042)
    STATUS_TPM_INVALID_STRUCTURE = ThirtyTwoBits(0xC0290043)
    STATUS_TPM_KEY_OWNER_CONTROL = ThirtyTwoBits(0xC0290044)
    STATUS_TPM_BAD_COUNTER = ThirtyTwoBits(0xC0290045)
    STATUS_TPM_NOT_FULLWRITE = ThirtyTwoBits(0xC0290046)
    STATUS_TPM_CONTEXT_GAP = ThirtyTwoBits(0xC0290047)
    STATUS_TPM_MAXNVWRITES = ThirtyTwoBits(0xC0290048)
    STATUS_TPM_NOOPERATOR = ThirtyTwoBits(0xC0290049)
    STATUS_TPM_RESOURCEMISSING = ThirtyTwoBits(0xC029004A)
    STATUS_TPM_DELEGATE_LOCK = ThirtyTwoBits(0xC029004B)
    STATUS_TPM_DELEGATE_FAMILY = ThirtyTwoBits(0xC029004C)
    STATUS_TPM_DELEGATE_ADMIN = ThirtyTwoBits(0xC029004D)
    STATUS_TPM_TRANSPORT_NOTEXCLUSIVE = ThirtyTwoBits(0xC029004E)
    STATUS_TPM_OWNER_CONTROL = ThirtyTwoBits(0xC029004F)
    STATUS_TPM_DAA_RESOURCES = ThirtyTwoBits(0xC0290050)
    STATUS_TPM_DAA_INPUT_DATA0 = ThirtyTwoBits(0xC0290051)
    STATUS_TPM_DAA_INPUT_DATA1 = ThirtyTwoBits(0xC0290052)
    STATUS_TPM_DAA_ISSUER_SETTINGS = ThirtyTwoBits(0xC0290053)
    STATUS_TPM_DAA_TPM_SETTINGS = ThirtyTwoBits(0xC0290054)
    STATUS_TPM_DAA_STAGE = ThirtyTwoBits(0xC0290055)
    STATUS_TPM_DAA_ISSUER_VALIDITY = ThirtyTwoBits(0xC0290056)
    STATUS_TPM_DAA_WRONG_W = ThirtyTwoBits(0xC0290057)
    STATUS_TPM_BAD_HANDLE = ThirtyTwoBits(0xC0290058)
    STATUS_TPM_BAD_DELEGATE = ThirtyTwoBits(0xC0290059)
    STATUS_TPM_BADCONTEXT = ThirtyTwoBits(0xC029005A)
    STATUS_TPM_TOOMANYCONTEXTS = ThirtyTwoBits(0xC029005B)
    STATUS_TPM_MA_TICKET_SIGNATURE = ThirtyTwoBits(0xC029005C)
    STATUS_TPM_MA_DESTINATION = ThirtyTwoBits(0xC029005D)
    STATUS_TPM_MA_SOURCE = ThirtyTwoBits(0xC029005E)
    STATUS_TPM_MA_AUTHORITY = ThirtyTwoBits(0xC029005F)
    STATUS_TPM_PERMANENTEK = ThirtyTwoBits(0xC0290061)
    STATUS_TPM_BAD_SIGNATURE = ThirtyTwoBits(0xC0290062)
    STATUS_TPM_NOCONTEXTSPACE = ThirtyTwoBits(0xC0290063)
    STATUS_TPM_20_E_ASYMMETRIC = ThirtyTwoBits(0xC0290081)
    STATUS_TPM_20_E_ATTRIBUTES = ThirtyTwoBits(0xC0290082)
    STATUS_TPM_20_E_HASH = ThirtyTwoBits(0xC0290083)
    STATUS_TPM_20_E_VALUE = ThirtyTwoBits(0xC0290084)
    STATUS_TPM_20_E_HIERARCHY = ThirtyTwoBits(0xC0290085)
    STATUS_TPM_20_E_KEY_SIZE = ThirtyTwoBits(0xC0290087)
    STATUS_TPM_20_E_MGF = ThirtyTwoBits(0xC0290088)
    STATUS_TPM_20_E_MODE = ThirtyTwoBits(0xC0290089)
    STATUS_TPM_20_E_TYPE = ThirtyTwoBits(0xC029008A)
    STATUS_TPM_20_E_HANDLE = ThirtyTwoBits(0xC029008B)
    STATUS_TPM_20_E_KDF = ThirtyTwoBits(0xC029008C)
    STATUS_TPM_20_E_RANGE = ThirtyTwoBits(0xC029008D)
    STATUS_TPM_20_E_AUTH_FAIL = ThirtyTwoBits(0xC029008E)
    STATUS_TPM_20_E_NONCE = ThirtyTwoBits(0xC029008F)
    STATUS_TPM_20_E_PP = ThirtyTwoBits(0xC0290090)
    STATUS_TPM_20_E_SCHEME = ThirtyTwoBits(0xC0290092)
    STATUS_TPM_20_E_SIZE = ThirtyTwoBits(0xC0290095)
    STATUS_TPM_20_E_SYMMETRIC = ThirtyTwoBits(0xC0290096)
    STATUS_TPM_20_E_TAG = ThirtyTwoBits(0xC0290097)
    STATUS_TPM_20_E_SELECTOR = ThirtyTwoBits(0xC0290098)
    STATUS_TPM_20_E_INSUFFICIENT = ThirtyTwoBits(0xC029009A)
    STATUS_TPM_20_E_SIGNATURE = ThirtyTwoBits(0xC029009B)
    STATUS_TPM_20_E_KEY = ThirtyTwoBits(0xC029009C)
    STATUS_TPM_20_E_POLICY_FAIL = ThirtyTwoBits(0xC029009D)
    STATUS_TPM_20_E_INTEGRITY = ThirtyTwoBits(0xC029009F)
    STATUS_TPM_20_E_TICKET = ThirtyTwoBits(0xC02900A0)
    STATUS_TPM_20_E_RESERVED_BITS = ThirtyTwoBits(0xC02900A1)
    STATUS_TPM_20_E_BAD_AUTH = ThirtyTwoBits(0xC02900A2)
    STATUS_TPM_20_E_EXPIRED = ThirtyTwoBits(0xC02900A3)
    STATUS_TPM_20_E_POLICY_CC = ThirtyTwoBits(0xC02900A4)
    STATUS_TPM_20_E_BINDING = ThirtyTwoBits(0xC02900A5)
    STATUS_TPM_20_E_CURVE = ThirtyTwoBits(0xC02900A6)
    STATUS_TPM_20_E_ECC_POINT = ThirtyTwoBits(0xC02900A7)
    STATUS_TPM_20_E_INITIALIZE = ThirtyTwoBits(0xC0290100)
    STATUS_TPM_20_E_FAILURE = ThirtyTwoBits(0xC0290101)
    STATUS_TPM_20_E_SEQUENCE = ThirtyTwoBits(0xC0290103)
    STATUS_TPM_20_E_PRIVATE = ThirtyTwoBits(0xC029010B)
    STATUS_TPM_20_E_HMAC = ThirtyTwoBits(0xC0290119)
    STATUS_TPM_20_E_DISABLED = ThirtyTwoBits(0xC0290120)
    STATUS_TPM_20_E_EXCLUSIVE = ThirtyTwoBits(0xC0290121)
    STATUS_TPM_20_E_ECC_CURVE = ThirtyTwoBits(0xC0290123)
    STATUS_TPM_20_E_AUTH_TYPE = ThirtyTwoBits(0xC0290124)
    STATUS_TPM_20_E_AUTH_MISSING = ThirtyTwoBits(0xC0290125)
    STATUS_TPM_20_E_POLICY = ThirtyTwoBits(0xC0290126)
    STATUS_TPM_20_E_PCR = ThirtyTwoBits(0xC0290127)
    STATUS_TPM_20_E_PCR_CHANGED = ThirtyTwoBits(0xC0290128)
    STATUS_TPM_20_E_UPGRADE = ThirtyTwoBits(0xC029012D)
    STATUS_TPM_20_E_TOO_MANY_CONTEXTS = ThirtyTwoBits(0xC029012E)
    STATUS_TPM_20_E_AUTH_UNAVAILABLE = ThirtyTwoBits(0xC029012F)
    STATUS_TPM_20_E_REBOOT = ThirtyTwoBits(0xC0290130)
    STATUS_TPM_20_E_UNBALANCED = ThirtyTwoBits(0xC0290131)
    STATUS_TPM_20_E_COMMAND_SIZE = ThirtyTwoBits(0xC0290142)
    STATUS_TPM_20_E_COMMAND_CODE = ThirtyTwoBits(0xC0290143)
    STATUS_TPM_20_E_AUTHSIZE = ThirtyTwoBits(0xC0290144)
    STATUS_TPM_20_E_AUTH_CONTEXT = ThirtyTwoBits(0xC0290145)
    STATUS_TPM_20_E_NV_RANGE = ThirtyTwoBits(0xC0290146)
    STATUS_TPM_20_E_NV_SIZE = ThirtyTwoBits(0xC0290147)
    STATUS_TPM_20_E_NV_LOCKED = ThirtyTwoBits(0xC0290148)
    STATUS_TPM_20_E_NV_AUTHORIZATION = ThirtyTwoBits(0xC0290149)
    STATUS_TPM_20_E_NV_UNINITIALIZED = ThirtyTwoBits(0xC029014A)
    STATUS_TPM_20_E_NV_SPACE = ThirtyTwoBits(0xC029014B)
    STATUS_TPM_20_E_NV_DEFINED = ThirtyTwoBits(0xC029014C)
    STATUS_TPM_20_E_BAD_CONTEXT = ThirtyTwoBits(0xC0290150)
    STATUS_TPM_20_E_CPHASH = ThirtyTwoBits(0xC0290151)
    STATUS_TPM_20_E_PARENT = ThirtyTwoBits(0xC0290152)
    STATUS_TPM_20_E_NEEDS_TEST = ThirtyTwoBits(0xC0290153)
    STATUS_TPM_20_E_NO_RESULT = ThirtyTwoBits(0xC0290154)
    STATUS_TPM_20_E_SENSITIVE = ThirtyTwoBits(0xC0290155)
    STATUS_TPM_COMMAND_BLOCKED = ThirtyTwoBits(0xC0290400)
    STATUS_TPM_INVALID_HANDLE = ThirtyTwoBits(0xC0290401)
    STATUS_TPM_DUPLICATE_VHANDLE = ThirtyTwoBits(0xC0290402)
    STATUS_TPM_EMBEDDED_COMMAND_BLOCKED = ThirtyTwoBits(0xC0290403)
    STATUS_TPM_EMBEDDED_COMMAND_UNSUPPORTED = ThirtyTwoBits(0xC0290404)
    STATUS_TPM_RETRY = ThirtyTwoBits(0xC0290800)
    STATUS_TPM_NEEDS_SELFTEST = ThirtyTwoBits(0xC0290801)
    STATUS_TPM_DOING_SELFTEST = ThirtyTwoBits(0xC0290802)
    STATUS_TPM_DEFEND_LOCK_RUNNING = ThirtyTwoBits(0xC0290803)
    STATUS_TPM_COMMAND_CANCELED = ThirtyTwoBits(0xC0291001)
    STATUS_TPM_TOO_MANY_CONTEXTS = ThirtyTwoBits(0xC0291002)
    STATUS_TPM_NOT_FOUND = ThirtyTwoBits(0xC0291003)
    STATUS_TPM_ACCESS_DENIED = ThirtyTwoBits(0xC0291004)
    STATUS_TPM_INSUFFICIENT_BUFFER = ThirtyTwoBits(0xC0291005)
    STATUS_TPM_PPI_FUNCTION_UNSUPPORTED = ThirtyTwoBits(0xC0291006)
    STATUS_PCP_ERROR_MASK = ThirtyTwoBits(0xC0292000)
    STATUS_PCP_DEVICE_NOT_READY = ThirtyTwoBits(0xC0292001)
    STATUS_PCP_INVALID_HANDLE = ThirtyTwoBits(0xC0292002)
    STATUS_PCP_INVALID_PARAMETER = ThirtyTwoBits(0xC0292003)
    STATUS_PCP_FLAG_NOT_SUPPORTED = ThirtyTwoBits(0xC0292004)
    STATUS_PCP_NOT_SUPPORTED = ThirtyTwoBits(0xC0292005)
    STATUS_PCP_BUFFER_TOO_SMALL = ThirtyTwoBits(0xC0292006)
    STATUS_PCP_INTERNAL_ERROR = ThirtyTwoBits(0xC0292007)
    STATUS_PCP_AUTHENTICATION_FAILED = ThirtyTwoBits(0xC0292008)
    STATUS_PCP_AUTHENTICATION_IGNORED = ThirtyTwoBits(0xC0292009)
    STATUS_PCP_POLICY_NOT_FOUND = ThirtyTwoBits(0xC029200A)
    STATUS_PCP_PROFILE_NOT_FOUND = ThirtyTwoBits(0xC029200B)
    STATUS_PCP_VALIDATION_FAILED = ThirtyTwoBits(0xC029200C)
    STATUS_PCP_DEVICE_NOT_FOUND = ThirtyTwoBits(0xC029200D)
    STATUS_PCP_WRONG_PARENT = ThirtyTwoBits(0xC029200E)
    STATUS_PCP_KEY_NOT_LOADED = ThirtyTwoBits(0xC029200F)
    STATUS_PCP_NO_KEY_CERTIFICATION = ThirtyTwoBits(0xC0292010)
    STATUS_PCP_KEY_NOT_FINALIZED = ThirtyTwoBits(0xC0292011)
    STATUS_PCP_ATTESTATION_CHALLENGE_NOT_SET = ThirtyTwoBits(0xC0292012)
    STATUS_PCP_NOT_PCR_BOUND = ThirtyTwoBits(0xC0292013)
    STATUS_PCP_KEY_ALREADY_FINALIZED = ThirtyTwoBits(0xC0292014)
    STATUS_PCP_KEY_USAGE_POLICY_NOT_SUPPORTED = ThirtyTwoBits(0xC0292015)
    STATUS_PCP_KEY_USAGE_POLICY_INVALID = ThirtyTwoBits(0xC0292016)
    STATUS_PCP_SOFT_KEY_ERROR = ThirtyTwoBits(0xC0292017)
    STATUS_PCP_KEY_NOT_AUTHENTICATED = ThirtyTwoBits(0xC0292018)
    STATUS_PCP_KEY_NOT_AIK = ThirtyTwoBits(0xC0292019)
    STATUS_PCP_KEY_NOT_SIGNING_KEY = ThirtyTwoBits(0xC029201A)
    STATUS_PCP_LOCKED_OUT = ThirtyTwoBits(0xC029201B)
    STATUS_PCP_CLAIM_TYPE_NOT_SUPPORTED = ThirtyTwoBits(0xC029201C)
    STATUS_PCP_TPM_VERSION_NOT_SUPPORTED = ThirtyTwoBits(0xC029201D)
    STATUS_PCP_BUFFER_LENGTH_MISMATCH = ThirtyTwoBits(0xC029201E)
    STATUS_PCP_IFX_RSA_KEY_CREATION_BLOCKED = ThirtyTwoBits(0xC029201F)
    STATUS_PCP_TICKET_MISSING = ThirtyTwoBits(0xC0292020)
    STATUS_PCP_RAW_POLICY_NOT_SUPPORTED = ThirtyTwoBits(0xC0292021)
    STATUS_PCP_KEY_HANDLE_INVALIDATED = ThirtyTwoBits(0xC0292022)
    STATUS_RTPM_NO_RESULT = ThirtyTwoBits(0xC0293002)
    STATUS_RTPM_PCR_READ_INCOMPLETE = ThirtyTwoBits(0xC0293003)
    STATUS_RTPM_INVALID_CONTEXT = ThirtyTwoBits(0xC0293004)
    STATUS_RTPM_UNSUPPORTED_CMD = ThirtyTwoBits(0xC0293005)
    STATUS_TPM_ZERO_EXHAUST_ENABLED = ThirtyTwoBits(0xC0294000)
    STATUS_HV_INVALID_HYPERCALL_CODE = ThirtyTwoBits(0xC0350002)
    STATUS_HV_INVALID_HYPERCALL_INPUT = ThirtyTwoBits(0xC0350003)
    STATUS_HV_INVALID_ALIGNMENT = ThirtyTwoBits(0xC0350004)
    STATUS_HV_INVALID_PARAMETER = ThirtyTwoBits(0xC0350005)
    STATUS_HV_ACCESS_DENIED = ThirtyTwoBits(0xC0350006)
    STATUS_HV_INVALID_PARTITION_STATE = ThirtyTwoBits(0xC0350007)
    STATUS_HV_OPERATION_DENIED = ThirtyTwoBits(0xC0350008)
    STATUS_HV_UNKNOWN_PROPERTY = ThirtyTwoBits(0xC0350009)
    STATUS_HV_PROPERTY_VALUE_OUT_OF_RANGE = ThirtyTwoBits(0xC035000A)
    STATUS_HV_INSUFFICIENT_MEMORY = ThirtyTwoBits(0xC035000B)
    STATUS_HV_PARTITION_TOO_DEEP = ThirtyTwoBits(0xC035000C)
    STATUS_HV_INVALID_PARTITION_ID = ThirtyTwoBits(0xC035000D)
    STATUS_HV_INVALID_VP_INDEX = ThirtyTwoBits(0xC035000E)
    STATUS_HV_INVALID_PORT_ID = ThirtyTwoBits(0xC0350011)
    STATUS_HV_INVALID_CONNECTION_ID = ThirtyTwoBits(0xC0350012)
    STATUS_HV_INSUFFICIENT_BUFFERS = ThirtyTwoBits(0xC0350013)
    STATUS_HV_NOT_ACKNOWLEDGED = ThirtyTwoBits(0xC0350014)
    STATUS_HV_INVALID_VP_STATE = ThirtyTwoBits(0xC0350015)
    STATUS_HV_ACKNOWLEDGED = ThirtyTwoBits(0xC0350016)
    STATUS_HV_INVALID_SAVE_RESTORE_STATE = ThirtyTwoBits(0xC0350017)
    STATUS_HV_INVALID_SYNIC_STATE = ThirtyTwoBits(0xC0350018)
    STATUS_HV_OBJECT_IN_USE = ThirtyTwoBits(0xC0350019)
    STATUS_HV_INVALID_PROXIMITY_DOMAIN_INFO = ThirtyTwoBits(0xC035001A)
    STATUS_HV_NO_DATA = ThirtyTwoBits(0xC035001B)
    STATUS_HV_INACTIVE = ThirtyTwoBits(0xC035001C)
    STATUS_HV_NO_RESOURCES = ThirtyTwoBits(0xC035001D)
    STATUS_HV_FEATURE_UNAVAILABLE = ThirtyTwoBits(0xC035001E)
    STATUS_HV_INSUFFICIENT_BUFFER = ThirtyTwoBits(0xC0350033)
    STATUS_HV_INSUFFICIENT_DEVICE_DOMAINS = ThirtyTwoBits(0xC0350038)
    STATUS_HV_CPUID_FEATURE_VALIDATION_ERROR = ThirtyTwoBits(0xC035003C)
    STATUS_HV_CPUID_XSAVE_FEATURE_VALIDATION_ERROR = ThirtyTwoBits(0xC035003D)
    STATUS_HV_PROCESSOR_STARTUP_TIMEOUT = ThirtyTwoBits(0xC035003E)
    STATUS_HV_SMX_ENABLED = ThirtyTwoBits(0xC035003F)
    STATUS_HV_INVALID_LP_INDEX = ThirtyTwoBits(0xC0350041)
    STATUS_HV_INVALID_REGISTER_VALUE = ThirtyTwoBits(0xC0350050)
    STATUS_HV_INVALID_VTL_STATE = ThirtyTwoBits(0xC0350051)
    STATUS_HV_NX_NOT_DETECTED = ThirtyTwoBits(0xC0350055)
    STATUS_HV_INVALID_DEVICE_ID = ThirtyTwoBits(0xC0350057)
    STATUS_HV_INVALID_DEVICE_STATE = ThirtyTwoBits(0xC0350058)
    STATUS_HV_PAGE_REQUEST_INVALID = ThirtyTwoBits(0xC0350060)
    STATUS_HV_INVALID_CPU_GROUP_ID = ThirtyTwoBits(0xC035006F)
    STATUS_HV_INVALID_CPU_GROUP_STATE = ThirtyTwoBits(0xC0350070)
    STATUS_HV_OPERATION_FAILED = ThirtyTwoBits(0xC0350071)
    STATUS_HV_NOT_ALLOWED_WITH_NESTED_VIRT_ACTIVE = ThirtyTwoBits(0xC0350072)
    STATUS_HV_INSUFFICIENT_ROOT_MEMORY = ThirtyTwoBits(0xC0350073)
    STATUS_HV_EVENT_BUFFER_ALREADY_FREED = ThirtyTwoBits(0xC0350074)
    STATUS_HV_INSUFFICIENT_CONTIGUOUS_MEMORY = ThirtyTwoBits(0xC0350075)
    STATUS_HV_DEVICE_NOT_IN_DOMAIN = ThirtyTwoBits(0xC0350076)
    STATUS_HV_NESTED_VM_EXIT = ThirtyTwoBits(0xC0350077)
    STATUS_HV_CALL_PENDING = ThirtyTwoBits(0xC0350079)
    STATUS_HV_MSR_ACCESS_FAILED = ThirtyTwoBits(0xC0350080)
    STATUS_HV_INSUFFICIENT_MEMORY_MIRRORING = ThirtyTwoBits(0xC0350081)
    STATUS_HV_INSUFFICIENT_CONTIGUOUS_MEMORY_MIRRORING = ThirtyTwoBits(0xC0350082)
    STATUS_HV_INSUFFICIENT_CONTIGUOUS_ROOT_MEMORY = ThirtyTwoBits(0xC0350083)
    STATUS_HV_INSUFFICIENT_ROOT_MEMORY_MIRRORING = ThirtyTwoBits(0xC0350084)
    STATUS_HV_INSUFFICIENT_CONTIGUOUS_ROOT_MEMORY_MIRRORING = ThirtyTwoBits(0xC0350085)
    STATUS_HV_NOT_PRESENT = ThirtyTwoBits(0xC0351000)
    STATUS_IPSEC_BAD_SPI = ThirtyTwoBits(0xC0360001)
    STATUS_IPSEC_SA_LIFETIME_EXPIRED = ThirtyTwoBits(0xC0360002)
    STATUS_IPSEC_WRONG_SA = ThirtyTwoBits(0xC0360003)
    STATUS_IPSEC_REPLAY_CHECK_FAILED = ThirtyTwoBits(0xC0360004)
    STATUS_IPSEC_INVALID_PACKET = ThirtyTwoBits(0xC0360005)
    STATUS_IPSEC_INTEGRITY_CHECK_FAILED = ThirtyTwoBits(0xC0360006)
    STATUS_IPSEC_CLEAR_TEXT_DROP = ThirtyTwoBits(0xC0360007)
    STATUS_IPSEC_AUTH_FIREWALL_DROP = ThirtyTwoBits(0xC0360008)
    STATUS_IPSEC_THROTTLE_DROP = ThirtyTwoBits(0xC0360009)
    STATUS_IPSEC_DOSP_BLOCK = ThirtyTwoBits(0xC0368000)
    STATUS_IPSEC_DOSP_RECEIVED_MULTICAST = ThirtyTwoBits(0xC0368001)
    STATUS_IPSEC_DOSP_INVALID_PACKET = ThirtyTwoBits(0xC0368002)
    STATUS_IPSEC_DOSP_STATE_LOOKUP_FAILED = ThirtyTwoBits(0xC0368003)
    STATUS_IPSEC_DOSP_MAX_ENTRIES = ThirtyTwoBits(0xC0368004)
    STATUS_IPSEC_DOSP_KEYMOD_NOT_ALLOWED = ThirtyTwoBits(0xC0368005)
    STATUS_IPSEC_DOSP_MAX_PER_IP_RATELIMIT_QUEUES = ThirtyTwoBits(0xC0368006)
    STATUS_VID_DUPLICATE_HANDLER = ThirtyTwoBits(0xC0370001)
    STATUS_VID_TOO_MANY_HANDLERS = ThirtyTwoBits(0xC0370002)
    STATUS_VID_QUEUE_FULL = ThirtyTwoBits(0xC0370003)
    STATUS_VID_HANDLER_NOT_PRESENT = ThirtyTwoBits(0xC0370004)
    STATUS_VID_INVALID_OBJECT_NAME = ThirtyTwoBits(0xC0370005)
    STATUS_VID_PARTITION_NAME_TOO_LONG = ThirtyTwoBits(0xC0370006)
    STATUS_VID_MESSAGE_QUEUE_NAME_TOO_LONG = ThirtyTwoBits(0xC0370007)
    STATUS_VID_PARTITION_ALREADY_EXISTS = ThirtyTwoBits(0xC0370008)
    STATUS_VID_PARTITION_DOES_NOT_EXIST = ThirtyTwoBits(0xC0370009)
    STATUS_VID_PARTITION_NAME_NOT_FOUND = ThirtyTwoBits(0xC037000A)
    STATUS_VID_MESSAGE_QUEUE_ALREADY_EXISTS = ThirtyTwoBits(0xC037000B)
    STATUS_VID_EXCEEDED_MBP_ENTRY_MAP_LIMIT = ThirtyTwoBits(0xC037000C)
    STATUS_VID_MB_STILL_REFERENCED = ThirtyTwoBits(0xC037000D)
    STATUS_VID_CHILD_GPA_PAGE_SET_CORRUPTED = ThirtyTwoBits(0xC037000E)
    STATUS_VID_INVALID_NUMA_SETTINGS = ThirtyTwoBits(0xC037000F)
    STATUS_VID_INVALID_NUMA_NODE_INDEX = ThirtyTwoBits(0xC0370010)
    STATUS_VID_NOTIFICATION_QUEUE_ALREADY_ASSOCIATED = ThirtyTwoBits(0xC0370011)
    STATUS_VID_INVALID_MEMORY_BLOCK_HANDLE = ThirtyTwoBits(0xC0370012)
    STATUS_VID_PAGE_RANGE_OVERFLOW = ThirtyTwoBits(0xC0370013)
    STATUS_VID_INVALID_MESSAGE_QUEUE_HANDLE = ThirtyTwoBits(0xC0370014)
    STATUS_VID_INVALID_GPA_RANGE_HANDLE = ThirtyTwoBits(0xC0370015)
    STATUS_VID_NO_MEMORY_BLOCK_NOTIFICATION_QUEUE = ThirtyTwoBits(0xC0370016)
    STATUS_VID_MEMORY_BLOCK_LOCK_COUNT_EXCEEDED = ThirtyTwoBits(0xC0370017)
    STATUS_VID_INVALID_PPM_HANDLE = ThirtyTwoBits(0xC0370018)
    STATUS_VID_MBPS_ARE_LOCKED = ThirtyTwoBits(0xC0370019)
    STATUS_VID_MESSAGE_QUEUE_CLOSED = ThirtyTwoBits(0xC037001A)
    STATUS_VID_VIRTUAL_PROCESSOR_LIMIT_EXCEEDED = ThirtyTwoBits(0xC037001B)
    STATUS_VID_STOP_PENDING = ThirtyTwoBits(0xC037001C)
    STATUS_VID_INVALID_PROCESSOR_STATE = ThirtyTwoBits(0xC037001D)
    STATUS_VID_EXCEEDED_KM_CONTEXT_COUNT_LIMIT = ThirtyTwoBits(0xC037001E)
    STATUS_VID_KM_INTERFACE_ALREADY_INITIALIZED = ThirtyTwoBits(0xC037001F)
    STATUS_VID_MB_PROPERTY_ALREADY_SET_RESET = ThirtyTwoBits(0xC0370020)
    STATUS_VID_MMIO_RANGE_DESTROYED = ThirtyTwoBits(0xC0370021)
    STATUS_VID_INVALID_CHILD_GPA_PAGE_SET = ThirtyTwoBits(0xC0370022)
    STATUS_VID_RESERVE_PAGE_SET_IS_BEING_USED = ThirtyTwoBits(0xC0370023)
    STATUS_VID_RESERVE_PAGE_SET_TOO_SMALL = ThirtyTwoBits(0xC0370024)
    STATUS_VID_MBP_ALREADY_LOCKED_USING_RESERVED_PAGE = ThirtyTwoBits(0xC0370025)
    STATUS_VID_MBP_COUNT_EXCEEDED_LIMIT = ThirtyTwoBits(0xC0370026)
    STATUS_VID_SAVED_STATE_CORRUPT = ThirtyTwoBits(0xC0370027)
    STATUS_VID_SAVED_STATE_UNRECOGNIZED_ITEM = ThirtyTwoBits(0xC0370028)
    STATUS_VID_SAVED_STATE_INCOMPATIBLE = ThirtyTwoBits(0xC0370029)
    STATUS_VID_VTL_ACCESS_DENIED = ThirtyTwoBits(0xC037002A)
    STATUS_VID_INSUFFICIENT_RESOURCES_RESERVE = ThirtyTwoBits(0xC037002B)
    STATUS_VID_INSUFFICIENT_RESOURCES_PHYSICAL_BUFFER = ThirtyTwoBits(0xC037002C)
    STATUS_VID_INSUFFICIENT_RESOURCES_HV_DEPOSIT = ThirtyTwoBits(0xC037002D)
    STATUS_VID_MEMORY_TYPE_NOT_SUPPORTED = ThirtyTwoBits(0xC037002E)
    STATUS_VID_INSUFFICIENT_RESOURCES_WITHDRAW = ThirtyTwoBits(0xC037002F)
    STATUS_VID_PROCESS_ALREADY_SET = ThirtyTwoBits(0xC0370030)
    STATUS_DM_OPERATION_LIMIT_EXCEEDED = ThirtyTwoBits(0xC0370600)
    STATUS_VOLMGR_DATABASE_FULL = ThirtyTwoBits(0xC0380001)
    STATUS_VOLMGR_DISK_CONFIGURATION_CORRUPTED = ThirtyTwoBits(0xC0380002)
    STATUS_VOLMGR_DISK_CONFIGURATION_NOT_IN_SYNC = ThirtyTwoBits(0xC0380003)
    STATUS_VOLMGR_PACK_CONFIG_UPDATE_FAILED = ThirtyTwoBits(0xC0380004)
    STATUS_VOLMGR_DISK_CONTAINS_NON_SIMPLE_VOLUME = ThirtyTwoBits(0xC0380005)
    STATUS_VOLMGR_DISK_DUPLICATE = ThirtyTwoBits(0xC0380006)
    STATUS_VOLMGR_DISK_DYNAMIC = ThirtyTwoBits(0xC0380007)
    STATUS_VOLMGR_DISK_ID_INVALID = ThirtyTwoBits(0xC0380008)
    STATUS_VOLMGR_DISK_INVALID = ThirtyTwoBits(0xC0380009)
    STATUS_VOLMGR_DISK_LAST_VOTER = ThirtyTwoBits(0xC038000A)
    STATUS_VOLMGR_DISK_LAYOUT_INVALID = ThirtyTwoBits(0xC038000B)
    STATUS_VOLMGR_DISK_LAYOUT_NON_BASIC_BETWEEN_BASIC_PARTITIONS = ThirtyTwoBits(0xC038000C)
    STATUS_VOLMGR_DISK_LAYOUT_NOT_CYLINDER_ALIGNED = ThirtyTwoBits(0xC038000D)
    STATUS_VOLMGR_DISK_LAYOUT_PARTITIONS_TOO_SMALL = ThirtyTwoBits(0xC038000E)
    STATUS_VOLMGR_DISK_LAYOUT_PRIMARY_BETWEEN_LOGICAL_PARTITIONS = ThirtyTwoBits(0xC038000F)
    STATUS_VOLMGR_DISK_LAYOUT_TOO_MANY_PARTITIONS = ThirtyTwoBits(0xC0380010)
    STATUS_VOLMGR_DISK_MISSING = ThirtyTwoBits(0xC0380011)
    STATUS_VOLMGR_DISK_NOT_EMPTY = ThirtyTwoBits(0xC0380012)
    STATUS_VOLMGR_DISK_NOT_ENOUGH_SPACE = ThirtyTwoBits(0xC0380013)
    STATUS_VOLMGR_DISK_REVECTORING_FAILED = ThirtyTwoBits(0xC0380014)
    STATUS_VOLMGR_DISK_SECTOR_SIZE_INVALID = ThirtyTwoBits(0xC0380015)
    STATUS_VOLMGR_DISK_SET_NOT_CONTAINED = ThirtyTwoBits(0xC0380016)
    STATUS_VOLMGR_DISK_USED_BY_MULTIPLE_MEMBERS = ThirtyTwoBits(0xC0380017)
    STATUS_VOLMGR_DISK_USED_BY_MULTIPLE_PLEXES = ThirtyTwoBits(0xC0380018)
    STATUS_VOLMGR_DYNAMIC_DISK_NOT_SUPPORTED = ThirtyTwoBits(0xC0380019)
    STATUS_VOLMGR_EXTENT_ALREADY_USED = ThirtyTwoBits(0xC038001A)
    STATUS_VOLMGR_EXTENT_NOT_CONTIGUOUS = ThirtyTwoBits(0xC038001B)
    STATUS_VOLMGR_EXTENT_NOT_IN_PUBLIC_REGION = ThirtyTwoBits(0xC038001C)
    STATUS_VOLMGR_EXTENT_NOT_SECTOR_ALIGNED = ThirtyTwoBits(0xC038001D)
    STATUS_VOLMGR_EXTENT_OVERLAPS_EBR_PARTITION = ThirtyTwoBits(0xC038001E)
    STATUS_VOLMGR_EXTENT_VOLUME_LENGTHS_DO_NOT_MATCH = ThirtyTwoBits(0xC038001F)
    STATUS_VOLMGR_FAULT_TOLERANT_NOT_SUPPORTED = ThirtyTwoBits(0xC0380020)
    STATUS_VOLMGR_INTERLEAVE_LENGTH_INVALID = ThirtyTwoBits(0xC0380021)
    STATUS_VOLMGR_MAXIMUM_REGISTERED_USERS = ThirtyTwoBits(0xC0380022)
    STATUS_VOLMGR_MEMBER_IN_SYNC = ThirtyTwoBits(0xC0380023)
    STATUS_VOLMGR_MEMBER_INDEX_DUPLICATE = ThirtyTwoBits(0xC0380024)
    STATUS_VOLMGR_MEMBER_INDEX_INVALID = ThirtyTwoBits(0xC0380025)
    STATUS_VOLMGR_MEMBER_MISSING = ThirtyTwoBits(0xC0380026)
    STATUS_VOLMGR_MEMBER_NOT_DETACHED = ThirtyTwoBits(0xC0380027)
    STATUS_VOLMGR_MEMBER_REGENERATING = ThirtyTwoBits(0xC0380028)
    STATUS_VOLMGR_ALL_DISKS_FAILED = ThirtyTwoBits(0xC0380029)
    STATUS_VOLMGR_NO_REGISTERED_USERS = ThirtyTwoBits(0xC038002A)
    STATUS_VOLMGR_NO_SUCH_USER = ThirtyTwoBits(0xC038002B)
    STATUS_VOLMGR_NOTIFICATION_RESET = ThirtyTwoBits(0xC038002C)
    STATUS_VOLMGR_NUMBER_OF_MEMBERS_INVALID = ThirtyTwoBits(0xC038002D)
    STATUS_VOLMGR_NUMBER_OF_PLEXES_INVALID = ThirtyTwoBits(0xC038002E)
    STATUS_VOLMGR_PACK_DUPLICATE = ThirtyTwoBits(0xC038002F)
    STATUS_VOLMGR_PACK_ID_INVALID = ThirtyTwoBits(0xC0380030)
    STATUS_VOLMGR_PACK_INVALID = ThirtyTwoBits(0xC0380031)
    STATUS_VOLMGR_PACK_NAME_INVALID = ThirtyTwoBits(0xC0380032)
    STATUS_VOLMGR_PACK_OFFLINE = ThirtyTwoBits(0xC0380033)
    STATUS_VOLMGR_PACK_HAS_QUORUM = ThirtyTwoBits(0xC0380034)
    STATUS_VOLMGR_PACK_WITHOUT_QUORUM = ThirtyTwoBits(0xC0380035)
    STATUS_VOLMGR_PARTITION_STYLE_INVALID = ThirtyTwoBits(0xC0380036)
    STATUS_VOLMGR_PARTITION_UPDATE_FAILED = ThirtyTwoBits(0xC0380037)
    STATUS_VOLMGR_PLEX_IN_SYNC = ThirtyTwoBits(0xC0380038)
    STATUS_VOLMGR_PLEX_INDEX_DUPLICATE = ThirtyTwoBits(0xC0380039)
    STATUS_VOLMGR_PLEX_INDEX_INVALID = ThirtyTwoBits(0xC038003A)
    STATUS_VOLMGR_PLEX_LAST_ACTIVE = ThirtyTwoBits(0xC038003B)
    STATUS_VOLMGR_PLEX_MISSING = ThirtyTwoBits(0xC038003C)
    STATUS_VOLMGR_PLEX_REGENERATING = ThirtyTwoBits(0xC038003D)
    STATUS_VOLMGR_PLEX_TYPE_INVALID = ThirtyTwoBits(0xC038003E)
    STATUS_VOLMGR_PLEX_NOT_RAID5 = ThirtyTwoBits(0xC038003F)
    STATUS_VOLMGR_PLEX_NOT_SIMPLE = ThirtyTwoBits(0xC0380040)
    STATUS_VOLMGR_STRUCTURE_SIZE_INVALID = ThirtyTwoBits(0xC0380041)
    STATUS_VOLMGR_TOO_MANY_NOTIFICATION_REQUESTS = ThirtyTwoBits(0xC0380042)
    STATUS_VOLMGR_TRANSACTION_IN_PROGRESS = ThirtyTwoBits(0xC0380043)
    STATUS_VOLMGR_UNEXPECTED_DISK_LAYOUT_CHANGE = ThirtyTwoBits(0xC0380044)
    STATUS_VOLMGR_VOLUME_CONTAINS_MISSING_DISK = ThirtyTwoBits(0xC0380045)
    STATUS_VOLMGR_VOLUME_ID_INVALID = ThirtyTwoBits(0xC0380046)
    STATUS_VOLMGR_VOLUME_LENGTH_INVALID = ThirtyTwoBits(0xC0380047)
    STATUS_VOLMGR_VOLUME_LENGTH_NOT_SECTOR_SIZE_MULTIPLE = ThirtyTwoBits(0xC0380048)
    STATUS_VOLMGR_VOLUME_NOT_MIRRORED = ThirtyTwoBits(0xC0380049)
    STATUS_VOLMGR_VOLUME_NOT_RETAINED = ThirtyTwoBits(0xC038004A)
    STATUS_VOLMGR_VOLUME_OFFLINE = ThirtyTwoBits(0xC038004B)
    STATUS_VOLMGR_VOLUME_RETAINED = ThirtyTwoBits(0xC038004C)
    STATUS_VOLMGR_NUMBER_OF_EXTENTS_INVALID = ThirtyTwoBits(0xC038004D)
    STATUS_VOLMGR_DIFFERENT_SECTOR_SIZE = ThirtyTwoBits(0xC038004E)
    STATUS_VOLMGR_BAD_BOOT_DISK = ThirtyTwoBits(0xC038004F)
    STATUS_VOLMGR_PACK_CONFIG_OFFLINE = ThirtyTwoBits(0xC0380050)
    STATUS_VOLMGR_PACK_CONFIG_ONLINE = ThirtyTwoBits(0xC0380051)
    STATUS_VOLMGR_NOT_PRIMARY_PACK = ThirtyTwoBits(0xC0380052)
    STATUS_VOLMGR_PACK_LOG_UPDATE_FAILED = ThirtyTwoBits(0xC0380053)
    STATUS_VOLMGR_NUMBER_OF_DISKS_IN_PLEX_INVALID = ThirtyTwoBits(0xC0380054)
    STATUS_VOLMGR_NUMBER_OF_DISKS_IN_MEMBER_INVALID = ThirtyTwoBits(0xC0380055)
    STATUS_VOLMGR_VOLUME_MIRRORED = ThirtyTwoBits(0xC0380056)
    STATUS_VOLMGR_PLEX_NOT_SIMPLE_SPANNED = ThirtyTwoBits(0xC0380057)
    STATUS_VOLMGR_NO_VALID_LOG_COPIES = ThirtyTwoBits(0xC0380058)
    STATUS_VOLMGR_PRIMARY_PACK_PRESENT = ThirtyTwoBits(0xC0380059)
    STATUS_VOLMGR_NUMBER_OF_DISKS_INVALID = ThirtyTwoBits(0xC038005A)
    STATUS_VOLMGR_MIRROR_NOT_SUPPORTED = ThirtyTwoBits(0xC038005B)
    STATUS_VOLMGR_RAID5_NOT_SUPPORTED = ThirtyTwoBits(0xC038005C)
    STATUS_BCD_TOO_MANY_ELEMENTS = ThirtyTwoBits(0xC0390002)
    STATUS_VHD_DRIVE_FOOTER_MISSING = ThirtyTwoBits(0xC03A0001)
    STATUS_VHD_DRIVE_FOOTER_CHECKSUM_MISMATCH = ThirtyTwoBits(0xC03A0002)
    STATUS_VHD_DRIVE_FOOTER_CORRUPT = ThirtyTwoBits(0xC03A0003)
    STATUS_VHD_FORMAT_UNKNOWN = ThirtyTwoBits(0xC03A0004)
    STATUS_VHD_FORMAT_UNSUPPORTED_VERSION = ThirtyTwoBits(0xC03A0005)
    STATUS_VHD_SPARSE_HEADER_CHECKSUM_MISMATCH = ThirtyTwoBits(0xC03A0006)
    STATUS_VHD_SPARSE_HEADER_UNSUPPORTED_VERSION = ThirtyTwoBits(0xC03A0007)
    STATUS_VHD_SPARSE_HEADER_CORRUPT = ThirtyTwoBits(0xC03A0008)
    STATUS_VHD_BLOCK_ALLOCATION_FAILURE = ThirtyTwoBits(0xC03A0009)
    STATUS_VHD_BLOCK_ALLOCATION_TABLE_CORRUPT = ThirtyTwoBits(0xC03A000A)
    STATUS_VHD_INVALID_BLOCK_SIZE = ThirtyTwoBits(0xC03A000B)
    STATUS_VHD_BITMAP_MISMATCH = ThirtyTwoBits(0xC03A000C)
    STATUS_VHD_PARENT_VHD_NOT_FOUND = ThirtyTwoBits(0xC03A000D)
    STATUS_VHD_CHILD_PARENT_ID_MISMATCH = ThirtyTwoBits(0xC03A000E)
    STATUS_VHD_CHILD_PARENT_TIMESTAMP_MISMATCH = ThirtyTwoBits(0xC03A000F)
    STATUS_VHD_METADATA_READ_FAILURE = ThirtyTwoBits(0xC03A0010)
    STATUS_VHD_METADATA_WRITE_FAILURE = ThirtyTwoBits(0xC03A0011)
    STATUS_VHD_INVALID_SIZE = ThirtyTwoBits(0xC03A0012)
    STATUS_VHD_INVALID_FILE_SIZE = ThirtyTwoBits(0xC03A0013)
    STATUS_VIRTDISK_PROVIDER_NOT_FOUND = ThirtyTwoBits(0xC03A0014)
    STATUS_VIRTDISK_NOT_VIRTUAL_DISK = ThirtyTwoBits(0xC03A0015)
    STATUS_VHD_PARENT_VHD_ACCESS_DENIED = ThirtyTwoBits(0xC03A0016)
    STATUS_VHD_CHILD_PARENT_SIZE_MISMATCH = ThirtyTwoBits(0xC03A0017)
    STATUS_VHD_DIFFERENCING_CHAIN_CYCLE_DETECTED = ThirtyTwoBits(0xC03A0018)
    STATUS_VHD_DIFFERENCING_CHAIN_ERROR_IN_PARENT = ThirtyTwoBits(0xC03A0019)
    STATUS_VIRTUAL_DISK_LIMITATION = ThirtyTwoBits(0xC03A001A)
    STATUS_VHD_INVALID_TYPE = ThirtyTwoBits(0xC03A001B)
    STATUS_VHD_INVALID_STATE = ThirtyTwoBits(0xC03A001C)
    STATUS_VIRTDISK_UNSUPPORTED_DISK_SECTOR_SIZE = ThirtyTwoBits(0xC03A001D)
    STATUS_VIRTDISK_DISK_ALREADY_OWNED = ThirtyTwoBits(0xC03A001E)
    STATUS_VIRTDISK_DISK_ONLINE_AND_WRITABLE = ThirtyTwoBits(0xC03A001F)
    STATUS_CTLOG_TRACKING_NOT_INITIALIZED = ThirtyTwoBits(0xC03A0020)
    STATUS_CTLOG_LOGFILE_SIZE_EXCEEDED_MAXSIZE = ThirtyTwoBits(0xC03A0021)
    STATUS_CTLOG_VHD_CHANGED_OFFLINE = ThirtyTwoBits(0xC03A0022)
    STATUS_CTLOG_INVALID_TRACKING_STATE = ThirtyTwoBits(0xC03A0023)
    STATUS_CTLOG_INCONSISTENT_TRACKING_FILE = ThirtyTwoBits(0xC03A0024)
    STATUS_VHD_METADATA_FULL = ThirtyTwoBits(0xC03A0028)
    STATUS_VHD_INVALID_CHANGE_TRACKING_ID = ThirtyTwoBits(0xC03A0029)
    STATUS_VHD_CHANGE_TRACKING_DISABLED = ThirtyTwoBits(0xC03A002A)
    STATUS_VHD_MISSING_CHANGE_TRACKING_INFORMATION = ThirtyTwoBits(0xC03A0030)
    STATUS_VHD_RESIZE_WOULD_TRUNCATE_DATA = ThirtyTwoBits(0xC03A0031)
    STATUS_VHD_COULD_NOT_COMPUTE_MINIMUM_VIRTUAL_SIZE = ThirtyTwoBits(0xC03A0032)
    STATUS_VHD_ALREADY_AT_OR_BELOW_MINIMUM_VIRTUAL_SIZE = ThirtyTwoBits(0xC03A0033)
    STATUS_VHD_UNEXPECTED_ID = ThirtyTwoBits(0xC03A0034)
    STATUS_RKF_KEY_NOT_FOUND = ThirtyTwoBits(0xC0400001)
    STATUS_RKF_DUPLICATE_KEY = ThirtyTwoBits(0xC0400002)
    STATUS_RKF_BLOB_FULL = ThirtyTwoBits(0xC0400003)
    STATUS_RKF_STORE_FULL = ThirtyTwoBits(0xC0400004)
    STATUS_RKF_FILE_BLOCKED = ThirtyTwoBits(0xC0400005)
    STATUS_RKF_ACTIVE_KEY = ThirtyTwoBits(0xC0400006)
    STATUS_RDBSS_RESTART_OPERATION = ThirtyTwoBits(0xC0410001)
    STATUS_RDBSS_CONTINUE_OPERATION = ThirtyTwoBits(0xC0410002)
    STATUS_RDBSS_POST_OPERATION = ThirtyTwoBits(0xC0410003)
    STATUS_RDBSS_RETRY_LOOKUP = ThirtyTwoBits(0xC0410004)
    STATUS_BTH_ATT_INVALID_HANDLE = ThirtyTwoBits(0xC0420001)
    STATUS_BTH_ATT_READ_NOT_PERMITTED = ThirtyTwoBits(0xC0420002)
    STATUS_BTH_ATT_WRITE_NOT_PERMITTED = ThirtyTwoBits(0xC0420003)
    STATUS_BTH_ATT_INVALID_PDU = ThirtyTwoBits(0xC0420004)
    STATUS_BTH_ATT_INSUFFICIENT_AUTHENTICATION = ThirtyTwoBits(0xC0420005)
    STATUS_BTH_ATT_REQUEST_NOT_SUPPORTED = ThirtyTwoBits(0xC0420006)
    STATUS_BTH_ATT_INVALID_OFFSET = ThirtyTwoBits(0xC0420007)
    STATUS_BTH_ATT_INSUFFICIENT_AUTHORIZATION = ThirtyTwoBits(0xC0420008)
    STATUS_BTH_ATT_PREPARE_QUEUE_FULL = ThirtyTwoBits(0xC0420009)
    STATUS_BTH_ATT_ATTRIBUTE_NOT_FOUND = ThirtyTwoBits(0xC042000A)
    STATUS_BTH_ATT_ATTRIBUTE_NOT_LONG = ThirtyTwoBits(0xC042000B)
    STATUS_BTH_ATT_INSUFFICIENT_ENCRYPTION_KEY_SIZE = ThirtyTwoBits(0xC042000C)
    STATUS_BTH_ATT_INVALID_ATTRIBUTE_VALUE_LENGTH = ThirtyTwoBits(0xC042000D)
    STATUS_BTH_ATT_UNLIKELY = ThirtyTwoBits(0xC042000E)
    STATUS_BTH_ATT_INSUFFICIENT_ENCRYPTION = ThirtyTwoBits(0xC042000F)
    STATUS_BTH_ATT_UNSUPPORTED_GROUP_TYPE = ThirtyTwoBits(0xC0420010)
    STATUS_BTH_ATT_INSUFFICIENT_RESOURCES = ThirtyTwoBits(0xC0420011)
    STATUS_BTH_ATT_UNKNOWN_ERROR = ThirtyTwoBits(0xC0421000)
    STATUS_SECUREBOOT_ROLLBACK_DETECTED = ThirtyTwoBits(0xC0430001)
    STATUS_SECUREBOOT_POLICY_VIOLATION = ThirtyTwoBits(0xC0430002)
    STATUS_SECUREBOOT_INVALID_POLICY = ThirtyTwoBits(0xC0430003)
    STATUS_SECUREBOOT_POLICY_PUBLISHER_NOT_FOUND = ThirtyTwoBits(0xC0430004)
    STATUS_SECUREBOOT_POLICY_NOT_SIGNED = ThirtyTwoBits(0xC0430005)
    STATUS_SECUREBOOT_FILE_REPLACED = ThirtyTwoBits(0xC0430007)
    STATUS_SECUREBOOT_POLICY_NOT_AUTHORIZED = ThirtyTwoBits(0xC0430008)
    STATUS_SECUREBOOT_POLICY_UNKNOWN = ThirtyTwoBits(0xC0430009)
    STATUS_SECUREBOOT_POLICY_MISSING_ANTIROLLBACKVERSION = ThirtyTwoBits(0xC043000A)
    STATUS_SECUREBOOT_PLATFORM_ID_MISMATCH = ThirtyTwoBits(0xC043000B)
    STATUS_SECUREBOOT_POLICY_ROLLBACK_DETECTED = ThirtyTwoBits(0xC043000C)
    STATUS_SECUREBOOT_POLICY_UPGRADE_MISMATCH = ThirtyTwoBits(0xC043000D)
    STATUS_SECUREBOOT_REQUIRED_POLICY_FILE_MISSING = ThirtyTwoBits(0xC043000E)
    STATUS_SECUREBOOT_NOT_BASE_POLICY = ThirtyTwoBits(0xC043000F)
    STATUS_SECUREBOOT_NOT_SUPPLEMENTAL_POLICY = ThirtyTwoBits(0xC0430010)
    STATUS_AUDIO_ENGINE_NODE_NOT_FOUND = ThirtyTwoBits(0xC0440001)
    STATUS_HDAUDIO_EMPTY_CONNECTION_LIST = ThirtyTwoBits(0xC0440002)
    STATUS_HDAUDIO_CONNECTION_LIST_NOT_SUPPORTED = ThirtyTwoBits(0xC0440003)
    STATUS_HDAUDIO_NO_LOGICAL_DEVICES_CREATED = ThirtyTwoBits(0xC0440004)
    STATUS_HDAUDIO_NULL_LINKED_LIST_ENTRY = ThirtyTwoBits(0xC0440005)
    STATUS_VSM_NOT_INITIALIZED = ThirtyTwoBits(0xC0450000)
    STATUS_VSM_DMA_PROTECTION_NOT_IN_USE = ThirtyTwoBits(0xC0450001)
    STATUS_IORING_REQUIRED_FLAG_NOT_SUPPORTED = ThirtyTwoBits(0xC0460001)
    STATUS_IORING_SUBMISSION_QUEUE_FULL = ThirtyTwoBits(0xC0460002)
    STATUS_IORING_VERSION_NOT_SUPPORTED = ThirtyTwoBits(0xC0460003)
    STATUS_IORING_SUBMISSION_QUEUE_TOO_BIG = ThirtyTwoBits(0xC0460004)
    STATUS_IORING_COMPLETION_QUEUE_TOO_BIG = ThirtyTwoBits(0xC0460005)
    STATUS_IORING_SUBMIT_IN_PROGRESS = ThirtyTwoBits(0xC0460006)
    STATUS_IORING_CORRUPT = ThirtyTwoBits(0xC0460007)
    STATUS_IORING_COMPLETION_QUEUE_TOO_FULL = ThirtyTwoBits(0xC0460008)
    STATUS_VOLSNAP_BOOTFILE_NOT_VALID = ThirtyTwoBits(0xC0500003)
    STATUS_VOLSNAP_ACTIVATION_TIMEOUT = ThirtyTwoBits(0xC0500004)
    STATUS_VOLSNAP_NO_BYPASSIO_WITH_SNAPSHOT = ThirtyTwoBits(0xC0500005)
    STATUS_IO_PREEMPTED = ThirtyTwoBits(0xC0510001)
    STATUS_SVHDX_ERROR_STORED = ThirtyTwoBits(0xC05C0000)
    STATUS_SVHDX_ERROR_NOT_AVAILABLE = ThirtyTwoBits(0xC05CFF00)
    STATUS_SVHDX_UNIT_ATTENTION_AVAILABLE = ThirtyTwoBits(0xC05CFF01)
    STATUS_SVHDX_UNIT_ATTENTION_CAPACITY_DATA_CHANGED = ThirtyTwoBits(0xC05CFF02)
    STATUS_SVHDX_UNIT_ATTENTION_RESERVATIONS_PREEMPTED = ThirtyTwoBits(0xC05CFF03)
    STATUS_SVHDX_UNIT_ATTENTION_RESERVATIONS_RELEASED = ThirtyTwoBits(0xC05CFF04)
    STATUS_SVHDX_UNIT_ATTENTION_REGISTRATIONS_PREEMPTED = ThirtyTwoBits(0xC05CFF05)
    STATUS_SVHDX_UNIT_ATTENTION_OPERATING_DEFINITION_CHANGED = ThirtyTwoBits(0xC05CFF06)
    STATUS_SVHDX_RESERVATION_CONFLICT = ThirtyTwoBits(0xC05CFF07)
    STATUS_SVHDX_WRONG_FILE_TYPE = ThirtyTwoBits(0xC05CFF08)
    STATUS_SVHDX_VERSION_MISMATCH = ThirtyTwoBits(0xC05CFF09)
    STATUS_VHD_SHARED = ThirtyTwoBits(0xC05CFF0A)
    STATUS_SVHDX_NO_INITIATOR = ThirtyTwoBits(0xC05CFF0B)
    STATUS_VHDSET_BACKING_STORAGE_NOT_FOUND = ThirtyTwoBits(0xC05CFF0C)
    STATUS_SMB_NO_PREAUTH_INTEGRITY_HASH_OVERLAP = ThirtyTwoBits(0xC05D0000)
    STATUS_SMB_BAD_CLUSTER_DIALECT = ThirtyTwoBits(0xC05D0001)
    STATUS_SMB_GUEST_LOGON_BLOCKED = ThirtyTwoBits(0xC05D0002)
    STATUS_SMB_NO_SIGNING_ALGORITHM_OVERLAP = ThirtyTwoBits(0xC05D0003)
    STATUS_NETWORK_AUTHENTICATION_PROMPT_CANCELED = ThirtyTwoBits(0xC05D0004)
    STATUS_SPACES_FAULT_DOMAIN_TYPE_INVALID = ThirtyTwoBits(0xC0E70001)
    STATUS_SPACES_RESILIENCY_TYPE_INVALID = ThirtyTwoBits(0xC0E70003)
    STATUS_SPACES_DRIVE_SECTOR_SIZE_INVALID = ThirtyTwoBits(0xC0E70004)
    STATUS_SPACES_DRIVE_REDUNDANCY_INVALID = ThirtyTwoBits(0xC0E70006)
    STATUS_SPACES_NUMBER_OF_DATA_COPIES_INVALID = ThirtyTwoBits(0xC0E70007)
    STATUS_SPACES_INTERLEAVE_LENGTH_INVALID = ThirtyTwoBits(0xC0E70009)
    STATUS_SPACES_NUMBER_OF_COLUMNS_INVALID = ThirtyTwoBits(0xC0E7000A)
    STATUS_SPACES_NOT_ENOUGH_DRIVES = ThirtyTwoBits(0xC0E7000B)
    STATUS_SPACES_EXTENDED_ERROR = ThirtyTwoBits(0xC0E7000C)
    STATUS_SPACES_PROVISIONING_TYPE_INVALID = ThirtyTwoBits(0xC0E7000D)
    STATUS_SPACES_ALLOCATION_SIZE_INVALID = ThirtyTwoBits(0xC0E7000E)
    STATUS_SPACES_ENCLOSURE_AWARE_INVALID = ThirtyTwoBits(0xC0E7000F)
    STATUS_SPACES_WRITE_CACHE_SIZE_INVALID = ThirtyTwoBits(0xC0E70010)
    STATUS_SPACES_NUMBER_OF_GROUPS_INVALID = ThirtyTwoBits(0xC0E70011)
    STATUS_SPACES_DRIVE_OPERATIONAL_STATE_INVALID = ThirtyTwoBits(0xC0E70012)
    STATUS_SPACES_UPDATE_COLUMN_STATE = ThirtyTwoBits(0xC0E70013)
    STATUS_SPACES_MAP_REQUIRED = ThirtyTwoBits(0xC0E70014)
    STATUS_SPACES_UNSUPPORTED_VERSION = ThirtyTwoBits(0xC0E70015)
    STATUS_SPACES_CORRUPT_METADATA = ThirtyTwoBits(0xC0E70016)
    STATUS_SPACES_DRT_FULL = ThirtyTwoBits(0xC0E70017)
    STATUS_SPACES_INCONSISTENCY = ThirtyTwoBits(0xC0E70018)
    STATUS_SPACES_LOG_NOT_READY = ThirtyTwoBits(0xC0E70019)
    STATUS_SPACES_NO_REDUNDANCY = ThirtyTwoBits(0xC0E7001A)
    STATUS_SPACES_DRIVE_NOT_READY = ThirtyTwoBits(0xC0E7001B)
    STATUS_SPACES_DRIVE_SPLIT = ThirtyTwoBits(0xC0E7001C)
    STATUS_SPACES_DRIVE_LOST_DATA = ThirtyTwoBits(0xC0E7001D)
    STATUS_SPACES_ENTRY_INCOMPLETE = ThirtyTwoBits(0xC0E7001E)
    STATUS_SPACES_ENTRY_INVALID = ThirtyTwoBits(0xC0E7001F)
    STATUS_SPACES_MARK_DIRTY = ThirtyTwoBits(0xC0E70020)
    STATUS_SPACES_PD_NOT_FOUND = ThirtyTwoBits(0xC0E70021)
    STATUS_SPACES_PD_LENGTH_MISMATCH = ThirtyTwoBits(0xC0E70022)
    STATUS_SPACES_PD_UNSUPPORTED_VERSION = ThirtyTwoBits(0xC0E70023)
    STATUS_SPACES_PD_INVALID_DATA = ThirtyTwoBits(0xC0E70024)
    STATUS_SPACES_FLUSH_METADATA = ThirtyTwoBits(0xC0E70025)
    STATUS_SPACES_CACHE_FULL = ThirtyTwoBits(0xC0E70026)
    STATUS_SPACES_REPAIR_IN_PROGRESS = ThirtyTwoBits(0xC0E70027)
    STATUS_SECCORE_INVALID_COMMAND = ThirtyTwoBits(0xC0E80000)
    STATUS_SYSTEM_INTEGRITY_ROLLBACK_DETECTED = ThirtyTwoBits(0xC0E90001)
    STATUS_SYSTEM_INTEGRITY_POLICY_VIOLATION = ThirtyTwoBits(0xC0E90002)
    STATUS_SYSTEM_INTEGRITY_INVALID_POLICY = ThirtyTwoBits(0xC0E90003)
    STATUS_SYSTEM_INTEGRITY_POLICY_NOT_SIGNED = ThirtyTwoBits(0xC0E90004)
    STATUS_SYSTEM_INTEGRITY_TOO_MANY_POLICIES = ThirtyTwoBits(0xC0E90005)
    STATUS_SYSTEM_INTEGRITY_SUPPLEMENTAL_POLICY_NOT_AUTHORIZED = ThirtyTwoBits(0xC0E90006)
    STATUS_SYSTEM_INTEGRITY_REPUTATION_MALICIOUS = ThirtyTwoBits(0xC0E90007)
    STATUS_SYSTEM_INTEGRITY_REPUTATION_PUA = ThirtyTwoBits(0xC0E90008)
    STATUS_SYSTEM_INTEGRITY_REPUTATION_DANGEROUS_EXT = ThirtyTwoBits(0xC0E90009)
    STATUS_SYSTEM_INTEGRITY_REPUTATION_OFFLINE = ThirtyTwoBits(0xC0E9000A)
    STATUS_SYSTEM_INTEGRITY_REPUTATION_UNFRIENDLY_FILE = ThirtyTwoBits(0xC0E9000B)
    STATUS_SYSTEM_INTEGRITY_REPUTATION_UNATTAINABLE = ThirtyTwoBits(0xC0E9000C)
    STATUS_SYSTEM_INTEGRITY_REPUTATION_EXPLICIT_DENY_FILE = ThirtyTwoBits(0xC0E9000D)
    STATUS_NO_APPLICABLE_APP_LICENSES_FOUND = ThirtyTwoBits(0xC0EA0001)
    STATUS_CLIP_LICENSE_NOT_FOUND = ThirtyTwoBits(0xC0EA0002)
    STATUS_CLIP_DEVICE_LICENSE_MISSING = ThirtyTwoBits(0xC0EA0003)
    STATUS_CLIP_LICENSE_INVALID_SIGNATURE = ThirtyTwoBits(0xC0EA0004)
    STATUS_CLIP_KEYHOLDER_LICENSE_MISSING_OR_INVALID = ThirtyTwoBits(0xC0EA0005)
    STATUS_CLIP_LICENSE_EXPIRED = ThirtyTwoBits(0xC0EA0006)
    STATUS_CLIP_LICENSE_SIGNED_BY_UNKNOWN_SOURCE = ThirtyTwoBits(0xC0EA0007)
    STATUS_CLIP_LICENSE_NOT_SIGNED = ThirtyTwoBits(0xC0EA0008)
    STATUS_CLIP_LICENSE_HARDWARE_ID_OUT_OF_TOLERANCE = ThirtyTwoBits(0xC0EA0009)
    STATUS_CLIP_LICENSE_DEVICE_ID_MISMATCH = ThirtyTwoBits(0xC0EA000A)
    STATUS_PLATFORM_MANIFEST_NOT_AUTHORIZED = ThirtyTwoBits(0xC0EB0001)
    STATUS_PLATFORM_MANIFEST_INVALID = ThirtyTwoBits(0xC0EB0002)
    STATUS_PLATFORM_MANIFEST_FILE_NOT_AUTHORIZED = ThirtyTwoBits(0xC0EB0003)
    STATUS_PLATFORM_MANIFEST_CATALOG_NOT_AUTHORIZED = ThirtyTwoBits(0xC0EB0004)
    STATUS_PLATFORM_MANIFEST_BINARY_ID_NOT_FOUND = ThirtyTwoBits(0xC0EB0005)
    STATUS_PLATFORM_MANIFEST_NOT_ACTIVE = ThirtyTwoBits(0xC0EB0006)
    STATUS_PLATFORM_MANIFEST_NOT_SIGNED = ThirtyTwoBits(0xC0EB0007)
    STATUS_APPEXEC_CONDITION_NOT_SATISFIED = ThirtyTwoBits(0xC0EC0000)
    STATUS_APPEXEC_HANDLE_INVALIDATED = ThirtyTwoBits(0xC0EC0001)
    STATUS_APPEXEC_INVALID_HOST_GENERATION = ThirtyTwoBits(0xC0EC0002)
    STATUS_APPEXEC_UNEXPECTED_PROCESS_REGISTRATION = ThirtyTwoBits(0xC0EC0003)
    STATUS_APPEXEC_INVALID_HOST_STATE = ThirtyTwoBits(0xC0EC0004)
    STATUS_APPEXEC_NO_DONOR = ThirtyTwoBits(0xC0EC0005)
    STATUS_APPEXEC_HOST_ID_MISMATCH = ThirtyTwoBits(0xC0EC0006)
    STATUS_APPEXEC_UNKNOWN_USER = ThirtyTwoBits(0xC0EC0007)
    STATUS_APPEXEC_APP_COMPAT_BLOCK = ThirtyTwoBits(0xC0EC0008)
    STATUS_APPEXEC_CALLER_WAIT_TIMEOUT = ThirtyTwoBits(0xC0EC0009)
    STATUS_APPEXEC_CALLER_WAIT_TIMEOUT_TERMINATION = ThirtyTwoBits(0xC0EC000A)
    STATUS_APPEXEC_CALLER_WAIT_TIMEOUT_LICENSING = ThirtyTwoBits(0xC0EC000B)
    STATUS_APPEXEC_CALLER_WAIT_TIMEOUT_RESOURCES = ThirtyTwoBits(0xC0EC000C)
